%
% bsim_collcrossconddata.m
%
% Batch simulation script that collects data across dopamine conditions.
%
% Last modification: 1/21/08


% Set path stuff.
runcoll_path = runcoll_stats;
taskset_path = taskset_TOBS1c_TOBS1crev;
% simphases_path = simphases_maint;
% simphases_path = simphases_train;
simphases_path = simphases_rev;

% Set up manipulation conditions we're working with in order of display 
% the graphs.
% manip_conds = [ manip_NShypo3 manip_NShypo2 manip_NShypo15 ...
%     manip_NShypo1 manip_NShypo05 manip_normal manip_NShyper05 ...
%     manip_NShyper1 manip_NShyper3 manip_NShyper5 ];
% manip_conds = [ manip_Bhypo3 manip_Bhypo2 manip_Bhypo15 ...
%     manip_Bhypo1 manip_Bhypo05 manip_normal manip_Bhyper05 ...
%     manip_Bhyper1 manip_Bhyper3 manip_Bhyper5 ];
% manip_conds = [ manip_PRhypo3 manip_PRhypo2 manip_PRhypo15 ...
%     manip_PRhypo1 manip_PRhypo05 manip_normal manip_PRhyper05 ...
%     manip_PRhyper1 manip_PRhyper3 manip_PRhyper5 ];
manip_conds = [ manip_ghypo3 manip_ghypo2 manip_ghypo15 ...
    manip_ghypo1 manip_ghypo05 manip_normal manip_ghyper05 ...
    manip_ghyper1 manip_ghyper3 manip_ghyper5 ];
num_conds = size(manip_conds,2);

% Set subject range.
first_subj = 1;
last_subj = 3;
num_subjs = last_subj - first_subj + 1;

disp_figs = [ ...
    0 ...             % Mean RTs
    0 ...             % Mean reward to next response delay
    1 ...             % Average % Correct
    1 ...             % Average % Incorrect
    1 ...             % Average % Missed
    1 ...             % Average % Conflicts
    1 ...             % Average % Extra Responses
    1 ...             % Average % Late Responses
    0 ...             % # learning trials
    1 ...             % Last 13 trials % Correct
    1 ...             % Last 13 trials % Incorrect
    1 ...             % Last 13 trials % Missed    
    1 ...             % Last 13 trials % Conflict
    1 ...             % Last 13 trials % Extra Response
    1 ...             % Last 13 trials % Late        
    0 ...             % % subjects with learned conjunction
    0 ...             % Average % Incorrect for wrong-first trials
    0 ...             % Average Babble unit activation
    0 ...             % Average Plan unit activation
    0 ...             % Average Nod Request unit activation
    0 ...             % Average Shake Request unit activation
    0 ...             % Average Babble Request unit activation
    0 ...             % Average Nod Go unit activation
    0 ...             % Average Shake Go unit activation
    0 ...             % Average Babble Go unit activation    
    0 ...             % Average Nod NoGo unit activation
    0 ...             % Average Shake NoGo unit activation
    0 ...             % Average Babble NoGo unit activation    
    ];

% Initialize data for manipulations.
mean_RTs = zeros(num_conds,num_subjs);
mean_rew_to_next_resps = zeros(num_conds,num_subjs);
ave_pct_corrects = zeros(num_conds,num_subjs);
ave_pct_incorrect = zeros(num_conds,num_subjs);
ave_pct_missed = zeros(num_conds,num_subjs);
ave_pct_conflict = zeros(num_conds,num_subjs);
ave_pct_extra_resp = zeros(num_conds,num_subjs);
ave_pct_late = zeros(num_conds,num_subjs);
learn_trials_meas = zeros(num_conds,num_subjs);
end_accur_meas = zeros(num_conds,num_subjs);
end_incorr_meas = zeros(num_conds,num_subjs);
end_missed_meas = zeros(num_conds,num_subjs);
end_conflict_meas = zeros(num_conds,num_subjs);
end_extra_resp_meas = zeros(num_conds,num_subjs);
end_late_meas = zeros(num_conds,num_subjs);
conj_learned_meas = zeros(num_conds,num_subjs);
wrong_guess_first_meas = zeros(num_conds,num_subjs);
ave_babble_activ_meas = zeros(num_conds,num_subjs);
ave_plan_activ_meas = zeros(num_conds,num_subjs);
ave_nod_req_activ_meas = zeros(num_conds,num_subjs);
ave_shake_req_activ_meas = zeros(num_conds,num_subjs);
ave_babble_req_activ_meas = zeros(num_conds,num_subjs);  
ave_nod_go_activ_meas = zeros(num_conds,num_subjs);
ave_shake_go_activ_meas = zeros(num_conds,num_subjs);
ave_babble_go_activ_meas = zeros(num_conds,num_subjs);
ave_nod_nogo_activ_meas = zeros(num_conds,num_subjs);
ave_shake_nogo_activ_meas = zeros(num_conds,num_subjs);
ave_babble_nogo_activ_meas = zeros(num_conds,num_subjs);

% Load all of the data for the manipulations.
for xx_cccd = 1:num_conds
    manip_path = manip_conds(xx_cccd);
    for yy_cccd = first_subj:last_subj
        subj_num = yy_cccd;
        bsim_setdatapath;   
        bsim_loadmultirun;
        collect_perf_data;       
        mean_RTs(xx_cccd,yy_cccd) = mean_RT;
        mean_rew_to_next_resps(xx_cccd,yy_cccd) = mean_rew_to_next_resp;
        ave_pct_corrects(xx_cccd,yy_cccd) = pct_correct;
        ave_pct_incorrect(xx_cccd,yy_cccd) = pct_incorrect;
        ave_pct_missed(xx_cccd,yy_cccd) = pct_missed; 
        ave_pct_conflict(xx_cccd,yy_cccd) = pct_conflict;
        ave_pct_extra_resp(xx_cccd,yy_cccd) = pct_extra_resp;
        ave_pct_late(xx_cccd,yy_cccd) = pct_late;
        learn_trials_meas(xx_cccd,yy_cccd) = learn_trials;
        end_accur_meas(xx_cccd,yy_cccd) = last13pct_corr;
        end_incorr_meas(xx_cccd,yy_cccd) = last13pct_incorr;
        end_missed_meas(xx_cccd,yy_cccd) = last13pct_missed;
        end_conflict_meas(xx_cccd,yy_cccd) = last13pct_conflict;
        end_extra_resp_meas(xx_cccd,yy_cccd) = last13pct_extra_resp;
        end_late_meas(xx_cccd,yy_cccd) = last13pct_late;
        conj_learned_meas(xx_cccd,yy_cccd) = conj_learned;
        wrong_guess_first_meas(xx_cccd,yy_cccd) = wrong_guess_first;
        ave_babble_activ_meas(xx_cccd,yy_cccd) = ave_babble_activ;
        ave_plan_activ_meas(xx_cccd,yy_cccd) = ave_plan_activ;
        ave_nod_req_activ_meas(xx_cccd,yy_cccd) = ave_nod_req_activ;
        ave_shake_req_activ_meas(xx_cccd,yy_cccd) = ave_shake_req_activ;
        ave_babble_req_activ_meas(xx_cccd,yy_cccd) = ave_babble_req_activ;
        ave_nod_go_activ_meas(xx_cccd,yy_cccd) = ave_nod_go_activ; 
        ave_shake_go_activ_meas(xx_cccd,yy_cccd) = ave_shake_go_activ; 
        ave_babble_go_activ_meas(xx_cccd,yy_cccd) = ave_babble_go_activ; 
        ave_nod_nogo_activ_meas(xx_cccd,yy_cccd) = ave_nod_nogo_activ; 
        ave_shake_nogo_activ_meas(xx_cccd,yy_cccd) = ave_shake_nogo_activ;
        ave_babble_nogo_activ_meas(xx_cccd,yy_cccd) = ave_babble_nogo_activ;
    end;
end;

if (disp_figs(1))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(mean_RTs(xx,:));
        dat_stds(xx) = std(mean_RTs(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on RT');
    xlabel('DA Condition');
    ylabel('RT (in ms)');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) 600 2600]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(2))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(mean_rew_to_next_resps(xx,:));
        dat_stds(xx) = std(mean_rew_to_next_resps(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Reward to Next Response Interval');
    xlabel('DA Condition');
    ylabel('Interval (in ms)');
    set(gca,'XTick',1:num_conds);
%     axis([0.5 (num_conds + 0.5) 0 70000]);
    axis([0.5 (num_conds + 0.5) 0 200000]);    
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(3))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(ave_pct_corrects(xx,:));
        dat_stds(xx) = std(ave_pct_corrects(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Percent Correct');
    xlabel('DA Condition');
    ylabel('Percent Correct');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(4))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(ave_pct_incorrect(xx,:));
        dat_stds(xx) = std(ave_pct_incorrect(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Percent Incorrect');
    xlabel('DA Condition');
    ylabel('Percent Incorrect');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 51]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(5))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(ave_pct_missed(xx,:));
        dat_stds(xx) = std(ave_pct_missed(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Percent Missed');
    xlabel('DA Condition');
    ylabel('Percent Missed');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);    
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(6))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(ave_pct_conflict(xx,:));
        dat_stds(xx) = std(ave_pct_conflict(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Percent Conflict');
    xlabel('DA Condition');
    ylabel('Percent Conflict');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 21]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(7))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(ave_pct_extra_resp(xx,:));
        dat_stds(xx) = std(ave_pct_extra_resp(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Percent Extra Resp');
    xlabel('DA Condition');
    ylabel('Percent Extra Resp');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 21]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(8))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(ave_pct_late(xx,:));
        dat_stds(xx) = std(ave_pct_late(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Percent Late');
    xlabel('DA Condition');
    ylabel('Percent Late');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 21]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

% Filter the learning trials iteration measure with the measure of whether
% the conjunction was learned or not.
learn_trials_meas = learn_trials_meas .* conj_learned_meas;

% Change the zeros in the learning iteration measure to a high number.
learn_trials_meas(find(learn_trials_meas == 0)) = 100;

if (disp_figs(9))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(learn_trials_meas(xx,:));
        dat_stds(xx) = std(learn_trials_meas(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Learning Trials');
    xlabel('DA Condition');
    ylabel('Trials to Learn');
    set(gca,'XTick',1:num_conds);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(10))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(end_accur_meas(xx,:));
        dat_stds(xx) = std(end_accur_meas(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on End Conj Accuracy');
    xlabel('DA Condition');
    ylabel('Last 13 Trial Accuracy');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(11))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(end_incorr_meas(xx,:));
        dat_stds(xx) = std(end_incorr_meas(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Last 13 Trial % Incorrect');
    xlabel('DA Condition');
    ylabel('Last 13 Trial % Incorrect');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(12))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(end_missed_meas(xx,:));
        dat_stds(xx) = std(end_missed_meas(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Last 13 Trial % Missed');
    xlabel('DA Condition');
    ylabel('Last 13 Trial % Missed');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(13))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(end_conflict_meas(xx,:));
        dat_stds(xx) = std(end_conflict_meas(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Last 13 Trial % Conflict');
    xlabel('DA Condition');
    ylabel('Last 13 Trial % Conflict');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(14))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(end_extra_resp_meas(xx,:));
        dat_stds(xx) = std(end_extra_resp_meas(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Last 13 Trial % Extra Response');
    xlabel('DA Condition');
    ylabel('Last 13 Trial % Extra Response');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(15))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_means(xx) = mean(end_late_meas(xx,:));
        dat_stds(xx) = std(end_late_meas(xx,:));
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Last 13 Trial % Late');
    xlabel('DA Condition');
    ylabel('Last 13 Trial % Late');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(16))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        the_plot = 100 * sum(conj_learned_meas,2) / size(conj_learned_meas,2);
    end;
    plot(the_plot);
    title('DA Effect on Conj Learning Chance');
    xlabel('DA Condition');
    ylabel('Percent of Subjects the Learned');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 101]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

wgf_incorr = ave_pct_incorrect .* wrong_guess_first_meas;

if (disp_figs(17))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = wgf_incorr(xx,:);
        dat_points = dat_points(find(dat_points ~= 0));
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Percent Incorrect Wrong Guess First');
    xlabel('DA Condition');
    ylabel('Percent Incorrect');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -1 41]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(18))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_babble_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Babble Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]); 
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(19))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_plan_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Plan Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 5.1]); 
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(20))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_nod_req_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Nod Request Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]); 
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(21))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_shake_req_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Shake Request Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]); 
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(22))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_babble_req_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Babble Request Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]); 
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(23))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_nod_go_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Nod Go Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]); 
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(24))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_shake_go_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Shake Go Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(25))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_babble_go_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Babble Go Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(26))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_nod_nogo_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Nod NoGo Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(27))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_shake_nogo_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Shake NoGo Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;

if (disp_figs(28))
    figure;
    dat_means = zeros(1,num_conds);
    dat_stds = zeros(1,num_conds);
    for xx = 1:num_conds
        dat_points = ave_babble_nogo_activ_meas(xx,:);
        dat_means(xx) = mean(dat_points);
        dat_stds(xx) = std(dat_points);
    end;
    errorbar(dat_means,dat_stds);
    title('DA Effect on Average Babble NoGo Unit Activity');
    xlabel('DA Condition');
    ylabel('Average Activation');
    set(gca,'XTick',1:num_conds);
    axis([0.5 (num_conds + 0.5) -0.1 0.8]);
    if (manip_conds(1) == manip_NShypo3)
        set(gca,'XTickLabel',{'ns3';'ns2';'ns15';'ns1';'ns05';'norm';'NS05'; ...
            'NS1';'NS3';'NS5'}); 
    elseif (manip_conds(1) == manip_Bhypo3)
        set(gca,'XTickLabel',{'b3';'b2';'b15';'b1';'b05';'norm';'B05'; ...
            'B1';'B3';'B5'}); 
    elseif (manip_conds(1) == manip_PRhypo3)
        set(gca,'XTickLabel',{'pr3';'pr2';'pr15';'pr1';'pr05';'norm';'PR05'; ...
            'PR1';'PR3';'PR5'});   
    else
        set(gca,'XTickLabel',{'g3';'g2';'g15';'g1';'g05';'norm';'G05'; ...
            'G1';'G3';'G5'});
    end;
end;