%
% bsim_compileruns.m
%
% Batch simulation script which compiles together individual trial runs
% into a master run file.
%
% Last modification: 1/21/08


% Set path.
% runcoll_path = runcoll_stats;
% % runcoll_path = runcoll_exemplar;
% taskset_path = taskset_TOBS1c_TOBS1crev;
% % taskset_path = taskset_TOBS_TOBSrev;
% simphases_path = simphases_maint;
% manip_path = manip_normal;
% subj_num = 1;
% run_num = 1;

% Change (temporarily) to the subject directory.
bsim_setdatapath;
old_dir = pwd;
cd(path_name);
dir_data = dir;
dir_data_c = struct2cell(dir_data);
fnames = dir_data_c(1,:)';
dir_run_nums = [];
for xx = 1:size(fnames,1)
    new_num = sscanf(cell2mat(fnames(xx)),'r%d_*');
    if ~isempty(new_num)
        dir_run_nums = [ dir_run_nums new_num ];
    end;
end;
dir_min_run = min(dir_run_nums);
dir_max_run = max(dir_run_nums);

% Change back to the old directory.
cd(old_dir);

% Set range of runs.
% first_run = 1;
% last_run = 4;
first_run = dir_min_run;
last_run = dir_max_run;

% Initialize multi-run variables.
mr_num_iters = 0;
mr_stim_on_sv = [];
mr_stim_x_sv = [];
mr_stim_y_sv = [];
mr_stim_red_sv = [];
mr_stim_green_sv = [];
mr_stim_blue_sv = [];
mr_tones_on_sv = zeros(12,1);
mr_reward_on_sv = [];
mr_reward_trigger_sv = [];
mr_reward_delivered_sv = [];
mr_punish_on_sv = [];
mr_punish_trigger_sv = [];
mr_punish_delivered_sv = [];
mr_novelty_on_sv = [];
mr_camera_x_sv = [];
mr_camera_y_sv = [];
mr_mem_color_map_sv = zeros(4,1);
mr_mem_tones_map_sv = zeros(12,1);
mr_track_execute_sv = [];
mr_nod_execute_sv = [];
mr_shake_execute_sv = [];
mr_target_count = 0;
mr_distractor_count = 0;
mr_delay_count = 0;
mr_reward_count = 0;
mr_punish_count = 0;
mr_target_nod = [];
mr_target_shake = [];
mr_target_x_nod = [];
mr_target_nod_shake = [];
mr_target_miss = [];
mr_distractor_nod = [];
mr_distractor_shake = [];
mr_distractor_x_shake = [];
mr_distractor_nod_shake = [];
mr_distractor_miss = [];
mr_delay_nod = [];
mr_delay_shake = [];
mr_delay_nod_shake = [];
mr_blind_nod = [];
mr_blind_shake = [];

color_wm_units = zeros(4,1);
tones_wm_units = zeros(12,1);
novelty_unit = [];
DA_unit = [];
frust_unit = [];
babble_req_unit = [];
babble_go_e_sum = [];
babble_go_i_sum = [];
babble_nogo_sum = [];
babble_init_unit = [];
babble_exec_unit = [];
babble_sum = [];
plan_sum = [];
nod_req_sum = [];
nod_go_e_sum = [];
nod_go_i_sum = [];
nod_nogo_sum = [];
nod_init_unit = [];
shake_req_sum = [];
shake_go_e_sum = [];
shake_go_i_sum = [];
shake_nogo_sum = [];
shake_init_unit = [];
ns_conflict_unit = [];
da_effect_units = zeros(6,1);

% Collate the results from the different runs.
for xx = first_run:last_run
    run_num = xx;
    bsim_setdatapath;
    load_simrun;
    
    % Make sure we have all of the model indices.
    get_cog_model_indices;

    mr_num_iters = mr_num_iters + num_iters;
    mr_stim_on_sv = [ mr_stim_on_sv stim_on_sv ];
    mr_stim_x_sv = [ mr_stim_x_sv stim_x_sv ];
    mr_stim_y_sv = [ mr_stim_y_sv stim_y_sv ];
    mr_stim_red_sv = [ mr_stim_red_sv stim_red_sv ];
    mr_stim_green_sv = [ mr_stim_green_sv stim_green_sv ];
    mr_stim_blue_sv = [ mr_stim_blue_sv stim_blue_sv ]; 
    mr_tones_on_sv = [ mr_tones_on_sv tones_on_sv ];
    mr_reward_on_sv = [ mr_reward_on_sv reward_on_sv ];
    mr_reward_trigger_sv = [ mr_reward_trigger_sv reward_trigger_sv ];
    mr_reward_delivered_sv = [ mr_reward_delivered_sv reward_delivered_sv];     
    mr_punish_on_sv = [ mr_punish_on_sv punish_on_sv ]; 
    mr_punish_trigger_sv = [ mr_punish_trigger_sv punish_trigger_sv ];
    mr_punish_delivered_sv = [ mr_punish_delivered_sv punish_delivered_sv ]; 
    mr_novelty_on_sv = [ mr_novelty_on_sv novelty_on_sv ];
    mr_camera_x_sv = [ mr_camera_x_sv camera_x_sv ];
    mr_camera_y_sv = [ mr_camera_y_sv camera_y_sv ];    
    mr_mem_color_map_sv = [ mr_mem_color_map_sv mem_color_map_sv ];
    mr_mem_tones_map_sv = [ mr_mem_tones_map_sv mem_tones_map_sv ];    
    mr_track_execute_sv = [ mr_track_execute_sv track_execute_sv ];    
    mr_nod_execute_sv = [ mr_nod_execute_sv nod_execute_sv ];
    mr_shake_execute_sv = [ mr_shake_execute_sv shake_execute_sv ];
    mr_target_count = mr_target_count + target_count;
    mr_distractor_count = mr_distractor_count + distractor_count;
    mr_delay_count = mr_delay_count + delay_count;
    mr_reward_count = mr_reward_count + reward_count;
    mr_punish_count = mr_punish_count + punish_count;
    res_ioffset = mr_num_iters - num_iters;
    mr_target_nod = [ mr_target_nod (target_nod + res_ioffset) ];
    mr_target_shake = [ mr_target_shake (target_shake + res_ioffset) ];
    mr_target_x_nod = [ mr_target_x_nod (target_x_nod + res_ioffset) ];
    mr_target_nod_shake = [ mr_target_nod_shake ...
        (target_nod_shake + res_ioffset) ];
    mr_target_miss = [ mr_target_miss (target_miss + res_ioffset) ];
    mr_distractor_nod = [ mr_distractor_nod ...
        (distractor_nod + res_ioffset) ];
    mr_distractor_shake = [ mr_distractor_shake ...
        (distractor_shake + res_ioffset) ];
    mr_distractor_x_shake = [ mr_distractor_x_shake ...
        (distractor_x_shake + res_ioffset) ];
    mr_distractor_nod_shake = [ mr_distractor_nod_shake ...
        (distractor_nod_shake + res_ioffset) ];
    mr_distractor_miss = [ mr_distractor_miss ...
        (distractor_miss + res_ioffset) ];
    mr_delay_nod = [ mr_delay_nod (delay_nod + res_ioffset) ];
    mr_delay_shake = [ mr_delay_shake (delay_shake + res_ioffset) ];
    mr_delay_nod_shake = [ mr_delay_nod_shake ...
        (delay_nod_shake + res_ioffset) ];
    mr_blind_nod = [ mr_blind_nod (blind_nod + res_ioffset) ];
    mr_blind_shake = [ mr_blind_shake (blind_shake + res_ioffset) ];
    
    area_ind = ColorMem_ind;
    new_activs = zeros(4,num_iters);
    for yy_bcr = 1:4
        x_ind = 1;
        y_ind = yy_bcr;
        fetchps_unit_activ_alliters;
        new_activs(yy_bcr,:) = activ_trace;
    end;
    color_wm_units = [ color_wm_units new_activs ];
 
    area_ind = TonesMem_ind;
    new_activs = zeros(12,num_iters);
    for yy_bcr = 1:12   
        x_ind = 1;
        y_ind = yy_bcr;
        fetchps_unit_activ_alliters;
        new_activs(yy_bcr,:) = activ_trace;
    end;
    tones_wm_units = [ tones_wm_units new_activs ];
    
    area_ind = Novelty_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    novelty_unit = [ novelty_unit activ_trace ];
    
    area_ind = DASignal_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    DA_unit = [ DA_unit activ_trace ];
    
    area_ind = Frustration_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;    
    frust_unit = [ frust_unit activ_trace ];
 
    area_ind = BabbleReq_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    babble_req_unit = [ babble_req_unit activ_trace ];

    activ_trace = zeros(1,num_iters);
    area_ind = BabbleGoE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    babble_go_e_sum = [ babble_go_e_sum activ_trace ];
    
    activ_trace = zeros(1,num_iters);
    area_ind = BabbleGoI_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    babble_go_i_sum = [ babble_go_i_sum activ_trace ];
    
    activ_trace = zeros(1,num_iters);
    area_ind = BabbleNoGo_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    babble_nogo_sum = [ babble_nogo_sum activ_trace ];    
    
    area_ind = BabbleInit_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    babble_init_unit = [ babble_init_unit activ_trace ];
    
    area_ind = BabbleExec_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    babble_exec_unit = [ babble_exec_unit activ_trace ];
    
    activ_trace = zeros(1,num_iters);
    area_ind = Babble_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    babble_sum = [ babble_sum activ_trace ];   
    
    activ_trace = zeros(1,num_iters);
    area_ind = Plan_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    plan_sum = [ plan_sum activ_trace ];   
    
    activ_trace = zeros(1,num_iters);
    area_ind = NodReqE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    nod_req_sum = [ nod_req_sum activ_trace ];  
      
    activ_trace = zeros(1,num_iters);
    area_ind = NodGoE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    nod_go_e_sum = [ nod_go_e_sum activ_trace ];  
    
    activ_trace = zeros(1,num_iters);
    area_ind = NodGoI_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    nod_go_i_sum = [ nod_go_i_sum activ_trace ];  
  
    activ_trace = zeros(1,num_iters);
    area_ind = NodNoGo_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    nod_nogo_sum = [ nod_nogo_sum activ_trace ];  
    
    area_ind = NodInit_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    nod_init_unit = [ nod_init_unit activ_trace ];  
     
    activ_trace = zeros(1,num_iters);
    area_ind = ShakeReqE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    shake_req_sum = [ shake_req_sum activ_trace ];  
      
    activ_trace = zeros(1,num_iters);
    area_ind = ShakeGoE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    shake_go_e_sum = [ shake_go_e_sum activ_trace ];  
    
    activ_trace = zeros(1,num_iters);
    area_ind = ShakeGoI_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    shake_go_i_sum = [ shake_go_i_sum activ_trace ];  
  
    activ_trace = zeros(1,num_iters);
    area_ind = ShakeNoGo_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        activ_trace(ii) = sum(sum(activs));
    end;
    shake_nogo_sum = [ shake_nogo_sum activ_trace ];  
    
    area_ind = ShakeInit_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    shake_init_unit = [ shake_init_unit activ_trace ]; 
    
    area_ind = NodShakeConf_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;    
    ns_conflict_unit = [ ns_conflict_unit activ_trace ];   
     
    area_ind = DAEffects_ind;
    new_activs = zeros(6,num_iters);
    for yy_bcr = 1:6
        x_ind = 1;
        y_ind = yy_bcr;
        fetchps_unit_activ_alliters;
        new_activs(yy_bcr,:) = activ_trace;
    end;
    da_effect_units = [ da_effect_units new_activs ];    
end;

% Set the new data to the multi-run compilation.
num_iters = mr_num_iters;
stim_on_sv = mr_stim_on_sv;
stim_x_sv = mr_stim_x_sv;
stim_y_sv = mr_stim_y_sv;
stim_red_sv = mr_stim_red_sv;
stim_green_sv = mr_stim_green_sv;
stim_blue_sv = mr_stim_blue_sv;
tones_on_sv = mr_tones_on_sv(:,2:(num_iters + 1));
reward_on_sv = mr_reward_on_sv;
reward_trigger_sv = mr_reward_trigger_sv;
reward_delivered_sv = mr_reward_delivered_sv;
punish_on_sv = mr_punish_on_sv;
punish_trigger_sv = mr_punish_trigger_sv;
punish_delivered_sv = mr_punish_delivered_sv;
novelty_on_sv = mr_novelty_on_sv;
camera_x_sv = mr_camera_x_sv;
camera_y_sv = mr_camera_y_sv;
mem_color_map_sv = mr_mem_color_map_sv(:,2:(num_iters + 1));
mem_tones_map_sv = mr_mem_tones_map_sv(:,2:(num_iters + 1));
track_execute_sv = mr_track_execute_sv;
nod_execute_sv = mr_nod_execute_sv;
shake_execute_sv = mr_shake_execute_sv;
target_count = mr_target_count;
distractor_count = mr_distractor_count;
delay_count = mr_delay_count;
reward_count = mr_reward_count;
punish_count = mr_punish_count;
target_nod = mr_target_nod;
target_shake = mr_target_shake;
target_x_nod = mr_target_x_nod;
target_nod_shake = mr_target_nod_shake;
target_miss = mr_target_miss;
distractor_nod = mr_distractor_nod;
distractor_shake = mr_distractor_shake;
distractor_x_shake = mr_distractor_x_shake;
distractor_nod_shake = mr_distractor_nod_shake;
distractor_miss = mr_distractor_miss;
delay_nod = mr_delay_nod;
delay_shake = mr_delay_shake;
delay_nod_shake = mr_delay_nod_shake;
blind_nod = mr_blind_nod;
blind_shake = mr_blind_shake;

color_wm_units = color_wm_units(:,2:(num_iters + 1));
tones_wm_units = tones_wm_units(:,2:(num_iters + 1));
da_effect_units = da_effect_units(:,2:(num_iters + 1));

% Set the file name for the compilation.
compilerun_fname = strcat(path_name,'multirun');

% Save the simulation output.
save(compilerun_fname,'num_iters','iter_duration','scene_width', ...
    'scene_height','stim_shape','camera_width','camera_height', ...
    'fovea_width','fovea_height','stim_on_sv','stim_x_sv','stim_y_sv', ...
    'stim_red_sv','stim_green_sv','stim_blue_sv','tones_on_sv', ...
    'reward_on_sv','reward_trigger_sv','reward_delivered_sv', ...
    'punish_on_sv','punish_trigger_sv','punish_delivered_sv', ...    
    'novelty_on_sv', 'brain_type','camera_x_sv','camera_y_sv', ...
    'mem_color_map_sv','mem_tones_map_sv','track_execute_sv', ...
    'nod_execute_sv','shake_execute_sv','target_count', ...
    'distractor_count','delay_count','reward_count','punish_count', ...
    'target_nod','target_shake','target_x_nod','target_nod_shake', ...
    'target_miss','distractor_nod','distractor_shake', ...
    'distractor_x_shake','distractor_nod_shake','distractor_miss', ...
    'delay_nod','delay_shake','delay_nod_shake', ...
    'blind_nod','blind_shake','color_wm_units','tones_wm_units', ...
    'novelty_unit','DA_unit','frust_unit','babble_req_unit', ...
    'babble_go_e_sum','babble_go_i_sum','babble_nogo_sum', ...
    'babble_init_unit','babble_exec_unit','babble_sum','plan_sum', ...
    'nod_req_sum','nod_go_e_sum','nod_go_i_sum','nod_nogo_sum', ...
    'nod_init_unit','shake_req_sum','shake_go_e_sum','shake_go_i_sum', ...
    'shake_nogo_sum','shake_init_unit','ns_conflict_unit', ...
    'da_effect_units');