%
% bsim_copymultiruns.m
%
% Batch simulation script for copying multirun.mat files over from the 
% full data directory so that they are in a directory that is more 
% manageable size-wise.
%
% Last modification: 1/21/08


% Set paths.
runcolls = [ runcoll_stats ];
tasksets = [ taskset_TOBS1c_TOBS1crev ];
simphases = [ simphases_train simphases_maint simphases_rev ];
manip_conds = [ manip_NShypo3 manip_NShypo2 manip_NShypo15 ...
    manip_NShypo1 manip_NShypo05 manip_normal manip_NShyper05 ...
    manip_NShyper1 manip_NShyper3 manip_NShyper5 ...
    manip_Bhypo3 manip_Bhypo2 manip_Bhypo15 ...
    manip_Bhypo1 manip_Bhypo05 manip_Bhyper05 ...
    manip_Bhyper1 manip_Bhyper3 manip_Bhyper5 ...
    manip_PRhypo3 manip_PRhypo2 manip_PRhypo15 ...
    manip_PRhypo1 manip_PRhypo05 manip_PRhyper05 ...
    manip_PRhyper1 manip_PRhyper3 manip_PRhyper5 ...
    manip_ghypo3 manip_ghypo2 manip_ghypo15 ...
    manip_ghypo1 manip_ghypo05 manip_ghyper05 ...
    manip_ghyper1 manip_ghyper3 manip_ghyper5 ];

% Loop over the run collections...
for xx1 = 1:size(runcolls,2)
    runcoll_path = runcolls(xx1);
    
    % Loop over the tasksets...
    for xx2 = 1:size(tasksets,2)
        taskset_path = tasksets(xx2);
        
        % Loop over the simulation phase directories...
        for xx3 = 1:size(simphases,2)
            simphases_path = simphases(xx3);

            % Loop over all of the DA manipulations...
            for xx4 = 1:size(manip_conds,2)
                manip_path = manip_conds(xx4);
                    
                % Change (temporarily) to the source manipulation directory.
                basepath_path = basepath_fulldata;
                subj_num = 1;  % ignored
                run_num = 1;   % ignored
                bsim_setdatapath;
                manip_path_name = strcat(path_pfx1,path_pfx2,path_pfx3, ...
                    path_pfx4,path_pfx5);
                old_dir = pwd;
                cd(manip_path_name);
                
                % Find the range of subject numbers.
                dir_data = dir;
                dir_data_c = struct2cell(dir_data);
                fnames = dir_data_c(1,:)';
                dir_subj_nums = [];
                for xx = 1:size(fnames,1)
                    new_num = sscanf(cell2mat(fnames(xx)),'subj%d');
                    if ~isempty(new_num)
                        dir_subj_nums = [ dir_subj_nums new_num ];
                    end;
                end;
                dir_min_subj = min(dir_subj_nums);
                dir_max_subj = max(dir_subj_nums);

                % Change back to the old directory.
                cd(old_dir);       
                
                % Create the DA condition directory.
                basepath_path = basepath_portdata;
                bsim_setdatapath;
                new_dirname = strcat(path_pfx1,path_pfx2,path_pfx3, ...
                    path_pfx4,path_pfx5);
                mkdir(new_dirname);                
                
                % Subjects range
                first_subj = dir_min_subj;
                last_subj = dir_max_subj;

                % Loop over all of the subjects...
                for xx5 = first_subj:last_subj
                    subj_num = xx5;
                    
                    % Get the source file name.
                    basepath_path = basepath_fulldata;
                    bsim_setdatapath;
                    sfname = strcat(path_name,'multirun.mat');
                    
                    % Get the target file name.
                    basepath_path = basepath_portdata;
                    bsim_setdatapath;
                    tfname = strcat(path_name,'multirun.mat'); 
                    
                    % Create the subject directory
                    mkdir(path_name);
                    
                    % Copy the multirun file.
                    cp_err = copyfile(sfname,tfname);
                    if (cp_err == 0)
                        disp('The subject file doesn''t exist.');
                        disp(sfname);
                    end;
                end; 
            end;
        end;        
    end;
end;