%
% bsim_newtrainsubj.m
%
% Batch simulation place-holder function.
%
% Last modification: 10/28/07


% Load the simulation run parameters.
load sim_run_params;

% Abort if the model is locked (for example a demo model you don't want to
% overwrite).
if (lock_model == 1)
    disp('This model is locked to avoid overwriting it.');
    return;
end;

% Create a new model with the desired physiological and connectivity
% parameters.
phys_initA
modl_initA

%
% Set the special randomized weights.
%

% Get the fascicle indices.
get_cog_model_indices;

% Set the Neural Dice to Nod Go weights.
fasc_ind = TNoisetoNGo_ind;
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);
fanin = 0;
for x_ind = 1:in_x_sz
    for y_ind = 1:in_y_sz
        fetch_cell_wt_inds;
        wt_vals = CW(wt_inds(:,:));
        CW(wt_inds(:,:)) = 0;
        r = rand;
        xr_ind = floor(r * out_x_sz) + 1;
        r = rand;
        yr_ind = floor(r * out_y_sz) + 1;
        CW(wt_inds(xr_ind,yr_ind)) = wt_vals(xr_ind,yr_ind);
    end;
end;

% Set the Neural Dice to Nod NoGo weights.
fasc_ind = TNoisetoNNoGo_ind;
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);
fanin = 0;
for x_ind = 1:in_x_sz
    for y_ind = 1:in_y_sz
        fetch_cell_wt_inds;
        wt_vals = CW(wt_inds(:,:));
        CW(wt_inds(:,:)) = 0;
        r = rand;
        xr_ind = floor(r * out_x_sz) + 1;
        r = rand;
        yr_ind = floor(r * out_y_sz) + 1;
        CW(wt_inds(xr_ind,yr_ind)) = wt_vals(xr_ind,yr_ind);
    end;
end;

% Set the Neural Dice to Shake Go weights.
fasc_ind = TNoisetoSGo_ind;
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);
fanin = 0;
for x_ind = 1:in_x_sz
    for y_ind = 1:in_y_sz
        fetch_cell_wt_inds;
        wt_vals = CW(wt_inds(:,:));
        CW(wt_inds(:,:)) = 0;
        r = rand;
        xr_ind = floor(r * out_x_sz) + 1;
        r = rand;
        yr_ind = floor(r * out_y_sz) + 1;
        CW(wt_inds(xr_ind,yr_ind)) = wt_vals(xr_ind,yr_ind);
    end;
end;

% Set the Neural Dice to Shake NoGo weights.
fasc_ind = TNoisetoSNoGo_ind;
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);
fanin = 0;
for x_ind = 1:in_x_sz
    for y_ind = 1:in_y_sz
        fetch_cell_wt_inds;
        wt_vals = CW(wt_inds(:,:));
        CW(wt_inds(:,:)) = 0;
        r = rand;
        xr_ind = floor(r * out_x_sz) + 1;
        r = rand;
        yr_ind = floor(r * out_y_sz) + 1;
        CW(wt_inds(xr_ind,yr_ind)) = wt_vals(xr_ind,yr_ind);
    end;
end;

% Set the Neural Dice to Babble Go weights.
fasc_ind = TNoisetoBGo_ind;
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);
fanin = 0;
for x_ind = 1:in_x_sz
    for y_ind = 1:in_y_sz
        fetch_cell_wt_inds;
        wt_vals = CW(wt_inds(:,:));
        CW(wt_inds(:,:)) = 0;
        r = rand;
        xr_ind = floor(r * out_x_sz) + 1;
        r = rand;
        yr_ind = floor(r * out_y_sz) + 1;
        CW(wt_inds(xr_ind,yr_ind)) = wt_vals(xr_ind,yr_ind);
    end;
end;

% Set the Neural Dice to Babble NoGo weights.
fasc_ind = TNoisetoBNoGo_ind;
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);
fanin = 0;
for x_ind = 1:in_x_sz
    for y_ind = 1:in_y_sz
        fetch_cell_wt_inds;
        wt_vals = CW(wt_inds(:,:));
        CW(wt_inds(:,:)) = 0;
        r = rand;
        xr_ind = floor(r * out_x_sz) + 1;
        r = rand;
        yr_ind = floor(r * out_y_sz) + 1;
        CW(wt_inds(xr_ind,yr_ind)) = wt_vals(xr_ind,yr_ind);
    end;
end;

% Save the weight changes.
save(start_model_fname,'Model_name','Num_areas','Num_conns','Area_name', ...
    'Area_num','Cell_type','Area_xy','Conn_name','Conn_fromto', ...
    'Chan_type','Conn_kind','Conn_xy','Conn_prob','Weig_mean', ... 
    'Weig_sigm','Conn_scle','CA','CW','CR','CH','CT','NC','NU', ...
    'unit_offset');

% Set path for new subject and make the directory.
bsim_init;
runcoll_path = runcoll_pilot;
taskset_path = taskset_TOBS1c_TOBS1crev;
% taskset_path = taskset_TOBS2c_TOBS2crev;
% simphases_path = simphases_maint;
simphases_path = simphases_train;
manip_path = manip_normal;
subj_num = 10;
run_num = 1;
bsim_setdatapath;

% Copy the right subject model over into the working directory.
sfname = strcat(start_model_fname,'.mat');
tfname = strcat(path_pfx1,path_pfx2,path_pfx3,path_pfx4,'subjs/', ...
    'subj',num2str(subj_num),'_modl.mat');
cp_err = copyfile(sfname,tfname);
if (cp_err == 0)
    disp('The model file doesn''t exist.');
end;