-------------------------------------
 Code Notes for Dissertation (Files)
-------------------------------------

George Chadderdon

Updated: 5/1/07

Version Info
============
The code in this directory is for the set of models being developed for my 
dissertation.  

To a certain extent, this work builds on work previously published in the 
Journal of Cognitive Neuroscience (February of 2006).  

Previous Versions
-----------------

WMPFC Current: The code and data related to the published JCN article.
george_wmpfc.8.21.03: The first-year project version.  Cue and delay units were 
  replaced by superficial and deep layer units.  The delayed match-to-sample 
  (DMS) task was implemented with this model.
george_wmpfc.2.16.03: The first version of the model.  PFC units have Cue, 
  Delay 1, Delay 2, and Response units.


Simulation Scripts
==================

Note: X's won't necessarily match in previous version directories!

PISHTAR simulation execution scripts

run_pantilt_sim.m: load the PISHTAR and brain network and run a simulation 
     on it.
init_PISHTAR_types.m: Load the variables which are used like enumerated 
     types in PISHTAR.
init_simrun.m: called by run_pantilt_sim.  This initializes the simulation.
blue_select_simrun.m: called by run_pantilt_sim and used to make the 
     environment reinforce Nod in response to blue stimuli, and Shake in 
     response to everything else.
red_select_simrun.m: called by run_pantilt_sim and used to make the 
     environment reinforce Nod in response to red stimuli, and Shake in 
     response to everything else.
combo_taskset_simrun.m: called by run_pantilt_sim and used to make the 
     environment reinforcement Nod and Shake according to either a Blue- or 
     Red-Select task, in the context of a C or Eb tone, respectively.
rule_based_brain.m: called by run_pantilt_sim.m and used to run a rule-
     based brain in the simulation environment.
init_cog_model_brain.m: called by run_pantilt_sim.m and used to initialize 
     the actual neural cognitive model brain.
get_cog_model_indices.m: called by init_cog_model_brain.m (and also 
     load_pantilt_sim.m). This reads indices for model areas and specific 
     units so that these can be accessed more easily by the code.
cog_model_brain.m: called by run_pantilt_sim.m and used to run the actual 
     neural cognitive model brain in the simulation environment.

Other simulation scripts

sim_run.m: run a simulation according to the current params setting in 
     set_simulation_params.m.
DA_critic_sim: Run a simulation of the adaptive critic.
test_sim.m: Run a simulation of a test model.
layer_sim.m: Run a simulation for a layer of units.
stim_make.m: used to make an arbitrary-shaped stimuli using the mouse to 
     select and deselect pixels.

Model preparation scripts

phys_initX.m: load physiological parameters for each cell and channel type 
    from a .dat file and write the results to a .mat file.
    (latest version: X = A -- 10/15/04)
modl_initX.m: load model definition from a .dat filie and construct the 
    network, writing the results to a .mat file. 
    (latest version: X = A -- 10/15/04)
set_simulation_params.m: set up what simulation model and scripts should 
    be run.  This should be run before fresh_model_run.m or the other model 
    simulation scripts.
fresh_model_run.m: generate a new model and run a simulation on it.

Model display scripts

disp_area_act.m: display activation of area _area_ind_.  Can be used during 
     simulation.
disp_area_act_ps.m: display activation of area _area_ind_ at time step
     _time_ind_.  Uses _output_.  Use after a simulation run.
disp_cell_wts.m: display connection weights in fascicle _fasc_ind_ to (from)
     the output (input) unit (_x_ind_, _y_ind_).
netconn_disp_tool.m: GUI caller for inspecting a network.  Use after a 
     simulation run.
ncdt_init.m: Initializes the netconn_disp_tool data structures.
ncdt_calls.m: Called by netconn_disp_tool.m.
show_trial.m: Play through a trial
load_pantilt_sim.m: Load PISHTAR simulation information for already-run 
     simulation.
make_disp_fig.m: Creates the figure for displaying the network activity 
     both during and after simulations.
disp_trial_step.m: Show trial _iter_ from saved simulation.  The
     load_pantilt_sim.m script needs to be run first.
disp_learning_events.m: Show instances of learning that happened in the 
     simulation.
plot_activs.m: plot activity of individual units and/or summation of area 
     activities.
plot_wt_learning.m: plot activity related to learning of a particular 
     weight.

Old scripts for dissecting

runtrialsimC.m: an old simulation loop script.  Has useful code for 
     dopamine level maintenance.
runsim5.m: an old simulation script which has useful code for learning 
     algorithms.
net_disp_tool.m: the old GUI caller for inspecting a network.  Use after a 
     simulation run.  Made obsolete by netconn_disp_tool.m.    
ndt_subl.m: called by net_disp_tool.m.
     
Stuff from previous version directories that might be useful later
    
make_trial_movie.m: play through a single PFC trial from the batch saving an 
     movie file of the run.
show_trial_tool.m: GUI caller for displaying trial steps.


Other Scripts
============= 

tokenize.m: breaks a long string into tokens.  Useful for file input.
readparam.m: function for reading $ parameters from an input line.

fetch_area_act.m: get activation of area _area_ind_.  Can be used during 
     simulation.
fetch_area_act_ps.m: get activation of area _area_ind_ at time step
     _time_ind_.  Uses _output_.  Use after a simulation run.    
    
getkeywait.m: a script (downloaded from a Web-site) that polls for and 
     reads in a keypress or mouse-click.
     
sigm.m: function for a regular "squashing" sigmoid.
invsigm.m: function for an inverse of the above sigmoid.
sigm_tune.m: allows (through a GUI) tuning and viewing effects of sigmoid 
     parameters (latest update 10/5/06).
sigm_tune_calls.m: called by sigm_tune.m.   

lesion_wts.m: zeroes out weights from a particular connection fascicle.
     
wcunitupdate.m: Function that implements standard sigmoidal units. 
     
wcnullclines_tool.m: GUI caller for displaying nullclines of W/C units at 
     different parameter settings.
wcnullclines.m: plots nullclines of Wilson/Cowan unit.

Stuff from previous version directories that might be useful later

show_trial_calls.m: called by show_trial_tool.m.
matrot.m: rotate/shifts a matrix.  Used to shift image stimuli.
wcunittest.m: tests dynamics of single Wilson/Cowan unit.
draw_Fpast.m: draws "saxophone" learning function.
blkavg.m: down-sample averages matrix in blocks.
    

Other Files in the Directory
============================

phys_parm_X.dat: parameter files for physiological parameters. 
     X = 1  dissertation model parameters
     X = old  JCN model parameters
     X = 11.18.06
model_X_dat: parameters files for model architectures. 
     X = 1  dissertation model 
     X = old  JCN model
     X = 11.18.06
     X = 1b
     
square_stim.mat: a 16x16 square stimulus shape.
phys_parm_X.mat: saved physiological parameters.
     X = 1 is the typical saved physiological parameters   
modl_parm_X.mat: saved model parameters.
     X = 1 is the typical saved model
     X = tr is for a saved trained model
sim_outX.mat: saved simulation information
     X = 1 is the usual
cog_outX.mat: saved output neural unit activations 
     X = 1 is the usual
     
netconn_disp_tool.fig: GUI figure for netconn_disp_tool.m.
sigm_tune.fig: GUI figure for sigm_tune.m.
wcnullclines_tool.fig: GUI figure for wcnullclines.m.

code_notes_files.m: documentation for files related to dissertation.
code_notes_params.m: documentation of persistent variables used by model.

Old files to be cannibalized

net_disp_tool.fig: GUI figure for net_disp_tool.m.

Stuff from previous version directories that might be useful later

show_trial_tool.fig: GUI figure for show_trial_tool.m.