%
% collect_RT.m
%
% Collect RT information from the current run.
%
% Last modification: 9/18/07


% Clear all variables and close all windows.
% clear all;
% close all;

vis_stim_duration = 3000;     % visual stimulus duration (in ms)
delay_duration = 2500;        % delay period duration (in ms)

stim_onsets = [];
nod_onsets = [];
shake_onsets = [];
reward_onsets = [];
for xx = 2:num_iters
    if ((stim_on_sv(xx - 1) == 0) && (stim_on_sv(xx)))
        stim_onsets = [ stim_onsets xx ];
    end;
    
    if ((nod_execute_sv(xx - 1) == 0) && (nod_execute_sv(xx)))
        nod_onsets = [ nod_onsets xx ];
    end;
    
    if ((shake_execute_sv(xx - 1) == 0) && (shake_execute_sv(xx)))
        shake_onsets = [ shake_onsets xx ];
    end;    
    
    if ((reward_on_sv(xx - 1) == 0) && (reward_on_sv(xx)))
        reward_onsets = [ reward_onsets xx ];
    end;        
end;

% Find the RTs.
resp_onsets = [];
resp_RTs = [];
for xx = 1:size(stim_onsets,2)
    stim_onset = stim_onsets(xx);
    nods_in_range = find((nod_onsets > stim_onset) & ...
        (nod_onsets < (stim_onset + ...
        (vis_stim_duration + delay_duration) / iter_duration)));
    shakes_in_range = find((shake_onsets > stim_onset) & ...
        (shake_onsets < (stim_onset + ...
        (vis_stim_duration + delay_duration) / iter_duration))); 
    resps_in_range = sort([nod_onsets(nods_in_range) ...
        shake_onsets(shakes_in_range)]);
    if (size(resps_in_range,2) > 0)
        resp_onset = resps_in_range(1);
        resp_onsets = [resp_onsets resp_onset];
        resp_RTs = [resp_RTs ((resp_onset - stim_onset) * iter_duration)];
    end;
end;

% Find the delay from each reward to the next response.
rew_to_next_resp = zeros(1,size(reward_onsets,2));
for xx = 1:size(reward_onsets,2)
    next_rews = find(resp_onsets > reward_onsets(xx));
    if (size(next_rews,2) > 0)
        rew_to_next_resp(xx) = (resp_onsets(next_rews(1)) - ...
            reward_onsets(xx)) * iter_duration; 
    end;
end;

% stim_onsets
% nod_onsets
% shake_onsets
resp_onsets
resp_RTs
reward_onsets
rew_to_next_resp