%
% collect_perf_data.m
%
% Collect performance data information from the current run.
%
% Last modification: 12/15/07


% Clear all variables and close all windows.
% clear all;
% close all;

vis_stim_duration = 3000;     % visual stimulus duration (in ms)
delay_duration = 2500;        % delay period duration (in ms)

stim_onsets = [];
stim_offsets = [];
tone_onsets = [];
nod_onsets = [];
shake_onsets = [];
reward_onsets = [];
punish_onsets = [];
if (sum(tones_on_sv(:,1)) > 0)
    tone_onsets = 1;
end;
for xx = 2:num_iters
    if ((stim_on_sv(xx - 1) == 0) && (stim_on_sv(xx)))
        stim_onsets = [ stim_onsets xx ];
    end;
    
    if ((stim_on_sv(xx - 1) == 1) && (stim_on_sv(xx) == 0))
        stim_offsets = [ stim_offsets xx ];
    end;
    
    if ((sum(tones_on_sv(:,(xx - 1))) == 0) && ...
        (sum(tones_on_sv(:,(xx))) > 0))
        tone_onsets = [ tone_onsets xx ];
    end;
    
    if ((nod_execute_sv(xx - 1) == 0) && (nod_execute_sv(xx)))
        nod_onsets = [ nod_onsets xx ];
    end;
    
    if ((shake_execute_sv(xx - 1) == 0) && (shake_execute_sv(xx)))
        shake_onsets = [ shake_onsets xx ];
    end;    
    
    if ((reward_on_sv(xx - 1) == 0) && (reward_on_sv(xx)))
        reward_onsets = [ reward_onsets xx ];
    end;        
    
    if ((punish_on_sv(xx - 1) == 0) && (punish_on_sv(xx)))
        punish_onsets = [ punish_onsets xx ];
    end;           
end;

% Find the RTs.
resp_onsets = [];
resp_RTs = [];
for xx = 1:size(stim_onsets,2)
    stim_onset = stim_onsets(xx);
    nods_in_range = find((nod_onsets > stim_onset) & ...
        (nod_onsets < (stim_onset + ...
        (vis_stim_duration + delay_duration) / iter_duration)));
    shakes_in_range = find((shake_onsets > stim_onset) & ...
        (shake_onsets < (stim_onset + ...
        (vis_stim_duration + delay_duration) / iter_duration))); 
    resps_in_range = sort([nod_onsets(nods_in_range) ...
        shake_onsets(shakes_in_range)]);
    if (size(resps_in_range,2) > 0)
        resp_onset = resps_in_range(1);
        resp_onsets = [resp_onsets resp_onset];
        resp_RTs = [resp_RTs ((resp_onset - stim_onset) * iter_duration)];
    end;
end;

% Get trial data.
num_trials = size(stim_onsets,2);
trial_starts = stim_onsets;
trial_ends = trial_starts + (vis_stim_duration + delay_duration) / ...
    iter_duration;
trial_stimoffs = zeros(1,num_trials);
for xx = 1:num_trials
    for yy = 1:size(stim_offsets,2)
        if ((stim_offsets(yy) > trial_starts(xx)) && ...
                (stim_offsets(yy) < trial_ends(xx)))
            trial_stimoffs(xx) = stim_offsets(yy);
        end;
    end;
end;
last_nontest_iter = num_iters - 1000;
test_trials = find(trial_starts > last_nontest_iter);
num_nontest_trials = test_trials(1) - 1;
last_calc_trial = num_nontest_trials;
% last_calc_trial = num_trials;

% Get the mean RT, counting only the appropriate trials.
mean_RT = mean(resp_RTs(find(resp_onsets <= last_nontest_iter)));

% Find the delay from each reward to the next response.
rew_to_next_resp = zeros(1,size(reward_onsets,2));
for xx = 1:size(reward_onsets,2)
    next_rews = find(resp_onsets > reward_onsets(xx));
    if ((size(next_rews,2) > 0) && ...
            (resp_onsets(next_rews(1)) <= last_nontest_iter))
        rew_to_next_resp(xx) = (resp_onsets(next_rews(1)) - ...
            reward_onsets(xx)) * iter_duration; 
    end;
end;

% Get the mean reward-to-next-behavior interval.
mean_rew_to_next_resp = 0;
if (size(rew_to_next_resp,2) > 0)
    nonzero_data = find(rew_to_next_resp > 0);
    if (size(nonzero_data,2) > 0)
        mean_rew_to_next_resp = mean(rew_to_next_resp(nonzero_data));
    end;
end;

% Get trial colors.
trial_colors = zeros(3,num_trials);
for xx = 1:num_trials
    trial_colors(1,xx) = stim_red_sv(trial_starts(xx));
    trial_colors(2,xx) = stim_green_sv(trial_starts(xx));
    trial_colors(3,xx) = stim_blue_sv(trial_starts(xx));
end;

% Get trial tones.
trial_tones = zeros(12,num_trials);
for xx = 1:size(tone_onsets,2)
    tone_iter = tone_onsets(xx);
    the_tone = tones_on_sv(:,tone_iter);   
    for yy = 1:num_trials
        if (tone_iter < trial_starts(yy))
            trial_tones(:,yy) = the_tone;
        end;
    end;
end;

% Get count of trial nods.
trial_nod_counts = zeros(1,num_trials);
for xx = 1:size(nod_onsets,2)
    nod_iter = nod_onsets(xx);
    for yy = 1:num_trials
        if ((nod_iter >= trial_starts(yy)) && (nod_iter <= trial_ends(yy)))
            trial_nod_counts(yy) = trial_nod_counts(yy) + 1;
        end;
    end;    
end;

% Get count of trial shakes.
trial_shake_counts = zeros(1,num_trials);
for xx = 1:size(shake_onsets,2)
    shake_iter = shake_onsets(xx);
    for yy = 1:num_trials
        if ((shake_iter >= trial_starts(yy)) && (shake_iter <= trial_ends(yy)))
            trial_shake_counts(yy) = trial_shake_counts(yy) + 1;
        end;
    end;    
end;

% Get count of trial rewards.
trial_reward_counts = zeros(1,num_trials);
for xx = 1:size(reward_onsets,2)
    reward_iter = reward_onsets(xx);
    for yy = 1:num_trials
        if ((reward_iter >= trial_starts(yy)) && ...
                (reward_iter <= trial_ends(yy)))
            trial_reward_counts(yy) = trial_reward_counts(yy) + 1;
        end;
    end;    
end;

% Get count of trial punishers.
trial_punish_counts = zeros(1,num_trials);
for xx = 1:size(punish_onsets,2)
    punish_iter = punish_onsets(xx);
    for yy = 1:num_trials
        if ((punish_iter >= trial_starts(yy)) && ...
                (punish_iter <= trial_ends(yy)))
            trial_punish_counts(yy) = trial_punish_counts(yy) + 1;
        end;
    end;    
end;

% Tabulate trials correct information.
trials_correct = zeros(1,num_trials);
for xx = 1:size(target_nod,2)
    nod_iter = target_nod(xx);
    for yy = 1:num_trials
        if ((nod_iter >= trial_starts(yy)) && (nod_iter <= trial_ends(yy)))
            trials_correct(yy) = 1;
        end;
    end;
end;
for xx = 1:size(distractor_shake,2)
    shake_iter = distractor_shake(xx);
    for yy = 1:num_trials
        if ((shake_iter >= trial_starts(yy)) && (shake_iter <= trial_ends(yy)))
            trials_correct(yy) = 1;
        end;
    end;
end;
trial_win3_accur = zeros(1,num_trials - 2);
for xx = 1:(num_trials - 2)
    trial_win3_accur(xx) = (trials_correct(xx) + ...
        trials_correct(xx + 1) + trials_correct(xx + 2)) / 3.0;
end;
trial_win5_accur = zeros(1,num_trials - 4);
for xx = 1:(num_trials - 4)
    trial_win5_accur(xx) = (trials_correct(xx) + ...
        trials_correct(xx + 1) + trials_correct(xx + 2) + ...
        trials_correct(xx + 3) + trials_correct(xx + 4)) / 5.0;
end;
trial_win7_accur = zeros(1,num_trials - 6);
for xx = 1:(num_trials - 6)
    trial_win7_accur(xx) = (trials_correct(xx) + ...
        trials_correct(xx + 1) + trials_correct(xx + 2) + ...
        trials_correct(xx + 3) + trials_correct(xx + 4) + ...
        trials_correct(xx + 5) + trials_correct(xx + 6)) / 7.0;
end;
trial_win13_accur = zeros(1,num_trials - 12);
for xx = 1:(num_trials - 12)
    trial_win13_accur(xx) = (trials_correct(xx) + ...
        trials_correct(xx + 1) + trials_correct(xx + 2) + ...
        trials_correct(xx + 3) + trials_correct(xx + 4) + ...
        trials_correct(xx + 5) + trials_correct(xx + 6) + ...
        trials_correct(xx + 7) + trials_correct(xx + 8) + ...
        trials_correct(xx + 9) + trials_correct(xx + 10) + ...
        trials_correct(xx + 11) + trials_correct(xx + 12)) / 13.0;
end;
pct_correct = 100 * sum(trials_correct(1:last_calc_trial)) / ...
    last_calc_trial;

% Tabulate trials incorrect information.
trials_incorrect = zeros(1,num_trials);
for xx = 1:size(target_shake,2)
    shake_iter = target_shake(xx);
    for yy = 1:num_trials
        if ((shake_iter >= trial_starts(yy)) && (shake_iter <= trial_ends(yy)))
            trials_incorrect(yy) = 1;
        end;
    end;
end;
for xx = 1:size(distractor_nod,2)
    nod_iter = distractor_nod(xx);
    for yy = 1:num_trials
        if ((nod_iter >= trial_starts(yy)) && (nod_iter <= trial_ends(yy)))
            trials_incorrect(yy) = 1;
        end;
    end;
end;
trial_win13_incorr = zeros(1,num_trials - 12);
for xx = 1:(num_trials - 12)
    trial_win13_incorr(xx) = (trials_incorrect(xx) + ...
        trials_incorrect(xx + 1) + trials_incorrect(xx + 2) + ...
        trials_incorrect(xx + 3) + trials_incorrect(xx + 4) + ...
        trials_incorrect(xx + 5) + trials_incorrect(xx + 6) + ...
        trials_incorrect(xx + 7) + trials_incorrect(xx + 8) + ...
        trials_incorrect(xx + 9) + trials_incorrect(xx + 10) + ...
        trials_incorrect(xx + 11) + trials_incorrect(xx + 12)) / 13.0;
end;
pct_incorrect = 100 * sum(trials_incorrect(1:last_calc_trial)) / ...
    last_calc_trial;

% Tabulate trials missed information.
trials_missed = zeros(1,num_trials);
for xx = 1:size(target_miss,2)
    miss_iter = target_miss(xx);   
    for yy = 1:num_trials
        if ((miss_iter >= trial_starts(yy)) && (miss_iter <= trial_ends(yy)))
            trials_missed(yy) = 1;
        end;
    end;
end;
for xx = 1:size(distractor_miss,2)
    miss_iter = distractor_miss(xx);
    for yy = 1:num_trials
        if ((miss_iter >= trial_starts(yy)) && (miss_iter <= trial_ends(yy)))
            trials_missed(yy) = 1;
        end;
    end;
end;
trial_win13_missed = zeros(1,num_trials - 12);
for xx = 1:(num_trials - 12)
    trial_win13_missed(xx) = (trials_missed(xx) + ...
        trials_missed(xx + 1) + trials_missed(xx + 2) + ...
        trials_missed(xx + 3) + trials_missed(xx + 4) + ...
        trials_missed(xx + 5) + trials_missed(xx + 6) + ...
        trials_missed(xx + 7) + trials_missed(xx + 8) + ...
        trials_missed(xx + 9) + trials_missed(xx + 10) + ...
        trials_missed(xx + 11) + trials_missed(xx + 12)) / 13.0;
end;
pct_missed = 100 * sum(trials_missed(1:last_calc_trial)) / ...
    last_calc_trial;

% Tabulate conflict trials information.  A conflict trial is one in which
% both a nod and shake happen during the same trial, either concurrently or
% consecutively.  Note that the system may actually be rewarded during a
% conflict trial, so long as the correct behavior doesn't overlap in time
% with the incorrect one.
trials_conflict = zeros(1,num_trials);
for xx = 1:num_trials
    if ((trial_nod_counts(xx) > 0) && (trial_shake_counts(xx) > 0))
        trials_conflict(xx) = 1;
    end;
end;
trial_win13_conflict = zeros(1,num_trials - 12);
for xx = 1:(num_trials - 12)
    trial_win13_conflict(xx) = (trials_conflict(xx) + ...
        trials_conflict(xx + 1) + trials_conflict(xx + 2) + ...
        trials_conflict(xx + 3) + trials_conflict(xx + 4) + ...
        trials_conflict(xx + 5) + trials_conflict(xx + 6) + ...
        trials_conflict(xx + 7) + trials_conflict(xx + 8) + ...
        trials_conflict(xx + 9) + trials_conflict(xx + 10) + ...
        trials_conflict(xx + 11) + trials_conflict(xx + 12)) / 13.0;
end;
pct_conflict = 100 * sum(trials_conflict(1:last_calc_trial)) / ...
    last_calc_trial;

% Tabulate extra response trials information.  These are correct trials
% which, however, have extra responses in them.
trials_extra_resp = zeros(1,num_trials);
for xx = 1:num_trials
    if ((trials_correct(xx) == 1) && ((trial_nod_counts(xx) > 1) || ...
            (trial_shake_counts(xx) > 1)))    
        trials_extra_resp(xx) = 1;
    end;
end;
trial_win13_extra_resp = zeros(1,num_trials - 12);
for xx = 1:(num_trials - 12)
    trial_win13_extra_resp(xx) = (trials_extra_resp(xx) + ...
        trials_extra_resp(xx + 1) + trials_extra_resp(xx + 2) + ...
        trials_extra_resp(xx + 3) + trials_extra_resp(xx + 4) + ...
        trials_extra_resp(xx + 5) + trials_extra_resp(xx + 6) + ...
        trials_extra_resp(xx + 7) + trials_extra_resp(xx + 8) + ...
        trials_extra_resp(xx + 9) + trials_extra_resp(xx + 10) + ...
        trials_extra_resp(xx + 11) + trials_extra_resp(xx + 12)) / 13.0;
end;
pct_extra_resp = 100 * sum(trials_extra_resp(1:last_calc_trial)) / ...
    last_calc_trial;

% Tabulate late trials information.  A late trial is a delay response
% (correct or incorrect) that falls within the trial period.  Extra
% responses, however, are discounted from this.
trials_late = zeros(1,num_trials);
for xx = 1:size(delay_nod,2)
    dresp_iter = delay_nod(xx);
    for yy = 1:num_trials
        if ((dresp_iter >= trial_starts(yy)) && ...
                (dresp_iter <= trial_ends(yy)) && ...
                (trials_conflict(yy) == 0) && ...
                (trials_extra_resp(yy) == 0))
            trials_late(yy) = 1;
        end;
    end;    
end;
for xx = 1:size(delay_shake,2)
    dresp_iter = delay_shake(xx);
    for yy = 1:num_trials
        if ((dresp_iter >= trial_starts(yy)) && ...
                (dresp_iter <= trial_ends(yy)) && ...
                (trials_conflict(yy) == 0) && ...
                (trials_extra_resp(yy) == 0))
            trials_late(yy) = 1;
        end;
    end;    
end;   
for xx = 1:size(delay_nod_shake,2)
    dresp_iter = delay_nod_shake(xx);
    for yy = 1:num_trials
        if ((dresp_iter >= trial_starts(yy)) && ...
                (dresp_iter <= trial_ends(yy)) && ...
                (trials_conflict(yy) == 0) && ...
                (trials_extra_resp(yy) == 0))
            trials_late(yy) = 1;
        end;
    end;    
end;  
trial_win13_late = zeros(1,num_trials - 12);
for xx = 1:(num_trials - 12)
    trial_win13_late(xx) = (trials_late(xx) + ...
        trials_late(xx + 1) + trials_late(xx + 2) + ...
        trials_late(xx + 3) + trials_late(xx + 4) + ...
        trials_late(xx + 5) + trials_late(xx + 6) + ...
        trials_late(xx + 7) + trials_late(xx + 8) + ...
        trials_late(xx + 9) + trials_late(xx + 10) + ...
        trials_late(xx + 11) + trials_late(xx + 12)) / 13.0;
end;
pct_late = 100 * sum(trials_late(1:last_calc_trial)) / last_calc_trial;

% Calculate a measure of trials required to learn conjunction.
learn_trials3est = 0;
for xx = 1:size(trial_win3_accur,2)
    if (trial_win3_accur(xx) > 0.67)
        learn_trials3est = xx;
        break;
    end;
end;
learn_trials5est = 0;
for xx = 1:size(trial_win5_accur,2)
    if (trial_win5_accur(xx) > 0.40)
        learn_trials5est = xx + 1;
        break;
    end;
end;
learn_trials7est = 0;
for xx = 1:size(trial_win7_accur,2)
    if (trial_win7_accur(xx) > 0.29)
        learn_trials7est = xx + 2;
        break;
    end;   
end;
learn_trials13est = 0;
for xx = 1:size(trial_win13_accur,2)
    if (trial_win13_accur(xx) > 0.16)
        learn_trials13est = xx + 2;
        break;
    end;   
end;

% Try the 3-window estimate, then the 5-win, 7-win, and 13-win estimates if
% earlier estimates do not find a start where the conjunction seems to be
% learned.  Note, that this is really only valid for the 1-conjunction
% multirun cases.
learn_trials = learn_trials3est;
if (learn_trials == 0)
    learn_trials = learn_trials5est;
end;
if (learn_trials == 0)
    learn_trials = learn_trials7est;
end;
if (learn_trials == 0)
    learn_trials = learn_trials13est;
end;

% Flag whether the subject gave a wrong response first.
wrong_guess_first = 0;
wrong_trials = find(trials_incorrect ~= 0);
right_trials = find(trials_correct ~= 0);
if ((~isempty(wrong_trials)) && (~isempty(right_trials)))
    if (wrong_trials(1) < right_trials(1))
        wrong_guess_first = 1;
    end;
end;

% conj_learned = 0;
% if (learn_trials > 0)
%     pct_trained_correct = ...
%         100 * sum(trials_correct((learn_trials + 1):num_trials)) / ...
%         (num_trials - (learn_trials + 1) + 1);
%     if (pct_trained_correct > 16)
%         conj_learned = 1;
%     end;
% end;

% Use the last 13 iterations as a measure of learned accuracy (likely
% across all conjunctions).
all_conj_end_accur = 100 * trial_win13_accur(size(trial_win13_accur,2));

% Calculate the last 13 iteration measure of various things (probably over
% the test run...)
last13pct_corr = 100 * trial_win13_accur(size(trial_win13_accur,2));
last13pct_incorr = 100 * trial_win13_incorr(size(trial_win13_incorr,2));
last13pct_missed = 100 * trial_win13_missed(size(trial_win13_missed,2));
last13pct_conflict = 100 * trial_win13_conflict(size(trial_win13_conflict,2));
last13pct_extra_resp = 100 * ...
    trial_win13_extra_resp(size(trial_win13_extra_resp,2));
last13pct_late = 100 * trial_win13_late(size(trial_win13_late,2));

if (all_conj_end_accur > 25)
    conj_learned = 1;
else
    conj_learned = 0;
end;

% Find the average summed color working memory unit activation during each 
% trial over the whole trial period.
ave_tr_color_wm_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_color_wm_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_color_wm_sum(xx) = ave_tr_color_wm_sum(xx) + ...
            sum(color_wm_units(:,yy));
    end;
    ave_tr_color_wm_sum(xx) = ave_tr_color_wm_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average summed color working memory unit activation during each 
% trial over the stimulus portion of the trial period.
ave_tr_stim_color_wm_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_color_wm_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_color_wm_sum(xx) = ave_tr_stim_color_wm_sum(xx) + ...
            sum(color_wm_units(:,yy));
    end;
    ave_tr_stim_color_wm_sum(xx) = ave_tr_stim_color_wm_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average summed color working memory unit activation during each 
% trial over the delay portion of the trial period.
ave_tr_del_color_wm_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_color_wm_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_color_wm_sum(xx) = ave_tr_del_color_wm_sum(xx) + ...
            sum(color_wm_units(:,yy));
    end;
    ave_tr_del_color_wm_sum(xx) = ave_tr_del_color_wm_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average summed tone working memory unit activation during each 
% trial over the whole trial period.
ave_tr_tone_wm_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_tone_wm_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_tone_wm_sum(xx) = ave_tr_tone_wm_sum(xx) + ...
            sum(tones_wm_units(:,yy));
    end;
    ave_tr_tone_wm_sum(xx) = ave_tr_tone_wm_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average summed tone working memory unit activation during each 
% trial over the stimulus portion of the trial period.
ave_tr_stim_tone_wm_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_tone_wm_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_tone_wm_sum(xx) = ave_tr_stim_tone_wm_sum(xx) + ...
            sum(tones_wm_units(:,yy));
    end;
    ave_tr_stim_tone_wm_sum(xx) = ave_tr_stim_tone_wm_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average summed tone working memory unit activation during each 
% trial over the delay portion of the trial period.
ave_tr_del_tone_wm_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_tone_wm_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_tone_wm_sum(xx) = ave_tr_del_tone_wm_sum(xx) + ...
            sum(tones_wm_units(:,yy));
    end;
    ave_tr_del_tone_wm_sum(xx) = ave_tr_del_tone_wm_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average novelty unit activation during each trial over the whole
% trial period.
ave_tr_novelty = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_novelty(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_novelty(xx) = ave_tr_novelty(xx) + novelty_unit(yy);
    end;
    ave_tr_novelty(xx) = ave_tr_novelty(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average novelty unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_novelty = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_novelty(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_novelty(xx) = ave_tr_stim_novelty(xx) + novelty_unit(yy);
    end;
    ave_tr_stim_novelty(xx) = ave_tr_stim_novelty(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average novelty unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_novelty = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_novelty(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_novelty(xx) = ave_tr_del_novelty(xx) + novelty_unit(yy);
    end;
    ave_tr_del_novelty(xx) = ave_tr_del_novelty(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average DA unit activation during each trial over the whole
% trial period.
ave_tr_DA = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_DA(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_DA(xx) = ave_tr_DA(xx) + DA_unit(yy);
    end;
    ave_tr_DA(xx) = ave_tr_DA(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average DA unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_DA = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_DA(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_DA(xx) = ave_tr_stim_DA(xx) + DA_unit(yy);
    end;
    ave_tr_stim_DA(xx) = ave_tr_stim_DA(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average DA unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_DA = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_DA(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_DA(xx) = ave_tr_del_DA(xx) + DA_unit(yy);
    end;
    ave_tr_del_DA(xx) = ave_tr_del_DA(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average frustration unit activation during each trial over the 
% whole trial period.
ave_tr_frust = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_frust(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_frust(xx) = ave_tr_frust(xx) + frust_unit(yy);
    end;
    ave_tr_frust(xx) = ave_tr_frust(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average frustration unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_frust = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_frust(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_frust(xx) = ave_tr_stim_frust(xx) + frust_unit(yy);
    end;
    ave_tr_stim_frust(xx) = ave_tr_stim_frust(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average frustration unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_frust = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_frust(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_frust(xx) = ave_tr_del_frust(xx) + frust_unit(yy);
    end;
    ave_tr_del_frust(xx) = ave_tr_del_frust(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Babble Request unit activation during each trial over the 
% whole trial period.
ave_tr_babble_req = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_babble_req(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_babble_req(xx) = ave_tr_babble_req(xx) + ...
            babble_req_unit(yy);
    end;
    ave_tr_babble_req(xx) = ave_tr_babble_req(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble Request unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_babble_req = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_babble_req(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_babble_req(xx) = ave_tr_stim_babble_req(xx) + ...
            babble_req_unit(yy);
    end;
    ave_tr_stim_babble_req(xx) = ave_tr_stim_babble_req(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble Request unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_babble_req = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_babble_req(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_babble_req(xx) = ave_tr_del_babble_req(xx) + ...
            babble_req_unit(yy);
    end;
    ave_tr_del_babble_req(xx) = ave_tr_del_babble_req(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Babble GoE sum activation during each trial over the 
% whole trial period.
ave_tr_babble_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_babble_go_e_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_babble_go_e_sum(xx) = ave_tr_babble_go_e_sum(xx) + ...
            babble_go_e_sum(yy);
    end;
    ave_tr_babble_go_e_sum(xx) = ave_tr_babble_go_e_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble GoE sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_babble_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_babble_go_e_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_babble_go_e_sum(xx) = ave_tr_stim_babble_go_e_sum(xx) + ...
            babble_go_e_sum(yy);
    end;
    ave_tr_stim_babble_go_e_sum(xx) = ave_tr_stim_babble_go_e_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble GoE sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_babble_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_babble_go_e_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_babble_go_e_sum(xx) = ave_tr_del_babble_go_e_sum(xx) + ...
            babble_go_e_sum(yy);
    end;
    ave_tr_del_babble_go_e_sum(xx) = ave_tr_del_babble_go_e_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Babble GoI sum activation during each trial over the 
% whole trial period.
ave_tr_babble_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_babble_go_i_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_babble_go_i_sum(xx) = ave_tr_babble_go_i_sum(xx) + ...
            babble_go_i_sum(yy);
    end;
    ave_tr_babble_go_i_sum(xx) = ave_tr_babble_go_i_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble GoI sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_babble_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_babble_go_i_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_babble_go_i_sum(xx) = ave_tr_stim_babble_go_i_sum(xx) + ...
            babble_go_i_sum(yy);
    end;
    ave_tr_stim_babble_go_i_sum(xx) = ave_tr_stim_babble_go_i_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble GoI sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_babble_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_babble_go_i_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_babble_go_i_sum(xx) = ave_tr_del_babble_go_i_sum(xx) + ...
            babble_go_i_sum(yy);
    end;
    ave_tr_del_babble_go_i_sum(xx) = ave_tr_del_babble_go_i_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Babble NoGo sum activation during each trial over the 
% whole trial period.
ave_tr_babble_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_babble_nogo_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_babble_nogo_sum(xx) = ave_tr_babble_nogo_sum(xx) + ...
            babble_nogo_sum(yy);
    end;
    ave_tr_babble_nogo_sum(xx) = ave_tr_babble_nogo_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble NoGo sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_babble_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_babble_nogo_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_babble_nogo_sum(xx) = ave_tr_stim_babble_nogo_sum(xx) + ...
            babble_nogo_sum(yy);
    end;
    ave_tr_stim_babble_nogo_sum(xx) = ave_tr_stim_babble_nogo_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble NoGo sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_babble_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_babble_nogo_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_babble_nogo_sum(xx) = ave_tr_del_babble_nogo_sum(xx) + ...
            babble_nogo_sum(yy);
    end;
    ave_tr_del_babble_nogo_sum(xx) = ave_tr_del_babble_nogo_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Babble Init unit activation during each trial over the 
% whole trial period.
ave_tr_babble_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_babble_init(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_babble_init(xx) = ave_tr_babble_init(xx) + ...
            babble_init_unit(yy);
    end;
    ave_tr_babble_init(xx) = ave_tr_babble_init(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble Init unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_babble_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_babble_init(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_babble_init(xx) = ave_tr_stim_babble_init(xx) + ...
            babble_init_unit(yy);
    end;
    ave_tr_stim_babble_init(xx) = ave_tr_stim_babble_init(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble Init unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_babble_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_babble_init(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_babble_init(xx) = ave_tr_del_babble_init(xx) + ...
            babble_init_unit(yy);
    end;
    ave_tr_del_babble_init(xx) = ave_tr_del_babble_init(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Babble Exec unit activation during each trial over the 
% whole trial period.
ave_tr_babble_exec = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_babble_exec(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_babble_exec(xx) = ave_tr_babble_exec(xx) + ...
            babble_exec_unit(yy);
    end;
    ave_tr_babble_exec(xx) = ave_tr_babble_exec(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble Exec unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_babble_exec = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_babble_exec(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_babble_exec(xx) = ave_tr_stim_babble_exec(xx) + ...
            babble_exec_unit(yy);
    end;
    ave_tr_stim_babble_exec(xx) = ave_tr_stim_babble_exec(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble Exec unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_babble_exec = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_babble_exec(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_babble_exec(xx) = ave_tr_del_babble_exec(xx) + ...
            babble_exec_unit(yy);
    end;
    ave_tr_del_babble_exec(xx) = ave_tr_del_babble_exec(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Babble sum activation during each trial over the 
% whole trial period.
ave_tr_babble_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_babble_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_babble_sum(xx) = ave_tr_babble_sum(xx) + ...
            babble_sum(yy);
    end;
    ave_tr_babble_sum(xx) = ave_tr_babble_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_babble_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_babble_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_babble_sum(xx) = ave_tr_stim_babble_sum(xx) + ...
            babble_sum(yy);
    end;
    ave_tr_stim_babble_sum(xx) = ave_tr_stim_babble_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Babble sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_babble_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_babble_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_babble_sum(xx) = ave_tr_del_babble_sum(xx) + ...
            babble_sum(yy);
    end;
    ave_tr_del_babble_sum(xx) = ave_tr_del_babble_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Plan sum activation during each trial over the 
% whole trial period.
ave_tr_plan_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_plan_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_plan_sum(xx) = ave_tr_plan_sum(xx) + ...
            plan_sum(yy);
    end;
    ave_tr_plan_sum(xx) = ave_tr_plan_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Plan sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_plan_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_plan_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_plan_sum(xx) = ave_tr_stim_plan_sum(xx) + ...
            plan_sum(yy);
    end;
    ave_tr_stim_plan_sum(xx) = ave_tr_stim_plan_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Plan sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_plan_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_plan_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_plan_sum(xx) = ave_tr_del_plan_sum(xx) + ...
            plan_sum(yy);
    end;
    ave_tr_del_plan_sum(xx) = ave_tr_del_plan_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Nod Request sum activation during each trial over the 
% whole trial period.
ave_tr_nod_req_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_nod_req_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_nod_req_sum(xx) = ave_tr_nod_req_sum(xx) + ...
            nod_req_sum(yy);
    end;
    ave_tr_nod_req_sum(xx) = ave_tr_nod_req_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod Request sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_nod_req_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_nod_req_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_nod_req_sum(xx) = ave_tr_stim_nod_req_sum(xx) + ...
            nod_req_sum(yy);
    end;
    ave_tr_stim_nod_req_sum(xx) = ave_tr_stim_nod_req_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod Request sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_nod_req_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_nod_req_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_nod_req_sum(xx) = ave_tr_del_nod_req_sum(xx) + ...
            nod_req_sum(yy);
    end;
    ave_tr_del_nod_req_sum(xx) = ave_tr_del_nod_req_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Nod GoE sum activation during each trial over the 
% whole trial period.
ave_tr_nod_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_nod_go_e_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_nod_go_e_sum(xx) = ave_tr_nod_go_e_sum(xx) + ...
            nod_go_e_sum(yy);
    end;
    ave_tr_nod_go_e_sum(xx) = ave_tr_nod_go_e_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod GoE sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_nod_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_nod_go_e_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_nod_go_e_sum(xx) = ave_tr_stim_nod_go_e_sum(xx) + ...
            nod_go_e_sum(yy);
    end;
    ave_tr_stim_nod_go_e_sum(xx) = ave_tr_stim_nod_go_e_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod GoE sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_nod_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_nod_go_e_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_nod_go_e_sum(xx) = ave_tr_del_nod_go_e_sum(xx) + ...
            nod_go_e_sum(yy);
    end;
    ave_tr_del_nod_go_e_sum(xx) = ave_tr_del_nod_go_e_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Nod GoI sum activation during each trial over the 
% whole trial period.
ave_tr_nod_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_nod_go_i_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_nod_go_i_sum(xx) = ave_tr_nod_go_i_sum(xx) + ...
            nod_go_i_sum(yy);
    end;
    ave_tr_nod_go_i_sum(xx) = ave_tr_nod_go_i_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod GoI sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_nod_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_nod_go_i_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_nod_go_i_sum(xx) = ave_tr_stim_nod_go_i_sum(xx) + ...
            nod_go_i_sum(yy);
    end;
    ave_tr_stim_nod_go_i_sum(xx) = ave_tr_stim_nod_go_i_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod GoI sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_nod_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_nod_go_i_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_nod_go_i_sum(xx) = ave_tr_del_nod_go_i_sum(xx) + ...
            nod_go_i_sum(yy);
    end;
    ave_tr_del_nod_go_i_sum(xx) = ave_tr_del_nod_go_i_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Nod NoGo sum activation during each trial over the 
% whole trial period.
ave_tr_nod_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_nod_nogo_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_nod_nogo_sum(xx) = ave_tr_nod_nogo_sum(xx) + ...
            nod_nogo_sum(yy);
    end;
    ave_tr_nod_nogo_sum(xx) = ave_tr_nod_nogo_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod NoGo sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_nod_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_nod_nogo_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_nod_nogo_sum(xx) = ave_tr_stim_nod_nogo_sum(xx) + ...
            nod_nogo_sum(yy);
    end;
    ave_tr_stim_nod_nogo_sum(xx) = ave_tr_stim_nod_nogo_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod NoGo sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_nod_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_nod_nogo_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_nod_nogo_sum(xx) = ave_tr_del_nod_nogo_sum(xx) + ...
            nod_nogo_sum(yy);
    end;
    ave_tr_del_nod_nogo_sum(xx) = ave_tr_del_nod_nogo_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Nod Init unit activation during each trial over the 
% whole trial period.
ave_tr_nod_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_nod_init(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_nod_init(xx) = ave_tr_nod_init(xx) + ...
            nod_init_unit(yy);
    end;
    ave_tr_nod_init(xx) = ave_tr_nod_init(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod Init unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_nod_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_nod_init(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_nod_init(xx) = ave_tr_stim_nod_init(xx) + ...
            nod_init_unit(yy);
    end;
    ave_tr_stim_nod_init(xx) = ave_tr_stim_nod_init(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod Init unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_nod_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_nod_init(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_nod_init(xx) = ave_tr_del_nod_init(xx) + ...
            nod_init_unit(yy);
    end;
    ave_tr_del_nod_init(xx) = ave_tr_del_nod_init(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Shake Request sum activation during each trial over the 
% whole trial period.
ave_tr_shake_req_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_shake_req_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_shake_req_sum(xx) = ave_tr_shake_req_sum(xx) + ...
            shake_req_sum(yy);
    end;
    ave_tr_shake_req_sum(xx) = ave_tr_shake_req_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake Request sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_shake_req_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_shake_req_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_shake_req_sum(xx) = ave_tr_stim_shake_req_sum(xx) + ...
            shake_req_sum(yy);
    end;
    ave_tr_stim_shake_req_sum(xx) = ave_tr_stim_shake_req_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake Request sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_shake_req_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_shake_req_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_shake_req_sum(xx) = ave_tr_del_shake_req_sum(xx) + ...
            shake_req_sum(yy);
    end;
    ave_tr_del_shake_req_sum(xx) = ave_tr_del_shake_req_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Shake GoE sum activation during each trial over the 
% whole trial period.
ave_tr_shake_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_shake_go_e_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_shake_go_e_sum(xx) = ave_tr_shake_go_e_sum(xx) + ...
            shake_go_e_sum(yy);
    end;
    ave_tr_shake_go_e_sum(xx) = ave_tr_shake_go_e_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake GoE sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_shake_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_shake_go_e_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_shake_go_e_sum(xx) = ave_tr_stim_shake_go_e_sum(xx) + ...
            shake_go_e_sum(yy);
    end;
    ave_tr_stim_shake_go_e_sum(xx) = ave_tr_stim_shake_go_e_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake GoE sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_shake_go_e_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_shake_go_e_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_shake_go_e_sum(xx) = ave_tr_del_shake_go_e_sum(xx) + ...
            shake_go_e_sum(yy);
    end;
    ave_tr_del_shake_go_e_sum(xx) = ave_tr_del_shake_go_e_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Shake GoI sum activation during each trial over the 
% whole trial period.
ave_tr_shake_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_shake_go_i_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_shake_go_i_sum(xx) = ave_tr_shake_go_i_sum(xx) + ...
            shake_go_i_sum(yy);
    end;
    ave_tr_shake_go_i_sum(xx) = ave_tr_shake_go_i_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake GoI sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_shake_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_shake_go_i_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_shake_go_i_sum(xx) = ave_tr_stim_shake_go_i_sum(xx) + ...
            shake_go_i_sum(yy);
    end;
    ave_tr_stim_shake_go_i_sum(xx) = ave_tr_stim_shake_go_i_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake GoI sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_shake_go_i_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_shake_go_i_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_shake_go_i_sum(xx) = ave_tr_del_shake_go_i_sum(xx) + ...
            shake_go_i_sum(yy);
    end;
    ave_tr_del_shake_go_i_sum(xx) = ave_tr_del_shake_go_i_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Shake NoGo sum activation during each trial over the 
% whole trial period.
ave_tr_shake_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_shake_nogo_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_shake_nogo_sum(xx) = ave_tr_shake_nogo_sum(xx) + ...
            shake_nogo_sum(yy);
    end;
    ave_tr_shake_nogo_sum(xx) = ave_tr_shake_nogo_sum(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake NoGo sum activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_shake_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_shake_nogo_sum(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_shake_nogo_sum(xx) = ave_tr_stim_shake_nogo_sum(xx) + ...
            shake_nogo_sum(yy);
    end;
    ave_tr_stim_shake_nogo_sum(xx) = ave_tr_stim_shake_nogo_sum(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake NoGo sum activation during each trial over the
% delay portion of the trial period.
ave_tr_del_shake_nogo_sum = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_shake_nogo_sum(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_shake_nogo_sum(xx) = ave_tr_del_shake_nogo_sum(xx) + ...
            shake_nogo_sum(yy);
    end;
    ave_tr_del_shake_nogo_sum(xx) = ave_tr_del_shake_nogo_sum(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Shake Init unit activation during each trial over the 
% whole trial period.
ave_tr_shake_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_shake_init(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_shake_init(xx) = ave_tr_shake_init(xx) + ...
            shake_init_unit(yy);
    end;
    ave_tr_shake_init(xx) = ave_tr_shake_init(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake Init unit activation during each trial over the
% stimulus portion of the trial period.
ave_tr_stim_shake_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_shake_init(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_shake_init(xx) = ave_tr_stim_shake_init(xx) + ...
            shake_init_unit(yy);
    end;
    ave_tr_stim_shake_init(xx) = ave_tr_stim_shake_init(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Shake Init unit activation during each trial over the
% delay portion of the trial period.
ave_tr_del_shake_init = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_shake_init(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_shake_init(xx) = ave_tr_del_shake_init(xx) + ...
            shake_init_unit(yy);
    end;
    ave_tr_del_shake_init(xx) = ave_tr_del_shake_init(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

% Find the average Nod/Shake Conflict unit activation during each trial 
% over the whole trial period.
ave_tr_ns_conflict = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_ns_conflict(xx) = 0;
    for yy = trial_starts(xx):(trial_ends(xx) - 1)
        ave_tr_ns_conflict(xx) = ave_tr_ns_conflict(xx) + ...
            ns_conflict_unit(yy);
    end;
    ave_tr_ns_conflict(xx) = ave_tr_ns_conflict(xx) / ...
        (trial_ends(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod/Shake Conflict unit activation during each trial 
% over the stimulus portion of the trial period.
ave_tr_stim_ns_conflict = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_stim_ns_conflict(xx) = 0;
    for yy = trial_starts(xx):(trial_stimoffs(xx) - 1)
        ave_tr_stim_ns_conflict(xx) = ave_tr_stim_ns_conflict(xx) + ...
            ns_conflict_unit(yy);
    end;
    ave_tr_stim_ns_conflict(xx) = ave_tr_stim_ns_conflict(xx) / ...
        (trial_stimoffs(xx) - trial_starts(xx) + 1);
end;

% Find the average Nod/Shake Conflict unit activation during each trial 
% over the delay portion of the trial period.
ave_tr_del_ns_conflict = zeros(1,num_trials);
for xx = 1:num_trials
    ave_tr_del_ns_conflict(xx) = 0;
    for yy = trial_stimoffs(xx):(trial_ends(xx) - 1)
        ave_tr_del_ns_conflict(xx) = ave_tr_del_ns_conflict(xx) + ...
            ns_conflict_unit(yy);
    end;
    ave_tr_del_ns_conflict(xx) = ave_tr_del_ns_conflict(xx) / ...
        (trial_ends(xx) - trial_stimoffs(xx) + 1);
end;

ave_babble_activ = mean(ave_tr_babble_sum(1:last_calc_trial));
ave_plan_activ = mean(ave_tr_plan_sum(1:last_calc_trial));
ave_nod_req_activ = mean(ave_tr_nod_req_sum(1:last_calc_trial));
ave_shake_req_activ = mean(ave_tr_shake_req_sum(1:last_calc_trial));
ave_babble_req_activ = mean(ave_tr_babble_req(1:last_calc_trial));
ave_nod_go_activ = mean(ave_tr_nod_go_e_sum(1:last_calc_trial));
ave_shake_go_activ = mean(ave_tr_shake_go_e_sum(1:last_calc_trial));
ave_babble_go_activ = mean(ave_tr_babble_go_e_sum(1:last_calc_trial));
ave_nod_nogo_activ = mean(ave_tr_nod_nogo_sum(1:last_calc_trial));
ave_shake_nogo_activ = mean(ave_tr_shake_nogo_sum(1:last_calc_trial));
ave_babble_nogo_activ = mean(ave_tr_babble_nogo_sum(1:last_calc_trial));
