%
% disp_cell_wts.m
%
% Display the connection weights in a certain fascicle that fan into or out 
% of a particular cell in the fascicle.
% fasc_ind selects the fascicle.  x_ind and y_ind select which 
% cell in the area we're interested in seeing the weights of.  fanin is set
% to 1 if we are looking for a fanin and 0 if we are looking at a fanout
% instead.
%
% Depends on: fasc_ind, fanin, x_ind, y_ind, NC, CA, CW, Conn_fromto, 
% Area_xy
%
% Last modification: 10/7/06

% Find the index for the first connection of the desired fascicle.
first_conn_ind = 1;
for xx = 1:fasc_ind - 1
    first_conn_ind = first_conn_ind + NC(xx);
end;

% Get the connection to and from addresses and the weights for the desired fascicle.
addr = double(CA(:,first_conn_ind:first_conn_ind + NC(fasc_ind) - 1));
weig = CW(first_conn_ind:first_conn_ind + NC(fasc_ind) - 1);

% Subtract the unit offsets to get the relative connection addresses.
addr(1,:) = addr(1,:) - unit_offset(Conn_fromto(fasc_ind,2));
addr(2,:) = addr(2,:) - unit_offset(Conn_fromto(fasc_ind,1));

% Get the area sizes for the input and output areas
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);

% For a fanin display...
if (fanin == 1)
    % Set all the weights to zero initially.
    wts = zeros(in_y_sz, in_x_sz);
    
    % Find the address of the unit we're interested in.
    to_ind = y_ind + (x_ind - 1) * out_y_sz; 

    % For all connections to this unit, find the x, y coordinates
    % of the weight and save the corresponding weight for display.
    for xx = 1:size(addr,2)
        if (addr(1,xx) == to_ind)
            x_targ = floor((addr(2,xx) - 1) / in_y_sz) + 1;
            y_targ = mod(addr(2,xx) - 1,in_y_sz) + 1;
            wts(y_targ,x_targ) = weig(xx);
        end;
    end;
% For a fanout display...    
else
    % Set all the weights to zero initially.
    wts = zeros(out_y_sz, out_x_sz);
    
    % Find the address of the unit we're interested in.
    from_ind = y_ind + (x_ind - 1) * in_y_sz;

    % For all connections to this unit, find the x, y coordinates
    % of the weight and save the corresponding weight for display.
    for xx = 1:size(addr,2)
        if (addr(2,xx) == from_ind)
            x_targ = floor((addr(1,xx) - 1) / out_y_sz) + 1;
            y_targ = mod(addr(1,xx) - 1,out_y_sz) + 1;
            wts(y_targ,x_targ) = weig(xx);
        end;
    end;    
end;

% Plot the weights (negatives won't work right, here).
wt_min_ceiling = 0.050;
wt_abs_bound = max(max(abs(wts)));
if (wt_abs_bound < wt_min_ceiling)
    wt_abs_bound = wt_min_ceiling;
end;
imagesc(wts, [0 wt_abs_bound]);

% This code plots weights the way I want, but the data cursor won't show
% the right data.
% wt_abs_bound = max(max(abs(wts)));
% if (wt_abs_bound < 0.001)
%     wt_abs_bound = 0.001;
% end;
% exc_wts = wts;
% inh_wts = wts;
% exc_wts(find(wts < 0)) = 0;
% inh_wts(find(wts > 0)) = 0;
% wts_disp = zeros(in_y_sz,in_x_sz,3);
% wts_disp(:,:,2) = exc_wts(:,:) ./ wt_abs_bound;   % excitatory weights
% wts_disp(:,:,1) = -inh_wts(:,:) ./ wt_abs_bound;  % inhibitory weights
% imagesc(wts_disp);