%
% disp_learning_events.m
%
% Show learning events that happened during a simulation run.
%
% Depends on: modCW, mdc, reward_on_sv, num_iters, Num_conns, unit_offset
%
% Last modification: 4/27/07

% Uses modCW from a simulation run.

del_modCW = zeros(size(mdc,2),num_iters);
reward_iters = [];
learn_iters = [];
wts_changed = [];

for (iter = 2:num_iters)
    if (reward_on_sv(iter) == 1)
        reward_iters = [reward_iters iter];
    end;
    del_modCW(:,iter) = modCW(:,iter) - modCW(:,iter-1);
    if (sum(del_modCW(:,iter)) ~= 0)
        learn_iters = [learn_iters iter];
        wts_changed = [wts_changed find(del_modCW(:,iter) ~= 0)'];      
    end;
end;
if (size(wts_changed,2) > 0)
    wc_source_area = zeros(1,size(wts_changed,2));
    wc_targ_area = zeros(1,size(wts_changed,2));
    wc_source_unit_x = zeros(1,size(wts_changed,2));
    wc_source_unit_y = zeros(1,size(wts_changed,2));  
    wc_targ_unit_x = zeros(1,size(wts_changed,2));
    wc_targ_unit_y = zeros(1,size(wts_changed,2));    
    for (ii = 1:size(wts_changed,2))
        source_addr = CA(2,mdc(wts_changed(ii)));
        target_addr = CA(1,mdc(wts_changed(ii)));        
        for (jj = 1:Num_areas-1)
            if ((unit_offset(jj) < source_addr) && ...
                (source_addr <= unit_offset(jj + 1)))
                wc_source_area(ii) = jj;
            end;
            if ((unit_offset(jj) < target_addr) && ...
                (target_addr <= unit_offset(jj + 1)))
                wc_targ_area(ii) = jj;
            end;            
        end;
        if (source_addr > unit_offset(Num_areas))
            wc_source_area(ii) = Num_areas;
        end;
        if (target_addr > unit_offset(Num_areas))
            wc_targ_area(ii) = Num_areas;
        end;
        in_x_sz = Area_xy(wc_source_area(ii),1);
        in_y_sz = Area_xy(wc_source_area(ii),2);
        out_x_sz = Area_xy(wc_targ_area(ii),1);
        out_y_sz = Area_xy(wc_targ_area(ii),2);
        source_unit_ind = source_addr - unit_offset(wc_source_area(ii));
        wc_source_unit_x(ii) = floor((double(source_unit_ind) - 1) / in_y_sz) + 1;
        wc_source_unit_y(ii) = mod(source_unit_ind - 1,in_y_sz) + 1;
        targ_unit_ind = target_addr - unit_offset(wc_targ_area(ii));
        wc_targ_unit_x(ii) = floor((double(targ_unit_ind) - 1) / out_y_sz) + 1;
        wc_targ_unit_y(ii) = mod(targ_unit_ind - 1,out_y_sz) + 1;        
    end;
end;
reward_iters
learn_iters
wts_changed
wc_source_area
wc_source_unit_x
wc_source_unit_y
wc_targ_area
wc_targ_unit_x
wc_targ_unit_y
if (size(wts_changed,2) > 0)
    figure(1);
    look_wt = wts_changed(1);
    plot(modCW(look_wt,:));
    xlab_str = strcat('Change of modCW weight #',num2str(look_wt));
    xlabel(xlab_str);
end;
if (size(wts_changed,2) > 0)
    figure(2);
    look_wt = wts_changed(1);
    plot(elig_trace(look_wt,:));
    xlab_str = strcat('Elig. trace of modCW weight #',num2str(look_wt));
    xlabel(xlab_str);
end;