%
% fetch_cell_wt_inds.m
%
% Fetch the connection weight indices in a certain fascicle that fan into 
% or out of a particular cell in the fascicle.  
% fasc_ind selects the fascicle.  x_ind and y_ind select which 
% cell in the area we're interested in seeing the indices of.  fanin is set
% to 1 if we are looking for a fanin and 0 if we are looking at a fanout
% instead.
%
% Depends on: fasc_ind, fanin, x_ind, y_ind, NC, CA, unit_offset, 
% Conn_fromto, Area_xy
%
% Last modification: 6/6/07

% Find the indices for the first and last connection of the desired fascicle.
first_conn_ind = 1;
for xx_fcwi = 1:fasc_ind - 1
    first_conn_ind = first_conn_ind + NC(xx_fcwi);
end;
last_conn_ind = first_conn_ind + NC(fasc_ind) - 1;

% Get the connection to and from addresses for the desired fascicle.
addr = double(CA(:,first_conn_ind:last_conn_ind));

% Subtract the unit offsets to get the relative connection addresses.
addr(1,:) = addr(1,:) - unit_offset(Conn_fromto(fasc_ind,2));
addr(2,:) = addr(2,:) - unit_offset(Conn_fromto(fasc_ind,1));

% Get the area sizes for the input and output areas
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);

% For a fanin display...
if (fanin == 1)
    % Set all the weights to zero initially.
    wt_inds = zeros(in_y_sz, in_x_sz);
    
    % Find the address of the unit we're interested in.
    to_ind = y_ind + (x_ind - 1) * out_y_sz; 

    % For all connections to this unit, find the x, y coordinates
    % of the weight and save the corresponding weight for display.
    for xx_fcwi = 1:size(addr,2)
        if (addr(1,xx_fcwi) == to_ind)
            x_targ = floor((addr(2,xx_fcwi) - 1) / in_y_sz) + 1;
            y_targ = mod(addr(2,xx_fcwi) - 1,in_y_sz) + 1;
            wt_inds(y_targ,x_targ) = xx_fcwi + first_conn_ind - 1;
        end;
    end;
% For a fanout display...    
else
    % Set all the weights to zero initially.
    wt_inds = zeros(out_y_sz, out_x_sz);
    
    % Find the address of the unit we're interested in.
    from_ind = y_ind + (x_ind - 1) * in_y_sz;

    % For all connections to this unit, find the x, y coordinates
    % of the weight and save the corresponding weight for display.
    for xx_fcwi = 1:size(addr,2)
        if (addr(2,xx_fcwi) == from_ind)
            x_targ = floor((addr(1,xx_fcwi) - 1) / out_y_sz) + 1;
            y_targ = mod(addr(1,xx_fcwi) - 1,out_y_sz) + 1;
            wt_inds(y_targ,x_targ) = xx_fcwi + first_conn_ind - 1;
        end;
    end;    
end;