%
% fetchps_area_fascin_iter.m
%
% Get the net input of a fascicle fasc_ind into all units in an area 
% selected by area_ind, for a particular time iteration.  Output is 
% fascins.  Use after a simulation run.
%
% Depends on: area_ind, fasc_ind, time_ind, output, Area_xy, Conn_fromto
%
% Last modification: 6/25/07


% Remember the area whose unit we're interested in, and the time index we 
% interested in.
the_area = area_ind;
the_time_ind = time_ind;
 
% Get the area sizes for the fascicle's target area.
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);

% Initialize the data we're reading.
fascins = zeros(out_y_sz,out_x_sz);

% For each unit in the target area...
for xx_fafi = 1:out_x_sz
    for yy_fafi = 1:out_y_sz
        % Get the fanin weights of the current time step.
        area_ind = the_area;
        time_ind = the_time_ind;
        fanin = 1;
        x_ind = xx_fafi;
        y_ind = yy_fafi;
        fetchps_cell_wts_iter;
        
        % Get the activations of the source layer for the previous time step.
        area_ind = Conn_fromto(fasc_ind,1);
        time_ind = the_time_ind - 1;
        if (time_ind > 0)
            fetchps_area_activs_iter;
        else
            activs = 0;
        end;
        
        % Calculate the net input contribution.
        fascins(yy_fafi,xx_fafi) = sum(sum(activs .* wts));
    end;
end;

% Make sure the time_ind is restored to its previous value.
time_ind = the_time_ind;