%
% get_cog_model_indices.m
%
% Load both area and unit indices for the cognitive model performing the
% pan-tilt tasks.  This will make access to the data in the code a lot
% easier.
%
% Last modification: 10/26/07


%
% Get indices for model areas.
%

% Run through all of the areas and extract the appropriate area indices.
for xx = 1:size(Area_name,1)
    the_area_name = sscanf(Area_name(xx,:),'%s');
    if (strcmp(the_area_name, 'VisStimOn'))
        VisStimOn_ind = Area_num(xx);    
    elseif (strcmp(the_area_name, 'ColorIn'))
        ColorIn_ind = Area_num(xx);
    elseif (strcmp(the_area_name, 'TonesIn'))
        TonesIn_ind = Area_num(xx);   
    elseif (strcmp(the_area_name, 'RewardIn'))
        RewardIn_ind = Area_num(xx);   
    elseif (strcmp(the_area_name, 'PunisherIn'))
        PunisherIn_ind = Area_num(xx);           
    elseif (strcmp(the_area_name, 'TrackExec'))
        TrackExec_ind = Area_num(xx);         
    elseif (strcmp(the_area_name, 'NodExec'))
        NodExec_ind = Area_num(xx);             
    elseif (strcmp(the_area_name, 'ShakeExec'))
        ShakeExec_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'TonicDAAff'))
        TonicDAAff_ind = Area_num(xx);          
    elseif (strcmp(the_area_name, 'NoveltyE'))
        Novelty_ind = Area_num(xx); 
%     elseif (strcmp(the_area_name, 'RewardCueE'))
%         RewardCue_ind = Area_num(xx);         
%     elseif (strcmp(the_area_name, 'RewPredict'))
%         RewPredict_ind = Area_num(xx);   
    elseif (strcmp(the_area_name, 'DASignal'))
        DASignal_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'DAEffects'))
        DAEffects_ind = Area_num(xx);     
    elseif (strcmp(the_area_name, 'Frustration'))
        Frustration_ind = Area_num(xx);         
    elseif (strcmp(the_area_name, 'BabbleReq'))
        BabbleReq_ind = Area_num(xx);         
    elseif (strcmp(the_area_name, 'BabbleGoE'))
        BabbleGoE_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'BabbleGoI'))
        BabbleGoI_ind = Area_num(xx);         
    elseif (strcmp(the_area_name, 'BabbleNoGo'))
        BabbleNoGo_ind = Area_num(xx);     
    elseif (strcmp(the_area_name, 'BabbleInit'))
        BabbleInit_ind = Area_num(xx);            
    elseif (strcmp(the_area_name, 'BabbleExec'))
        BabbleExec_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'BabbleDiceE'))
        BabbleDice_ind = Area_num(xx);           
    elseif (strcmp(the_area_name, 'Babble'))
        Babble_ind = Area_num(xx);            
    elseif (strcmp(the_area_name, 'ColorsWM'))
        ColorMem_ind = Area_num(xx);  
    elseif (strcmp(the_area_name, 'TonesWM'))
        TonesMem_ind = Area_num(xx);  
    elseif (strcmp(the_area_name, 'ReinfWM'))
        ReinfMem_ind = Area_num(xx);     
    elseif (strcmp(the_area_name, 'Plan'))
        Plan_ind = Area_num(xx);       
    elseif (strcmp(the_area_name, 'NodReqE'))
        NodReqE_ind = Area_num(xx);      
    elseif (strcmp(the_area_name, 'NodGoE'))
        NodGoE_ind = Area_num(xx);
    elseif (strcmp(the_area_name, 'NodGoI'))
        NodGoI_ind = Area_num(xx);        
    elseif (strcmp(the_area_name, 'NodNoGo'))
        NodNoGo_ind = Area_num(xx);        
    elseif (strcmp(the_area_name, 'NodInit'))
        NodInit_ind = Area_num(xx);    
    elseif (strcmp(the_area_name, 'ShakeReqE'))
        ShakeReqE_ind = Area_num(xx);              
    elseif (strcmp(the_area_name, 'ShakeGoE'))
        ShakeGoE_ind = Area_num(xx);
    elseif (strcmp(the_area_name, 'ShakeGoI'))
        ShakeGoI_ind = Area_num(xx);        
    elseif (strcmp(the_area_name, 'ShakeNoGo'))
        ShakeNoGo_ind = Area_num(xx);       
    elseif (strcmp(the_area_name, 'ShakeInit'))
        ShakeInit_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'NodShakeConf'))
        NodShakeConf_ind = Area_num(xx);  
    elseif (strcmp(the_area_name, 'NeuralNoise'))
        NeuralNoise_ind = Area_num(xx);      
    elseif (strcmp(the_area_name, 'NeuralDiceE'))
        NeuralDiceE_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'GatedDice'))
        GatedDice_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'DiceSet'))
        DiceSet_ind = Area_num(xx); 
    elseif (strcmp(the_area_name, 'DiceGate'))
        DiceGate_ind = Area_num(xx);        
    end;
end;

%
% Get indices for model units.
%

% Find the visual stimulus presence unit index.
lo_bound = 1;
for xx = 1:VisStimOn_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(VisStimOn_ind,3) - 1;
VisStimOnUnit_ind = lo_bound;

% Find the first and last color unit indices.
lo_bound = 1;
for xx = 1:ColorIn_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ColorIn_ind,3) - 1;
RedUnit_ind = lo_bound;
YellowUnit_ind = hi_bound;

% Find the first and last color unit indices of the color memory area.
lo_bound = 1;
for xx = 1:ColorMem_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ColorMem_ind,3) - 1;
RedMemUnit_ind = lo_bound;
YellowMemUnit_ind = hi_bound;

% Find the first and last tone unit indices.
lo_bound = 1;
for xx = 1:TonesIn_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(TonesIn_ind,3) - 1;
CUnit_ind = lo_bound;
BUnit_ind = hi_bound;

% Find the first and last tone unit indices of the tone memory area.
lo_bound = 1;
for xx = 1:TonesMem_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(TonesMem_ind,3) - 1;
CMemUnit_ind = lo_bound;
BMemUnit_ind = hi_bound;

% Find the reward unit index.
lo_bound = 1;
for xx = 1:RewardIn_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(RewardIn_ind,3) - 1;
RewardUnit_ind = lo_bound;

% Find the punisher unit index.
lo_bound = 1;
for xx = 1:PunisherIn_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(PunisherIn_ind,3) - 1;
PunisherUnit_ind = lo_bound;

% Find the reinforcement working memory index.
lo_bound = 1;
for xx = 1:ReinfMem_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ReinfMem_ind,3) - 1;
ReinfMemUnit_ind = lo_bound;

% Find the track execute unit index.
lo_bound = 1;
for xx = 1:TrackExec_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(TrackExec_ind,3) - 1;
TrackExecUnit_ind = lo_bound;

% Find the nod execute unit index.
lo_bound = 1;
for xx = 1:NodExec_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(NodExec_ind,3) - 1;
NodExecUnit_ind = lo_bound;

% Find the shake execute unit index.
lo_bound = 1;
for xx = 1:ShakeExec_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ShakeExec_ind,3) - 1;
ShakeExecUnit_ind = lo_bound;

% Find the tonic DA afferent unit index.
lo_bound = 1;
for xx = 1:TonicDAAff_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(TonicDAAff_ind,3) - 1;
TonicDAAffUnit_ind = lo_bound;

% Find the novelty unit index.
lo_bound = 1;
for xx = 1:Novelty_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(Novelty_ind,3) - 1;
NoveltyUnit_ind = lo_bound;

% % Find the reward cue unit index.
% lo_bound = 1;
% for xx = 1:RewardCue_ind - 1
%     lo_bound = lo_bound + Area_xy(xx,3);
% end;
% hi_bound = lo_bound + Area_xy(RewardCue_ind,3) - 1;
% RewardCueUnit_ind = lo_bound;
% 
% % Find the first and last unit indices of the reward prediction area.
% lo_bound = 1;
% for xx = 1:RewPredict_ind - 1
%     lo_bound = lo_bound + Area_xy(xx,3);
% end;
% hi_bound = lo_bound + Area_xy(RewPredict_ind,3) - 1;
% RewPredictLoUnit = lo_bound;
% RewPredictHiUnit = hi_bound;

% Find the DA signal unit index.
lo_bound = 1;
for xx = 1:DASignal_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(DASignal_ind,3) - 1;
DAUnit_ind = lo_bound;

% Find the DA effects unit indices.
lo_bound = 1;
for xx = 1:DAEffects_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(DAEffects_ind,3) - 1;
DAPlanEffUnit_ind = lo_bound;
DAReqEffUnit_ind = lo_bound + 1;
DANodShakeGoEffUnit_ind = lo_bound + 2;
DANodShakeNoGoEffUnit_ind = lo_bound + 3;
DABabbleGoEffUnit_ind = lo_bound + 4;
DABabbleNoGoEffUnit_ind = lo_bound + 5;

% Find the frustration unit index.
lo_bound = 1;
for xx = 1:Frustration_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(Frustration_ind,3) - 1;
FrustrationUnit_ind = lo_bound;

% Find the babble request unit index.
lo_bound = 1;
for xx = 1:BabbleReq_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(BabbleReq_ind,3) - 1;
BabbleReqUnit_ind = lo_bound;

% Find the babble Go unit excitatory index.
lo_bound = 1;
for xx = 1:BabbleGoE_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(BabbleGoE_ind,3) - 1;
BabbleGoUnitE_ind = lo_bound;

% Find the babble Go unit inhibitory index.
lo_bound = 1;
for xx = 1:BabbleGoI_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(BabbleGoI_ind,3) - 1;
BabbleGoUnitI_ind = lo_bound;

% Find the babble NoGo unit index.
lo_bound = 1;
for xx = 1:BabbleNoGo_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(BabbleNoGo_ind,3) - 1;
BabbleNoGoUnit_ind = lo_bound;

% Find the babble init unit index.
lo_bound = 1;
for xx = 1:BabbleInit_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(BabbleInit_ind,3) - 1;
BabbleInitUnit_ind = lo_bound;

% Find the babble exec unit index.
lo_bound = 1;
for xx = 1:BabbleExec_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(BabbleExec_ind,3) - 1;
BabbleExecUnit_ind = lo_bound;

% Find the Nod request excitatory unit index.
lo_bound = 1;
for xx = 1:NodReqE_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(NodReqE_ind,3) - 1;
NodReqUnitE_ind = lo_bound;

% Find the excitatory Nod Go unit index.
lo_bound = 1;
for xx = 1:NodGoE_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(NodGoE_ind,3) - 1;
NodGoUnitE_ind = lo_bound;

% Find the inhibitory Nod Go unit index.
lo_bound = 1;
for xx = 1:NodGoI_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(NodGoI_ind,3) - 1;
NodGoUnitI_ind = lo_bound;

% Find the Nod NoGo unit index.
lo_bound = 1;
for xx = 1:NodNoGo_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(NodNoGo_ind,3) - 1;
NodNoGoUnit_ind = lo_bound;

% Find the Nod Init unit index.
lo_bound = 1;
for xx = 1:NodInit_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(NodInit_ind,3) - 1;
NodInitUnit_ind = lo_bound;

% Find the Shake request excitatory unit index.
lo_bound = 1;
for xx = 1:ShakeReqE_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ShakeReqE_ind,3) - 1;
ShakeReqUnitE_ind = lo_bound;

% Find the excitatory Shake Go unit index.
lo_bound = 1;
for xx = 1:ShakeGoE_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ShakeGoE_ind,3) - 1;
ShakeGoUnitE_ind = lo_bound;

% Find the inhibitory Shake Go unit index.
lo_bound = 1;
for xx = 1:ShakeGoI_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ShakeGoI_ind,3) - 1;
ShakeGoUnitI_ind = lo_bound;

% Find the Shake NoGo unit index.
lo_bound = 1;
for xx = 1:ShakeNoGo_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ShakeNoGo_ind,3) - 1;
ShakeNoGoUnit_ind = lo_bound;

% Find the Shake Init unit index.
lo_bound = 1;
for xx = 1:ShakeInit_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(ShakeInit_ind,3) - 1;
ShakeInitUnit_ind = lo_bound; 

% Find the Nod/Shake Conflict unit index.
lo_bound = 1;
for xx = 1:NodShakeConf_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(NodShakeConf_ind,3) - 1;
NodShakeConfUnit_ind = lo_bound; 

% Find the neural dice set unit index.
lo_bound = 1;
for xx = 1:DiceSet_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(DiceSet_ind,3) - 1;
DiceSetUnit_ind = lo_bound; 

% Find the neural dice gate unit index.
lo_bound = 1;
for xx = 1:DiceGate_ind - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(DiceGate_ind,3) - 1;
DiceGateUnit_ind = lo_bound; 

%
% Get indices for model connnection fascicles.
%

% Find the fascicles.
for xx = 1:size(Conn_name,1)
    the_conn_name = sscanf(Conn_name(xx,:),'%s');
%     if (strcmp(the_conn_name, 'Color_WMtoRewCueE'))
%         Color_WMtoRewCueE_ind = xx;
%     elseif (strcmp(the_conn_name, 'Tones_WMtoRewCueE'))
%         Tones_WMtoRewCueE_ind = xx;        
%     elseif (strcmp(the_conn_name, 'Color_WMtoRewPred'))
%         Color_WMtoRewPred_ind = xx;
%     elseif (strcmp(the_conn_name, 'Tones_WMtoRewPred'))
%         Tones_WMtoRewPred_ind = xx;    
    if (strcmp(the_conn_name, 'TonicDAtoDASig'))
        TonicDAtoDASig_ind = xx;   
    elseif (strcmp(the_conn_name, 'RewIntoDASig'))
        RewIntoDASig_ind = xx;          
%     elseif (strcmp(the_conn_name, 'RewCuetoDASig'))
%         RewCuetoDASig_ind = xx;
%     elseif (strcmp(the_conn_name, 'RewPredtoDASig'))
%         RewPredtoDASig_ind = xx;
    elseif (strcmp(the_conn_name, 'NoveltytoDASig'))
        NoveltytoDASig_ind = xx; 
    elseif (strcmp(the_conn_name, 'PunishIntoDASig'))
        PunishIntoDASig_ind = xx;    
    elseif (strcmp(the_conn_name, 'FrusttoDASig'))
        FrusttoDASig_ind = xx;          
    elseif (strcmp(the_conn_name, 'NovtoBReq'))
        NovtoBReq_ind = xx;         
    elseif (strcmp(the_conn_name, 'FrusttoBReq'))
        FrusttoBReq_ind = xx;    
    elseif (strcmp(the_conn_name, 'Color_WMtoBReq'))
        Color_WMtoBReq_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoBReq'))
        Tones_WMtoBReq_ind = xx;    
    elseif (strcmp(the_conn_name, 'BabbleReqtoGo'))
        BabbleReqtoGo_ind = xx;      
    elseif (strcmp(the_conn_name, 'TNoisetoBGo'))
        TNoisetoBGo_ind = xx;        
    elseif (strcmp(the_conn_name, 'Color_WMtoBGo'))
        Color_WMtoBGo_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoBGo'))
        Tones_WMtoBGo_ind = xx;
    elseif (strcmp(the_conn_name, 'BabbleInittoNoGo'))
        BabbleInittoNoGo_ind = xx;
    elseif (strcmp(the_conn_name, 'TNoisetoBNoGo'))
        TNoisetoBNoGo_ind = xx;
    elseif (strcmp(the_conn_name, 'Color_WMtoBNoGo'))
        Color_WMtoBNoGo_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoBNoGo'))
        Tones_WMtoBNoGo_ind = xx;   
    elseif (strcmp(the_conn_name, 'BabbleReqtoInit'))
        BabbleReqtoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'BabbleGoEtoInit'))
        BabbleGoEtoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'BabbleGoItoInit'))
        BabbleGoItoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'BabbleNoGotoInit'))
        BabbleNoGotoInit_ind = xx;                   
    elseif (strcmp(the_conn_name, 'VisStimtoPlan'))
        VisStimtoPlan_ind = xx;       
    elseif (strcmp(the_conn_name, 'Color_WMtoPlan'))
        Color_WMtoPlan_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoPlan'))
        Tones_WMtoPlan_ind = xx;    
    elseif (strcmp(the_conn_name, 'BabbletoPlan'))
        BabbletoPlan_ind = xx;  
    elseif (strcmp(the_conn_name, 'PlanBias'))
        PlanBias_ind = xx;     
    elseif (strcmp(the_conn_name, 'PlantoNodReqE'))
        PlantoNodReqE_ind = xx;     
    elseif (strcmp(the_conn_name, 'BabbletoNodReqE'))
        BabbletoNodReqE_ind = xx;   
    elseif (strcmp(the_conn_name, 'NodReqBias'))
        NodReqBias_ind = xx;  
    elseif (strcmp(the_conn_name, 'NodReqtoGo'))
        NodReqtoGo_ind = xx;        
    elseif (strcmp(the_conn_name, 'TNoisetoNGo'))
        TNoisetoNGo_ind = xx;        
    elseif (strcmp(the_conn_name, 'Color_WMtoNGo'))
        Color_WMtoNGo_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoNGo'))
        Tones_WMtoNGo_ind = xx;
    elseif (strcmp(the_conn_name, 'NodInittoNoGo'))
        NodInittoNoGo_ind = xx;
    elseif (strcmp(the_conn_name, 'TNoisetoNNoGo'))
        TNoisetoNNoGo_ind = xx;
    elseif (strcmp(the_conn_name, 'Color_WMtoNNoGo'))
        Color_WMtoNNoGo_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoNNoGo'))
        Tones_WMtoNNoGo_ind = xx;           
    elseif (strcmp(the_conn_name, 'NodReqtoInit'))
        NodReqtoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'NodGoEtoInit'))
        NodGoEtoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'NodGoItoInit'))
        NodGoItoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'NodNoGotoInit'))
        NodNoGotoInit_ind = xx;           
    elseif (strcmp(the_conn_name, 'PlantoShakeReqE'))
        PlantoShakeReqE_ind = xx;   
    elseif (strcmp(the_conn_name, 'BabbletoShakeReqE'))
        BabbletoShakeReqE_ind = xx; 
    elseif (strcmp(the_conn_name, 'ShakeReqBias'))
        ShakeReqBias_ind = xx;       
    elseif (strcmp(the_conn_name, 'ShakeReqtoGo'))
        ShakeReqtoGo_ind = xx;       
    elseif (strcmp(the_conn_name, 'TNoisetoSGo'))
        TNoisetoSGo_ind = xx;         
    elseif (strcmp(the_conn_name, 'Color_WMtoSGo'))
        Color_WMtoSGo_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoSGo'))
        Tones_WMtoSGo_ind = xx; 
    elseif (strcmp(the_conn_name, 'ShakeInittoNoGo'))
        ShakeInittoNoGo_ind = xx;   
    elseif (strcmp(the_conn_name, 'TNoisetoSNoGo'))
        TNoisetoSNoGo_ind = xx;        
    elseif (strcmp(the_conn_name, 'Color_WMtoSNoGo'))
        Color_WMtoSNoGo_ind = xx;         
    elseif (strcmp(the_conn_name, 'Tones_WMtoSNoGo'))
        Tones_WMtoSNoGo_ind = xx; 
    elseif (strcmp(the_conn_name, 'ShakeReqtoInit'))
        ShakeReqtoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'ShakeGoEtoInit'))
        ShakeGoEtoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'ShakeGoItoInit'))
        ShakeGoItoInit_ind = xx; 
    elseif (strcmp(the_conn_name, 'ShakeNoGotoInit'))
        ShakeNoGotoInit_ind = xx;              
    end;
end;