%
% init_cog_model_brain.m
%
% Initialize the brain for the neural cognitive model.
%
% Last modification: 10/30/07


% Set initial paramaters
init_unit_noise = 0.001;     % amplitude of initial unit activity noise
premotor_exec_thresh = 0.65;  % threshold of activation for Nod and Shake 
                             % Exec units                           
babble_exec_thresh = 0.5;    % threshold of activation for Babble Exec unit

load_trained_wts = 1;        % begin simulation with the saved weights?
learning_on = 0;             % is learning turned on?
save_trained_wts = 1;        % save the learned weights?

babble_lesioned = 0;         % turn off the babbling through lesioning?
fast_babble = 1;             % turn on a fast babble? (unused right now)  
reset_nogo_wts = 0;          % reset the NoGo weights?

% Set DA manipulation parameters (-1 means complete antagonism, +1 complete
% agonism, 0 no effect)
DA_runtype_normal = 0;
DA_runtype_NShypo05 = 1;
DA_runtype_NShypo1 = 2;
DA_runtype_NShypo15 = 3;
DA_runtype_NShypo2 = 4;
DA_runtype_NShypo3 = 5;
DA_runtype_Bhypo05 = 6;
DA_runtype_Bhypo1 = 7;
DA_runtype_Bhypo15 = 8;
DA_runtype_Bhypo2 = 9;
DA_runtype_Bhypo3 = 10;
DA_runtype_PRhypo05 = 11;
DA_runtype_PRhypo1 = 12;
DA_runtype_PRhypo15 = 13;
DA_runtype_PRhypo2 = 14;
DA_runtype_PRhypo3 = 15;
DA_runtype_ghypo05 = 16;
DA_runtype_ghypo1 = 17;
DA_runtype_ghypo15 = 18;
DA_runtype_ghypo2 = 19;
DA_runtype_ghypo3 = 20;
DA_runtype_NShyper05 = 21;
DA_runtype_NShyper1 = 22;
DA_runtype_NShyper3 = 23;
DA_runtype_NShyper5 = 24;
DA_runtype_Bhyper05 = 25;
DA_runtype_Bhyper1 = 26;
DA_runtype_Bhyper3 = 27;
DA_runtype_Bhyper5 = 28;
DA_runtype_PRhyper05 = 29;
DA_runtype_PRhyper1 = 30;
DA_runtype_PRhyper3 = 31;
DA_runtype_PRhyper5 = 32;
DA_runtype_ghyper05 = 33;
DA_runtype_ghyper1 = 34;
DA_runtype_ghyper3 = 35;
DA_runtype_ghyper5 = 36;

DA_runtype = DA_runtype_normal;

% DA_runtype = DA_runtype_NShypo05;
% DA_runtype = DA_runtype_NShypo1;
% DA_runtype = DA_runtype_NShypo15;
% DA_runtype = DA_runtype_NShypo2;
% DA_runtype = DA_runtype_NShypo3;
% DA_runtype = DA_runtype_Bhypo05;
% DA_runtype = DA_runtype_Bhypo1;
% DA_runtype = DA_runtype_Bhypo15;
% DA_runtype = DA_runtype_Bhypo2;
% DA_runtype = DA_runtype_Bhypo3;
% DA_runtype = DA_runtype_PRhypo05;
% DA_runtype = DA_runtype_PRhypo1;
% DA_runtype = DA_runtype_PRhypo15;
% DA_runtype = DA_runtype_PRhypo2;
% DA_runtype = DA_runtype_PRhypo3;
% DA_runtype = DA_runtype_ghypo05;
% DA_runtype = DA_runtype_ghypo1;
% DA_runtype = DA_runtype_ghypo15;
% DA_runtype = DA_runtype_ghypo2;
% DA_runtype = DA_runtype_ghypo3;

% DA_runtype = DA_runtype_NShyper05;
% DA_runtype = DA_runtype_NShyper1;
% DA_runtype = DA_runtype_NShyper3;
% DA_runtype = DA_runtype_NShyper5;
% DA_runtype = DA_runtype_Bhyper05;
% DA_runtype = DA_runtype_Bhyper1;
% DA_runtype = DA_runtype_Bhyper3;
% DA_runtype = DA_runtype_Bhyper5;
% DA_runtype = DA_runtype_PRhyper05;
% DA_runtype = DA_runtype_PRhyper1;
% DA_runtype = DA_runtype_PRhyper3;
% DA_runtype = DA_runtype_PRhyper5;
% DA_runtype = DA_runtype_ghyper05;
% DA_runtype = DA_runtype_ghyper1;
% DA_runtype = DA_runtype_ghyper3;
% DA_runtype = DA_runtype_ghyper5;

if (DA_runtype == DA_runtype_NShypo05)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = -0.05;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = -0.05;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units            
elseif (DA_runtype == DA_runtype_NShypo1)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = -0.1;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = -0.1;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units           
elseif (DA_runtype == DA_runtype_NShypo15)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = -0.15;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = -0.15;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units  
elseif (DA_runtype == DA_runtype_NShypo2)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = -0.2;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = -0.2;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units 
elseif (DA_runtype == DA_runtype_NShypo3)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = -0.3;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = -0.3;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_Bhypo05)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = -0.05;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = -0.05; 
        % agonism effect on babble striatal NoGo units            
elseif (DA_runtype == DA_runtype_Bhypo1)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = -0.1;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = -0.1; 
        % agonism effect on babble striatal NoGo units           
elseif (DA_runtype == DA_runtype_Bhypo15)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = -0.15;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = -0.15; 
        % agonism effect on babble striatal NoGo units  
elseif (DA_runtype == DA_runtype_Bhypo2)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = -0.2;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = -0.2; 
        % agonism effect on babble striatal NoGo units 
elseif (DA_runtype == DA_runtype_Bhypo3)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = -0.3;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = -0.3; 
        % agonism effect on babble striatal NoGo units     
elseif (DA_runtype == DA_runtype_PRhypo05)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = -0.05;    
        % agonism effect on Plan units
    DA_req_unit_agon = -0.05;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units            
elseif (DA_runtype == DA_runtype_PRhypo1)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = -0.1;    
        % agonism effect on Plan units
    DA_req_unit_agon = -0.1;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units           
elseif (DA_runtype == DA_runtype_PRhypo15)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = -0.15;    
        % agonism effect on Plan units
    DA_req_unit_agon = -0.15;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units  
elseif (DA_runtype == DA_runtype_PRhypo2)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = -0.2;    
        % agonism effect on Plan units
    DA_req_unit_agon = -0.2;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units 
elseif (DA_runtype == DA_runtype_PRhypo3)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = -0.3;    
        % agonism effect on Plan units
    DA_req_unit_agon = -0.3;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units       
elseif (DA_runtype == DA_runtype_ghypo05)
    DA_global_agon = -0.05;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units            
elseif (DA_runtype == DA_runtype_ghypo1)
    DA_global_agon = -0.1;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units           
elseif (DA_runtype == DA_runtype_ghypo15)
    DA_global_agon = -0.15;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units  
elseif (DA_runtype == DA_runtype_ghypo2)
    DA_global_agon = -0.2;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units 
elseif (DA_runtype == DA_runtype_ghypo3)
    DA_global_agon = -0.3;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units   
elseif (DA_runtype == DA_runtype_NShyper05)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0.05;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0.05;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_NShyper1)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0.1;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0.1;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_NShyper3)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0.3;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0.3;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_NShyper5)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0.5;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0.5;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units       
elseif (DA_runtype == DA_runtype_Bhyper05)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0.05;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0.05; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_Bhyper1)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0.1;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0.1; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_Bhyper3)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0.3;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0.3; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_Bhyper5)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0.5;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0.5; 
        % agonism effect on babble striatal NoGo units  
 elseif (DA_runtype == DA_runtype_PRhyper05)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0.05;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0.05;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_PRhyper1)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0.1;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0.1;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_PRhyper3)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0.3;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0.3;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_PRhyper5)
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0.5;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0.5;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units   
elseif (DA_runtype == DA_runtype_ghyper05)
    DA_global_agon = 0.05;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_ghyper1)
    DA_global_agon = 0.1;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_ghyper3)
    DA_global_agon = 0.3;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
elseif (DA_runtype == DA_runtype_ghyper5)
    DA_global_agon = 0.5;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units
else  % normal DA
    DA_global_agon = 0;       
        % global effect (applied to all downstream targets)
    DA_plan_unit_agon = 0;    
        % agonism effect on Plan units
    DA_req_unit_agon = 0;     
        % agonism effect on Request units
    DA_nodshake_go_agon = 0;    
        % agonism effect on nod/shake striatal Go units
    DA_nodshake_nogo_agon = 0;  
        % agonism effect on nod/shake striatal NoGo units
    DA_babble_go_agon = 0;   
        % agonism effect on babble striatal Go units
    DA_babble_nogo_agon = 0; 
        % agonism effect on babble striatal NoGo units      
end;

% Override the load_trained_wts setting, if we're running a fresh model.
if (fresh_model == 1)
    load_trained_wts = 0;
end;

%
% Initialize the babble apparatus.
%

% Initialize frustration unit.
tonic_DA_frust_wt = 0.018;
babble_exec_frust_inhib_wt = 1.0;
reward_frust_inhib_wt = 1.0;
reward_cue_frust_inhib_wt = 0.005;
frustration_level = 0.0;
frust_peak_latency = 30000.0; % time for frustration to peak from 0 (in ms)
frust_peak_latency = 20000.0;
frust_peak_latency = 40000.0;
frust_inc = iter_duration / frust_peak_latency;
frust_bhvr_reset = 0;

% Initialize babble counters and parameters.
babble_count = 0;
nod_babble_count = 0;
shake_babble_count = 0;
nod_shake_babble_count = 0;
last_babble_start_iter = 0;
babble_exec_act = 0.0;
babble_iter_dur = 25;
babble_refrac_dur = 50;
babble_iter_count = -babble_refrac_dur;
babble_dice_set_thresh = 0.5;
% babble_dice_unset_gain = 10;
% babble_dice_set_gain = 20;
babble_dice_unset_gain = 6;
babble_dice_set_gain = 40;

% Load model parameters (connectivity and cell/channel-types).
if (load_trained_wts == 1)
    load(train_model_fname);
else
    load(start_model_fname);
end;

% Load physiological parameters (cells and channels).
load(phys_fname);

% Get indices for different parts of the model.
get_cog_model_indices;

% Get the CT number for the babble dice cell type.
babble_dice_CT = Cell_type(BabbleDice_ind);

%
% Initialize the neural dice apparatus.
%
neural_dice_CT = Cell_type(NeuralDiceE_ind);
neural_dice_set_thresh = 0.5;
neural_dice_set = 0.0;
neural_dice_gate = 0.0;
neural_dice_iter_count = 0;
nd_throw_duration = 5;
nd_set_duration = 40;
dice_unset_gain = 6;
dice_set_gain = 40;

%
% Initialize the adaptive critic apparatus.
%

% num_color_CS = 4;
% num_tones_CS = 12;
% num_CS = num_color_CS + num_tones_CS;
% num_rew_delays = 40;
% min_rew_delay = 10;   % in iterations
% CS_activs = zeros(num_CS,1);
% CS_past_activs = zeros(num_CS,1);
% CS_thresh = 0.8;
% rew_pred_out = zeros(num_rew_delays,1);
% rew_pred_netin = zeros(num_rew_delays,1);
% rew_pred_color_CW_ind = zeros(num_rew_delays,num_color_CS);
% rew_pred_tones_CW_ind = zeros(num_rew_delays,num_tones_CS);
% rew_pred_CW_ind = zeros(num_rew_delays,num_CS);
% rew_pred_wts = zeros(num_rew_delays,num_CS);
% rew_pred_ic_ct = zeros(num_rew_delays,num_CS);
% rew_pred_act_wts = zeros(num_rew_delays,num_CS);
% rew_pred_wt_elig_ind = zeros(1,num_CS * num_rew_delays);
% rew_pred_wt_elig = zeros(1,num_CS * num_rew_delays);
% DA_rew_pred_wts = zeros(num_rew_delays,1);
% tonic_DA_input = 0.2;

%
% Load the rew_pred_CW_ind indices
%

% % Find the index for the first connection of the desired fascicle.
% first_conn_ind = 1;
% for xx = 1:Color_WMtoRewPred_ind - 1
%     first_conn_ind = first_conn_ind + NC(xx);
% end;
% 
% % Get the connection to and from addresses and the weights for the desired 
% % fascicle.
% addr = double(CA(:,first_conn_ind:first_conn_ind + ...
%     NC(Color_WMtoRewPred_ind) - 1));
% 
% % Subtract the unit offsets to get the relative connection addresses.
% addr(1,:) = addr(1,:) - unit_offset(Conn_fromto(Color_WMtoRewPred_ind,2));
% addr(2,:) = addr(2,:) - unit_offset(Conn_fromto(Color_WMtoRewPred_ind,1));
% 
% % For each reward prediction unit (with a different delay)...
% for to_ind = 1:Area_xy(Conn_fromto(Color_WMtoRewPred_ind,2),3) 
%     % For all connections to this unit, save the value of the address into
%     % CA and CW so we can use it later.
%     for xx = 1:size(addr,2)
%         if (addr(1,xx) == to_ind)
%             rew_pred_color_CW_ind(to_ind,addr(2,xx)) = first_conn_ind + xx - 1;
%         end;
%     end;
% end;
% 
% % Find the index for the first connection of the desired fascicle.
% first_conn_ind = 1;
% for xx = 1:Tones_WMtoRewPred_ind - 1
%     first_conn_ind = first_conn_ind + NC(xx);
% end;
% 
% % Get the connection to and from addresses and the weights for the desired 
% % fascicle.
% addr = double(CA(:,first_conn_ind:first_conn_ind + ...
%     NC(Tones_WMtoRewPred_ind) - 1));
% 
% % Subtract the unit offsets to get the relative connection addresses.
% addr(1,:) = addr(1,:) - unit_offset(Conn_fromto(Tones_WMtoRewPred_ind,2));
% addr(2,:) = addr(2,:) - unit_offset(Conn_fromto(Tones_WMtoRewPred_ind,1));
% 
% % For each reward prediction unit (with a different delay)...
% for to_ind = 1:Area_xy(Conn_fromto(Tones_WMtoRewPred_ind,2),3) 
%     % For all connections to this unit, save the value of the address into
%     % CA and CW so we can use it later.
%     for xx = 1:size(addr,2)
%         if (addr(1,xx) == to_ind)
%             rew_pred_tones_CW_ind(to_ind,addr(2,xx)) = first_conn_ind + xx - 1;
%         end;
%     end;
% end;
% 
% rew_pred_CW_ind = [ rew_pred_color_CW_ind rew_pred_tones_CW_ind ];

%
% Load the DA weights
%

% Find the weight for the tonic DA to DA fascicle.
first_conn_ind = 1;
for xx = 1:TonicDAtoDASig_ind - 1
    first_conn_ind = first_conn_ind + NC(xx);
end;
DA_tonic_input_wt = CW(first_conn_ind);

% Find the weight for the reward input to DA fascicle.
first_conn_ind = 1;
for xx = 1:RewIntoDASig_ind - 1
    first_conn_ind = first_conn_ind + NC(xx);
end;
reward_input_wt = CW(first_conn_ind);

% % Find the weight for the reward cue to DA fascicle.
% first_conn_ind = 1;
% for xx = 1:RewCuetoDASig_ind - 1
%     first_conn_ind = first_conn_ind + NC(xx);
% end;
% DA_rew_cue_wt = CW(first_conn_ind);
%     
% % Find the weights for the reward prediction to DA fascicle.
% first_conn_ind = 1;
% for xx = 1:RewPredtoDASig_ind - 1
%     first_conn_ind = first_conn_ind + NC(xx);
% end;
% last_conn_ind = first_conn_ind + NC(RewPredtoDASig_ind) - 1;
% DA_rew_pred_wts = CW(first_conn_ind:last_conn_ind)';

% Find the weight for the novelty signal to DA fascicle.
first_conn_ind = 1;
for xx = 1:NoveltytoDASig_ind - 1
    first_conn_ind = first_conn_ind + NC(xx);
end;
novelty_input_wt = CW(first_conn_ind);

% Find the weight for the punisher input to DA fascicle.
first_conn_ind = 1;
for xx = 1:PunishIntoDASig_ind - 1
    first_conn_ind = first_conn_ind + NC(xx);
end;
punish_input_wt = CW(first_conn_ind);

% Find the weight for the frustration input to DA fascicle.
first_conn_ind = 1;
for xx = 1:FrusttoDASig_ind - 1
    first_conn_ind = first_conn_ind + NC(xx);
end;
DA_frust_wt = CW(first_conn_ind);

%
% Perform lesions / weight resets if desired.
%

% Look for specific fascicles to lesion.
for xx = 1:size(Conn_name,1)
    the_conn_name = sscanf(Conn_name(xx,:),'%s');
    if (strcmp(the_conn_name, 'NodInittoNoGo'))
        fasc_ind1 = xx;
    elseif (strcmp(the_conn_name, 'ShakeInittoNoGo'))
        fasc_ind2 = xx;         
    end;
end;

% Lesion them.
% fasc_ind = NodInittoNoGo_ind;
% lesion_val = 0.4;
% lesion_wts;
% fasc_ind = ShakeInittoNoGo_ind;
% lesion_val = 0.4;
% lesion_wts;  
    
% If we need to lesion the babble connections, do so.
if (babble_lesioned)
    fasc_ind = BabbletoPlanE_ind;
    lesion_wts;
    fasc_ind = BabbletoNodReqE_ind;
    lesion_wts;  
    fasc_ind = BabbletoShakeReqE_ind;
    lesion_wts;      
end;

% If we need to reset the NoGo weights, do so.
if (reset_nogo_wts)
    fasc_ind = Color_WMtoNNoGo_ind;
    lesion_val = 0.001;
    lesion_wts;
    fasc_ind = Tones_WMtoNNoGo_ind;
    lesion_val = 0.001;
    lesion_wts;
    fasc_ind = Color_WMtoSNoGo_ind;
    lesion_val = 0.001;
    lesion_wts;
    fasc_ind = Tones_WMtoSNoGo_ind;
    lesion_val = 0.001;
    lesion_wts;    
end;

%
% Prepare learning algorithm.
%

% Find the indices for the modifiable (i.e., learning) connections.
[a mdc] = find(MOD(CH));  

if ((~isempty(mdc)) && (learning_on == 1))
	% Find the indices for the modifiable connection fascicle indices.
	[a mdf] = find(MOD(Chan_type));
	
	% Get the list (with replications removed) of all indices of units containing
	% modifiable input weights.
	mdu = unique(CA(1,mdc));
end;

% Find indices mapping each connection to the corresponding index to mdc (0
% if no such connection exists).
Cmdc_ind = zeros(1,size(CW,2));
for xx = 1:size(CW,2)
    the_ind = find(mdc == xx);
    if (isempty(the_ind))
        Cmd_ind(xx) = 0;
    else
        Cmdc_ind(xx) = the_ind;
    end;
end;

% Initialize the modifiable weight values.
modCW = zeros(size(mdc,2),num_iters);
for iter = 1:num_iters
    modCW(:,iter) = CW(mdc)';
end;

% Initialize the indices to DA effect units that mediate agonism effects.
DAeff_learn_units = zeros(1,size(eligib_duration,2));
DAeff_learn_units(Chan_type(VisStimtoPlan_ind)) = DAPlanEffUnit_ind;
DAeff_learn_units(Chan_type(PlantoNodReqE_ind)) = DAReqEffUnit_ind;
DAeff_learn_units(Chan_type(Color_WMtoNGo_ind)) = DANodShakeGoEffUnit_ind;
DAeff_learn_units(Chan_type(Color_WMtoNNoGo_ind)) = DANodShakeNoGoEffUnit_ind;
DAeff_learn_units(Chan_type(Color_WMtoBGo_ind)) = DABabbleGoEffUnit_ind;
DAeff_learn_units(Chan_type(Color_WMtoBNoGo_ind)) = DABabbleNoGoEffUnit_ind;

% Initialize the eligibility traces.
elig_trace = zeros(size(mdc,2),num_iters);
elig_iter_count = zeros(size(mdc,2),1);
% rew_pred_wt_elig_ind = [];
% for xx = 1:num_CS
%     for yy = 1:num_rew_delays
%         rew_pred_wt_elig_ind = [rew_pred_wt_elig_ind find(mdc == ...
%             rew_pred_CW_ind(yy,xx))];
%     end;
% end;

%
% Initialize the apparatus for disabling eligibility traces of NoGo units.
%

elig_disable = zeros(size(mdc,2),1);
NoGo_thal_elig_thresh = 0.20;   % threshold thalamic input has to clear to 
                                % enable eligibility trace
num_NoGo_units = NU(NodNoGo_ind) + NU(ShakeNoGo_ind) + NU(BabbleNoGo_ind);
num_NoGo_learn_affs = NU(ColorMem_ind) + NU(TonesMem_ind);
NoGo_wt_inds = zeros(num_NoGo_units,1);
NoGo_thal_in_unit_inds = zeros(num_NoGo_units,1);
NoGo_elig_dis_wt_inds = zeros(num_NoGo_units,num_NoGo_learn_affs);
curr_unit = 1;

% Get the fanout weight indices for Nod Init to Nod NoGo fascicle.
fasc_ind = NodInittoNoGo_ind;
fanin = 0;
x_ind = 1;
y_ind = 1;
fetch_cell_wt_inds;
InittoNoGo_fanout_inds = wt_inds;
NoGo_x_size = size(wt_inds,2);
NoGo_y_size = size(wt_inds,1);

% For each Nod NoGo unit...
for xx = 1:NoGo_x_size
    for yy = 1:NoGo_y_size
        % Get the fanin weight indices for the color working memory.
        fasc_ind = Color_WMtoNNoGo_ind;
        fanin = 1;
        x_ind = xx;
        y_ind = yy;
        fetch_cell_wt_inds;
        dis_wt_inds = reshape(wt_inds,1,NU(ColorMem_ind));
        
        % Get the fanin weight indices for the tones working memory.        
        fasc_ind = Tones_WMtoNNoGo_ind;
        fanin = 1;
        x_ind = xx;
        y_ind = yy;
        fetch_cell_wt_inds;
        dis_wt_inds = [ dis_wt_inds reshape(wt_inds,1,NU(TonesMem_ind)) ];
        
        % Save the indices for the current unit.
        NoGo_wt_inds(curr_unit) = InittoNoGo_fanout_inds(xx,yy);
        NoGo_thal_in_unit_inds(curr_unit) = NodInitUnit_ind;
        NoGo_elig_dis_wt_inds(curr_unit,:) = Cmdc_ind(dis_wt_inds);
        
        % Increment the current unit.
        curr_unit = curr_unit + 1;
    end;
end;

% Get the fanout weight indices for Shake Init to Shake NoGo fascicle.
fasc_ind = ShakeInittoNoGo_ind;
fanin = 0;
x_ind = 1;
y_ind = 1;
fetch_cell_wt_inds;
InittoNoGo_fanout_inds = wt_inds;
NoGo_x_size = size(wt_inds,2);
NoGo_y_size = size(wt_inds,1);

% For each Shake NoGo unit...
for xx = 1:NoGo_x_size
    for yy = 1:NoGo_y_size
        % Get the fanin weight indices for the color working memory.
        fasc_ind = Color_WMtoSNoGo_ind;
        fanin = 1;
        x_ind = xx;
        y_ind = yy;
        fetch_cell_wt_inds;
        dis_wt_inds = reshape(wt_inds,1,NU(ColorMem_ind));
        
        % Get the fanin weight indices for the tones working memory.        
        fasc_ind = Tones_WMtoSNoGo_ind;
        fanin = 1;
        x_ind = xx;
        y_ind = yy;
        fetch_cell_wt_inds;
        dis_wt_inds = [ dis_wt_inds reshape(wt_inds,1,NU(TonesMem_ind)) ];
        
        % Save the indices for the current unit.
        NoGo_wt_inds(curr_unit) = InittoNoGo_fanout_inds(xx,yy);
        NoGo_thal_in_unit_inds(curr_unit) = ShakeInitUnit_ind;
        NoGo_elig_dis_wt_inds(curr_unit,:) = Cmdc_ind(dis_wt_inds);
        
        % Increment the current unit.
        curr_unit = curr_unit + 1;
    end;
end;

% Get the fanout weight indices for Babble Init to Babble NoGo fascicle.
fasc_ind = BabbleInittoNoGo_ind;
fanin = 0;
x_ind = 1;
y_ind = 1;
fetch_cell_wt_inds;
InittoNoGo_fanout_inds = wt_inds;
NoGo_x_size = size(wt_inds,2);
NoGo_y_size = size(wt_inds,1);

% For each Babble NoGo unit...
for xx = 1:NoGo_x_size
    for yy = 1:NoGo_y_size
        % Get the fanin weight indices for the color working memory.
        fasc_ind = Color_WMtoBNoGo_ind;
        fanin = 1;
        x_ind = xx;
        y_ind = yy;
        fetch_cell_wt_inds;
        dis_wt_inds = reshape(wt_inds,1,NU(ColorMem_ind));
        
        % Get the fanin weight indices for the tones working memory.        
        fasc_ind = Tones_WMtoBNoGo_ind;
        fanin = 1;
        x_ind = xx;
        y_ind = yy;
        fetch_cell_wt_inds;
        dis_wt_inds = [ dis_wt_inds reshape(wt_inds,1,NU(TonesMem_ind)) ];
        
        % Save the indices for the current unit.
        NoGo_wt_inds(curr_unit) = InittoNoGo_fanout_inds(xx,yy);
        NoGo_thal_in_unit_inds(curr_unit) = BabbleInitUnit_ind;
        NoGo_elig_dis_wt_inds(curr_unit,:) = Cmdc_ind(dis_wt_inds);
        
        % Increment the current unit.
        curr_unit = curr_unit + 1;
    end;
end;

%
% Initialize the weight renormalization algorithm.
%

max_arbor_size = 64;
num_norm_arbors = 1;
norm_arbor_wt_ind = zeros(1,max_arbor_size);
norm_arbor_size = [];
norm_arbor_maxtotwt = [];

% Find all of the connection types that need normalizing and for each...
norm_arbor_conntypes = find(maxtotwt > 0.0);
for xx = 1:size(norm_arbor_conntypes,2)
    % Find the destination units the connection type has.
    learn_CH = norm_arbor_conntypes(xx);
    learn_conns = (CH == learn_CH);
    learn_maxtotwt = maxtotwt(learn_CH); 
    learn_dest_units = unique(double(CA(1,:)) .* learn_conns);
    learn_dest_units(1) = [];
    
    % For each of the destination units, find the indices to CW for the
    % entire arbor.
    for yy = 1:size(learn_dest_units,2)
        dest_match_conns = (CA(1,:) == learn_dest_units(yy));
        norm_wt_ind = find(dest_match_conns .* learn_conns);
        norm_arbor_wt_ind(num_norm_arbors,1:size(norm_wt_ind,2)) = ...
            norm_wt_ind;  
        norm_arbor_size = [norm_arbor_size size(norm_wt_ind,2)];
        norm_arbor_maxtotwt = [norm_arbor_maxtotwt learn_maxtotwt];
        norm_arbor_wt_ind = [norm_arbor_wt_ind; zeros(1,max_arbor_size)];
        num_norm_arbors = num_norm_arbors + 1;   
    end;
end;

% Trim the last (null) arbor off.
norm_arbor_wt_ind(num_norm_arbors,:) = [];       
num_norm_arbors = num_norm_arbors - 1;

%
% Initialize DA modulation algorithm.
%
mid_DA_thresh = thresh;
mid_DA_gain = gain;
norm_DA_level = 0.37;
DA_thresh_scale_gain = 9;
DA_gain_scale_gain = 9;
modDA_CTind = find(DA_out_mod > 0);  % find CT indices where DA affects
DAeff_mod_units = zeros(1,size(thresh,2));
DAeff_mod_units(Cell_type(NodGoE_ind)) = DANodShakeGoEffUnit_ind;
DAeff_mod_units(Cell_type(NodNoGo_ind)) = DANodShakeNoGoEffUnit_ind;
DAeff_mod_units(Cell_type(BabbleGoE_ind)) = DABabbleGoEffUnit_ind;
DAeff_mod_units(Cell_type(BabbleNoGo_ind)) = DABabbleNoGoEffUnit_ind;

% Initialize the array for adjusting thresholds for each cell.
thresh_adj = zeros(1,sum(NU));

% Initialize the kWTA algorithm.
max_pool_size = 128;
num_kWTA_area_pools = 1;
kWTA_pool_unit_inds = zeros(1,max_pool_size);
kWTA_pool_sizes = [];
kWTA_pool_kvals = [];
kWTA_pool_thresh_inds = [];
for area_ind = 1:Num_areas
    k = kWTA(Cell_type(area_ind));
    if (k > 0)
        fetch_area_unit_inds;
        num_units = size(unit_inds,1) * size(unit_inds,2);
        pool_unit_inds = reshape(unit_inds,1,num_units);
        kWTA_pool_unit_inds(num_kWTA_area_pools,1:num_units) = ...
            pool_unit_inds;  
        kWTA_pool_sizes = [kWTA_pool_sizes num_units];
        kWTA_pool_kvals = [kWTA_pool_kvals k];
        kWTA_pool_thresh_inds = [kWTA_pool_thresh_inds Cell_type(area_ind)]; 
        kWTA_pool_unit_inds = [kWTA_pool_unit_inds; zeros(1,max_pool_size)];
        num_kWTA_area_pools = num_kWTA_area_pools + 1;
    end;
end;
for xx = 1:size(pooled_kWTA,2)
    pk = pooled_kWTA(xx);
    if (pk > 0)
        new_num_units = 0;
        new_pool_unit_inds = [];
        for area_ind = 1:Num_areas
            if (Cell_type(area_ind) == xx)
                fetch_area_unit_inds;           
                num_units = size(unit_inds,1) * size(unit_inds,2);
                pool_unit_inds = reshape(unit_inds,1,num_units);
                new_num_units = new_num_units + num_units;
                new_pool_unit_inds = [new_pool_unit_inds pool_unit_inds];
            end;
        end;       
        kWTA_pool_unit_inds(num_kWTA_area_pools,1:new_num_units) = ...
            new_pool_unit_inds;        
        kWTA_pool_sizes = [kWTA_pool_sizes new_num_units];
        kWTA_pool_kvals = [kWTA_pool_kvals pk];       
        kWTA_pool_thresh_inds = [kWTA_pool_thresh_inds Cell_type(area_ind)];       
        kWTA_pool_unit_inds = [kWTA_pool_unit_inds; zeros(1,max_pool_size)];
        num_kWTA_area_pools = num_kWTA_area_pools + 1;        
    end;
end;

% Trim the last (null) pool off.
kWTA_pool_unit_inds(num_kWTA_area_pools,:) = [];       
num_kWTA_area_pools = num_kWTA_area_pools - 1;

%
% Initialize vectors for unit activity.
% NOTE: Spast and S are ordered so that activity is drawn column-wise 
% from the areas.
%
Spast = init_unit_noise .* rand(1,sum(NU));      
    % random uniform distribution 0 to 1 * noise factor

% Initialize output data arrays.
output = zeros(sum(NU),num_iters);

% Initialize saved threshold arrays.
base_threshs = zeros(sum(NU),num_iters);
thresh_adjs = zeros(sum(NU),num_iters);