%
% init_simrun.m
%
% Initialize the PISHTAR simulation, setting the simulation parameters.
% Note that the "types" (numbers given text labels) are defined in the
% caller, run_pantilt_sim.m.
%
% Last modification: 8/30/07


% Parameters here for ease of editing...
num_iters = 1000;
% simrun_type = simrun_blue_select;
% simrun_type = simrun_red_select;
% simrun_type = simrun_combo_taskset;
simrun_type = simrun_combo_rev_taskset;
% simrun_type = simrun_c_tone_reward;
% simrun_type = simrun_c_tone_punish;
stim_choices = 2;
task_choices = 2;
brain_type = brain_cog_model;
% brain_type = brain_rule_based;
active_reaction = 1;    % blue select rule-based brain
% active_reaction = 5;    % combo taskset rule-based brain
reward_delivery_pct = 100;    % percentage of rewards delivered
punish_delivery_pct = 100;    % percentage of punishers delivered
punish_strictness = ptrigger_wrong;
punish_opposites = 1;
punish_delays = 0;
punish_nodshakes = 0;
punish_extras = 0;
punish_blinds = 0;
punish_misses = 0;

% Read in simulation run script arguments and use them if they exist.
nargs = size(sr_sargs,2);
if (nargs >= 2)
    stim_choices = sr_sargs(1);
    task_choices = sr_sargs(2);    
end;
    
if (stim_choices == 1)
    blue_stim_chance = 1;
    red_stim_chance = 1;
    green_stim_chance = 1;
    yellow_stim_chance = 1;
    violet_stim_chance = 0;
elseif (stim_choices == 2)
    blue_stim_chance = 1;
    red_stim_chance = 0;
    green_stim_chance = 0;
    yellow_stim_chance = 0;
    violet_stim_chance = 0;
elseif (stim_choices == 3)
    blue_stim_chance = 0;
    red_stim_chance = 1;
    green_stim_chance = 0;
    yellow_stim_chance = 0;
    violet_stim_chance = 0;
elseif (stim_choices == 4)
    blue_stim_chance = 0;
    red_stim_chance = 0;
    green_stim_chance = 1;
    yellow_stim_chance = 0;
    violet_stim_chance = 0;
elseif (stim_choices == 5)
    blue_stim_chance = 0;
    red_stim_chance = 0;
    green_stim_chance = 0;
    yellow_stim_chance = 1;
    violet_stim_chance = 0;    
elseif (stim_choices == 6)
    blue_stim_chance = 1;
    red_stim_chance = 1;
    green_stim_chance = 0;
    yellow_stim_chance = 0;
    violet_stim_chance = 0;    
end;

if (task_choices == 1)
    blue_select_chance = 1;
    red_select_chance = 1;
elseif (task_choices == 2)
    blue_select_chance = 1;
    red_select_chance = 0; 
elseif (task_choices == 3)
    blue_select_chance = 0;
    red_select_chance = 1;      
end;

% Set general simulation parameters.
% num_iters = 1000;         % number of iterations in simulation (maximum)
iter_duration = 100.0;    % duration of each iteration (in ms)
scene_width = 128;        % width of visual environment in pixels
scene_height = 128;       % height of visual environment in pixels
% simrun_type = simrun_blue_select;
% simrun_type = simrun_red_select;
% simrun_type = simrun_dms_select;
% simrun_type = simrun_dnms_select;
% simrun_type = simrun_combo_taskset;
monitor_interval = 100;   % increment of iterations at which we report how 
                          % much time has elapsed
display_scene = 0;        % do we display the scene iterations for the user?
get_key_input = 0;        % do we look for keyboard input from the user?

% Set visual stimulus parameters.
load square_stim;  % loads stim_shape (16 x 16 square)
% stim_shape = ones(64);  % make a bigger stimulus for the time being
vis_stim_duration = 3000;  % visual stimulus duration (in ms)
stim_speed = 80;          % stimulus speed (in pixels / sec.)
% stim_all_behavior = bhvr_centerdrop;
stim_all_behavior = bhvr_rnddrop;
% blue_stim_chance = 4;
% red_stim_chance = 1;
% green_stim_chance = 1;
% yellow_stim_chance = 1;
% violet_stim_chance = 1;

% Set tone stimulus paramaters.
tone_stim_duration = 500;     % tone stimulus duration (in ms)

% Set color working memory parameters.
color_mem_duration = 10000;   % color working memory duration (in ms)
color_mem_duration = 5000;

% Set tone working memory parameters.
tones_mem_duration = 25000;   % tones working memory duration (in ms)
tones_mem_duration = 100000;

% Set delay period parameters.
delay_duration = 2500;        % delay period duration (in ms)

% Set reinforcement parameters.
require_foveate = 1;          % does subject need to foveate on visual 
                              % stimuli before responding to be rewarded?
nod_seen_thresh = 15;         % number of Nod iterations needed to detect
shake_seen_thresh = 15;       % number of Shake iterations needed to detect
reward_duration = 500.0;      % duration of reward deliveries (in ms)
reinf_delay_dur = 1500.0;     % duration after stimulus disappears (in ms) 
                              % that a reward or punisher will still be 
                              % delivered on a correct response
stim_rew_delay_dur = 1000.0;  % duration of delay between stimulus onset
                              % and reward delivery
% reinf_delay_dur = 3500.0;
% stim_rew_delay_dur = 3500.0;  
punish_duration = 500.0;      % duration of punisher deliveries (in ims)
stim_pun_delay_dur = 3500.0;  % duration of delay between stimulus onset
                              % and punisher delivery
                              
if ((simrun_type == simrun_c_tone_reward) || ...
        (simrun_type == simrun_c_tone_reward))
    delay_duration = 4500;     % delay period duration (in ms)
    reinf_delay_dur = 3500.0;
    stim_rew_delay_dur = 3500.0;
    tones_mem_duration = 4500;
end;
    
% Set novelty parameters.
max_num_color_novs = 3;    % number of times a color stimulus will be 
                           % regarded as novel
max_num_tones_novs = 3;    % number of times a tone stimulus will be 
                           % regarded as novel
novelty_duration = 500.0;  % duration of novelty signals (in ms)

% Set camera "body" parameters.
camera_width = 64;
camera_height = 64;
fovea_width = 16;
fovea_height = 16;
pan_speed = 100;        % pan motor speed (in pixels / sec.)
tilt_speed = 100;       % tilt motor speed (in pixels / sec.)

% Set brain parameters.
% brain_type = brain_rule_based;
% brain_type = brain_null_model;
% brain_type = brain_cog_model;

% Initialize current simulation state.
stim_on = 0;
stim_x = 1;
stim_y = 1;
stim_x_velocity = 0;
stim_y_velocity = 0;
stim_shape_type = shape_none;
stim_color_type = color_blue;
stim_red = 0.0;
stim_green = 0.0;
stim_blue = 1.0;
stim_behavior = stim_all_behavior;
prev_stim_behavior = stim_all_behavior;
tones_on = zeros(12,1);
reward_on = 0;
reward_timer = 0;  % in ms
reward_trigger = rtrigger_none;
reinf_delay_on = 0;
reinf_delay_timer = 0;      % how long after the last stimulus do we have 
                            % to respond with reinforcement?
stim_rew_delay_timer = 0;   % how long before we deliver delayed reward?
reward_delivered = 0;       % has reward already been delivered?
punish_on = 0;
punish_timer = 0;  % in ms
punish_trigger = ptrigger_none;
stim_pun_delay_timer = 0;   % how long before we deliver delayed punisher?
punish_delivered = 0;       % has punisher already been delivered?
novelty_on = 0;
novelty_timer = 0;  % in ms
last_stim_start_iter = 0;
last_nod_start_iter = 0;
last_shake_start_iter = 0;
last_nod_end_iter = 0;
last_shake_end_iter = 0;
curr_event_type = event_null;
last_event_type = event_null;
curr_event_timer = 0;
events_count = 0;
stim_on_sv = zeros(1,num_iters);
stim_x_sv = zeros(1,num_iters);
stim_y_sv = zeros(1,num_iters);
stim_red_sv = zeros(1,num_iters);
stim_green_sv = zeros(1,num_iters);
stim_blue_sv = zeros(1,num_iters);
tones_on_sv = zeros(12,num_iters);
reward_on_sv = zeros(1,num_iters);
reward_trigger_sv = zeros(1,num_iters);
reward_delivered_sv = zeros(1,num_iters);
punish_on_sv = zeros(1,num_iters);
punish_trigger_sv = zeros(1,num_iters);
punish_delivered_sv = zeros(1,num_iters);
novelty_on_sv = zeros(1,num_iters);
mem_color_map_sv = zeros(4,num_iters);
tones_mem_sv = zeros(12,num_iters);

% Initialize trial performance parameters.
target_count = 0;
distractor_count = 0;
delay_count = 0;
reward_count = 0;
punish_count = 0;
target_nod = [];
target_shake = [];
target_x_nod = [];
target_nod_shake = [];
target_miss = [];
distractor_nod = [];
distractor_shake = [];
distractor_x_shake = [];
distractor_nod_shake = [];
distractor_miss = [];
delay_nod = [];
delay_shake = [];
delay_nod_shake = [];
blind_nod = [];
blind_shake = [];

% Initialize current body state.  The camera starts in the center of the 
% scene and is stationary and not avatared.  ('Avatared' is game-programming
% terminology meaning the manifestation of the moving object is under human
% user control.)
pan_velocity = 0;
tilt_velocity = 0;
camera_x = 1 + (scene_width - camera_width) / 2.0;
camera_y = 1 + (scene_height - camera_height) / 2.0;
camera_x_sv = zeros(1,num_iters);
camera_y_sv = zeros(1,num_iters);

% Initialize input part of brain.
retina_rods = zeros(64);
retina_cones = zeros(16,16,3);
color_map = zeros(4,1);
past_color_map = zeros(4,1);
mem_color_map = zeros(4,1);
color_mem_timer = 0;
novcount_color_map = ones(4,1);
novcount_color_map = novcount_color_map .* max_num_color_novs;
tones_map = zeros(12,1);
past_tones_map = zeros(12,1);
mem_tones_map = zeros(12,1);
tones_mem_timer = 0;
novcount_tones = ones(12,1);
novcount_tones = novcount_tones .* max_num_tones_novs;
% reward_on = 0;           % defined earlier, but also part of brain
% track_execute = 0;       % primarily output, but also input
% nod_execute = 0;         % primarily output, but also input
% shake_execute = 0;       % primarily output, but also input

% Initialize output part of brain.
track_execute = 0;
nod_execute = 0;
nod_centered = 0;
nod_iter_count = 0;
nod_phase = 1;
shake_execute = 0;
shake_centered = 0;
shake_iter_count = 0;
shake_phase = 1;
track_execute_sv = zeros(1,num_iters);
nod_execute_sv = zeros(1,num_iters);
shake_execute_sv = zeros(1,num_iters);

% Calculate probability thresholds for different stimuli.
total_chance = blue_stim_chance + red_stim_chance + green_stim_chance + ...
    yellow_stim_chance + violet_stim_chance;
blue_stim_thresh = blue_stim_chance / total_chance;
red_stim_thresh = blue_stim_thresh + (red_stim_chance / total_chance);
green_stim_thresh = red_stim_thresh + (green_stim_chance / total_chance);
yellow_stim_thresh = green_stim_thresh + (yellow_stim_chance / total_chance);

% Calculate probability thresholds for different tasks. 
total_chance = blue_select_chance + red_select_chance;
blue_select_thresh = blue_select_chance / total_chance;
red_select_thresh = blue_select_thresh + (red_select_chance / total_chance);