%
% make_disp_fig.m
%
% Create a figure window which will display the data.  load_pantilt_sim.m 
% needs to be run first.
%
% Last modification: 4/29/08


%
% Set up user-selected initial variables.
%

% Choose the set of things to be plotted.
% plot_set = 1;   % basic simulation
plot_set = 2;   % complex simulation
% plot_set = 3;   % Plan and Nod/Shake Request unit activation
% plot_set = 4;   % Nod Go activation (part)
% plot_set = 5;   % Nod Go activation (full)
% plot_set = 6;   % Nod NoGo activation (part)
% plot_set = 7;   % Nod NoGo activation (full)
% plot_set = 8;   % Shake Go activation (part)
% plot_set = 9;   % Shake Go activation (full)
% plot_set = 10;  % Shake NoGo activation (part)
% plot_set = 11;  % Shake NoGo activation (full)
% plot_set = 12;  % Babble Go activation (part)
% plot_set = 13;  % Babble Go activation (full)
% plot_set = 14;  % Babble NoGo activation (part)
% plot_set = 15;  % Babble NoGo activation (full)
% plot_set = 16;  % Neural dice activation
% plot_set = 17;  % Plan unit activation (focus)
% plot_set = 18;  % Request unit activation (focus)
% plot_set = 19;  % Nod / Shake / Babble learned activation
% plot_set = 20;  % Babble and Babble unit influence activation

% Precalculate fascicle net inputs.
do_precalc_fascins = 1;
if (do_precalc_fascins == 1)
    if ((isempty(who('precalc_fascins_done'))) || ...
            (precalc_fascins_done == 0))
        precalc_fascins;
    end;
end;

% Grab script arguments if they exist.
if (~isempty(who('st_sargs')))
    nargs = size(st_sargs,2);
    if (nargs > 0)
        plot_set = st_sargs(1);
    end;
end;

% Lay out the display.
% ID#  What it plots
% -------------------
%   1  Environment: camera panning and tilting around
%   2  Perifoveal (black and white) view
%   3  Motor execution units: Track, Nod, and Shake
%   4  Color units, both current and working memory
%   5  Tone units, both current and working memory
%   6  Reward and Punisher units
%   7  Novelty unit
%   8  Visual stimulus presence unit
%   9  Reward cue unit (excitatory)
%  10  Reward prediction units (NOT IMPLEMENTED YET)
%  11  DA signal unit
%  12  Frustration unit
%  13  Babble gating
%  14  Babble Request unit
%  15  Babble Go excitatory units
%  16  Babble Go inhibitory units
%  17  Babble NoGo units
%  18  Babble Init unit
%  19  Babble units
%  20  Plan units
%  21  Motor gating
%  22  Nod Request excitatory units
%  23  Nod Request inhibitory unit
%  24  Nod Go excitatory units
%  25  Nod Go inhibitory units
%  26  Nod NoGo units
%  27  Nod Init unit
%  28  Shake Request excitatory units
%  29  Shake Request inhibitory unit
%  30  Shake Go excitatory units
%  31  Shake Go inhibitory units
%  32  Shake NoGo units
%  33  Shake Init unit
%  34  Neural Noise units
%  35  Neural Dice units
%  36  Neural Gated Dice units
%  37  Neural Dice Set unit
%  38  Neural Dice Gate unit
%  39  Nod Request -> Nod Go (excitatory) fanout weights
%  40  RedWM -> Nod Go (excitatory) fanout weights 
%  41  GreenWM -> Nod Go (excitatory) fanout weights
%  42  BlueWM -> Nod Go (excitatory) fanout weights
%  43  YellowWM -> Nod Go (excitatory) fanout weights
%  44  CToneWM -> Nod Go (excitatory) fanout weights
%  45  EFlatToneWM -> Nod Go (excitatory) fanout weights
%  46  Nod Init -> Nod NoGo fanout weights
%  47  RedWM -> Nod NoGo fanout weights 
%  48  GreenWM -> Nod NoGo fanout weights
%  49  BlueWM -> Nod NoGo fanout weights
%  50  YellowWM -> Nod NoGo fanout weights
%  51  CToneWM -> Nod NoGo fanout weights
%  52  EFlatToneWM -> Nod NoGo fanout weights
%  53  Shake Request -> Shake Go (excitatory) fanout weights
%  54  RedWM -> Shake Go (excitatory) fanout weights 
%  55  GreenWM -> Shake Go (excitatory) fanout weights
%  56  BlueWM -> Shake Go (excitatory) fanout weights
%  57  YellowWM -> Shake Go (excitatory) fanout weights
%  58  CToneWM -> Shake Go (excitatory) fanout weights
%  59  EFlatToneWM -> Shake Go (excitatory) fanout weights
%  60  Shake Init -> Shake NoGo fanout weights
%  61  RedWM -> Shake NoGo fanout weights 
%  62  GreenWM -> Shake NoGo fanout weights
%  63  BlueWM -> Shake NoGo fanout weights
%  64  YellowWM -> Shake NoGo fanout weights
%  65  CToneWM -> Shake NoGo fanout weights
%  66  EFlatToneWM -> Shake NoGo fanout weights
%  67  Babble Request -> Babble Go (excitatory) fanout weights
%  68  RedWM -> Babble Go (excitatory) fanout weights 
%  69  GreenWM -> Babble Go (excitatory) fanout weights
%  70  BlueWM -> Babble Go (excitatory) fanout weights
%  71  YellowWM -> Babble Go (excitatory) fanout weights
%  72  CToneWM -> Babble Go (excitatory) fanout weights
%  73  EFlatToneWM -> Babble Go (excitatory) fanout weights
%  74  Babble Init -> Babble NoGo fanout weights
%  75  RedWM -> Babble NoGo fanout weights 
%  76  GreenWM -> Babble NoGo fanout weights
%  77  BlueWM -> Babble NoGo fanout weights
%  78  YellowWM -> Babble NoGo fanout weights
%  79  CToneWM -> Babble NoGo fanout weights
%  80  EFlatToneWM -> Babble NoGo fanout weights
%  81  VisStim -> Plan fanout weights
%  82  RedWM -> Plan fanout weights 
%  83  GreenWM -> Plan fanout weights
%  84  BlueWM -> Plan fanout weights
%  85  YellowWM -> Plan fanout weights
%  86  CToneWM -> Plan fanout weights
%  87  EFlatToneWM -> Plan fanout weights
%  88  Bias -> Plan fanout weights
%  89  Bias -> Nod Request fanout weights
%  90  Bias -> Shake Request fanout weights
%  91  Inputs -> Plan fanin weights
%  92  Nod Init -> Nod NoGo fascicle summed net input
%  93  Neural DiceE -> Nod NoGo fascicle summed net input
%  94  Color and Tone WM -> Nod NoGo fascicle summed net input
%  95  Total Nod NoGo fascicle summed net input
%  96  Shake Init -> Shake NoGo fascicle summed net input
%  97  Neural DiceE -> Shake NoGo fascicle summed net input
%  98  Color and Tone WM -> Shake NoGo fascicle summed net input
%  99  Total Shake NoGo fascicle summed net input
%  100 Nod Request -> Nod Go fascicle summed net input
%  101 Neural DiceE -> Nod Go fascicle summed net input
%  102 Color and Tone WM -> Nod Go fascicle summed net input
%  103 Total Nod Go fascicle summed net input
%  104 Shake Request -> Shake Go fascicle summed net input
%  105 Neural DiceE -> Shake Go fascicle summed net input
%  106 Color and Tone WM -> Shake Go fascicle summed net input
%  107 Total Shake Go fascicle summed net input
%  108 Babble Request -> Babble Go fascicle summed net input
%  109 Neural DiceE -> Babble Go fascicle summed net input
%  110 Color and Tone WM -> Babble Go fascicle summed net input
%  111 Total Babble Go fascicle summed net input
%  112 Babble Init -> Babble NoGo fascicle summed net input
%  113 Neural DiceE -> Babble NoGo fascicle summed net input
%  114 Color and Tone WM -> Babble NoGo fascicle summed net input
%  115 Total Babble NoGo fascicle summed net input
%  116 Inputs -> Plan fascicle summed net input
%  117 Babble -> Plan fascicle summed net input
%  118 Bias -> Plan fascicle summed net input
%  119 Total Plan fascicle summed net input
%  120 Plan -> Nod Request fascicle summed net input
%  121 Babble -> Nod Request fascicle summed net input
%  122 Bias -> Nod Request fascicle summed net input
%  123 Total Nod Request fascicle summed net input
%  124 Plan -> Shake Request fascicle summed net input
%  125 Babble -> Shake Request fascicle summed net input
%  126 Bias -> Shake Request fascicle summed net input
%  127 Total Shake Request fascicle summed net input

% This is the ordering in which the plots are to be shown...
switch(plot_set)
    case 1
        disp_plot_map = ...
            [ 1 2 3; ...
              4 5 6 ];
    case 2
        disp_plot_map = ...
            [ 1  6  7 11; ...
              4 20 21  3; ...
              5 13 19 12 ];         
    case 3
        disp_plot_map = ...
            [  8 81 120 121; ...
               4 84  82  22; ...
               5 86  87  28; ...
              19 20 124 125 ];           
    case 4
        disp_plot_map = ...
            [ 22 39  0  0; ...
              36 40 41 24; ...
               4 42 43 25; ...               
               5 44 45  0 ];            
    case 5
        disp_plot_map = ...
            [ 22 39 100 101; ...
              36 40  41 102; ...
               4 42  43 103; ...               
               5 44  45  24 ];              
    case 6
        disp_plot_map = ...
            [ 27 46  0  0; ...
              36 47 48 26; ...
               4 49 50  0; ...               
               5 51 52  0 ];               
    case 7
        disp_plot_map = ...
            [ 27 46 92 93; ...
              36 47 48 94; ...
               4 49 50 95; ...               
               5 51 52 26 ];           
    case 8
        disp_plot_map = ...
            [ 28 53  0  0; ...
              36 54 55 30; ...
               4 56 57 31; ...               
               5 58 59  0 ];        
    case 9
        disp_plot_map = ...
            [ 28 53 104 105; ...
              36 54  55 106; ...
               4 56  57 107; ...               
               5 58  59  30 ];        
    case 10
        disp_plot_map = ...
            [ 33 60  0  0; ...
              36 61 62 32; ...
               4 63 64  0; ...               
               5 65 66  0 ];  
    case 11
        disp_plot_map = ...
            [ 33 60 96 97; ...
              36 61 62 98; ...
               4 63 64 99; ...               
               5 65 66 32 ];  
    case 12
        disp_plot_map = ...
            [ 14 67  0  0; ...
              36 68 69 15; ...
               4 70 71 16; ...               
               5 72 73  0 ];
    case 13
        disp_plot_map = ...
            [ 14 67 108 109; ...
              36 68  69 110; ...
               4 70  71 111; ...               
               5 72  73  15 ];   
    case 14
        disp_plot_map = ...
            [ 18 74  0  0; ...
              36 75 76 17; ...
               4 77 78  0; ...               
               5 79 80  0 ];          
    case 15
        disp_plot_map = ...
            [ 18 74 112 113; ...
              36 75  76 114; ...
               4 77  78 115; ...               
               5 79  80  17 ];                    
    case 16
        disp_plot_map = ...
            [ 34 35 36; ...              
               0 37 38 ];          
    case 17
        disp_plot_map = ...
            [  8 81 116   0; ...
               4 84  82 119; ...
               5 86  87  20; ...
              19 88 117   0 ];  
    case 18
        disp_plot_map = ...
            [  8  20 122 123; ...
               4 120 121  22; ...
               5 124 125  28; ...
               0  19 126 127 ];   
    case 19
        disp_plot_map = ...
            [ 8 20 15 17; ...              
              4 22 24 26; ...
              5 28 30 32 ];       
    case 20
        disp_plot_map = ...
            [ 12 14 18; ...
              19 22 27; ...
              20 28 33 ];
end;
num_avail_plots = 127;

% 
% Set up figure for plotting.
%

% Set up the figure window.
l_fig_pos = 0.01;
b_fig_pos = 0.05;
fig_w = 0.9;
fig_h = 0.85;
fh = figure(1);
set(fh,'Units','normalized');
set(fh,'Position',[l_fig_pos b_fig_pos fig_w fig_h]);
colormap(gray);

% Set up iteration label.
iter_l_pos = 0.46;
iter_b_pos = 1 - 0.06;
iter_wid = 0.15;
iter_hgt = 0.04;
iter_label = annotation(...
    fh,'textbox',...
    'Position',[iter_l_pos iter_b_pos iter_wid iter_hgt],...
    'FitHeightToText','off',...
    'HorizontalAlignment','center',...
    'String',{'Iteration #1'});

% Lay out the subplots.
num_plots = size(disp_plot_map,1) * size(disp_plot_map,2);
subplot_inds = zeros(num_avail_plots,3);
for ii = 1:num_avail_plots
    [y x] = find(disp_plot_map == ii);
    subplot_inds(ii,1) = size(disp_plot_map,1);
    subplot_inds(ii,2) = size(disp_plot_map,2);
    if (isempty(x))
        subplot_inds(ii,3) = 0;
    else
        subplot_inds(ii,3) = (y - 1) * size(disp_plot_map,2) + x;
    end;
end;

% Find indices mapping each connection to the corresponding index to mdc (0
% if no such connection exists).
Cmdc_ind = zeros(1,size(CW,2));
for xx = 1:size(CW,2)
    the_ind = find(mdc == xx);
    if (isempty(the_ind))
        Cmd_ind(xx) = 0;
    else
        Cmdc_ind(xx) = the_ind;
    end;
end;

% Set up the environment axes and image.
plot_id = 1;
if (subplot_inds(plot_id,3) > 0)
    disp_scene = zeros(scene_height,scene_width,3);
    env_axes = subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    env_im = imagesc(disp_scene, [0 1]);
    xlabel('Environment View');
    axis square;
    hold all;
end;

% Set up the perifoveal view axes and image.
plot_id = 2;
if (subplot_inds(plot_id,3) > 0)
    retina_rods = zeros(64);
    perifov_axes = subplot(subplot_inds(plot_id,1), ...
        subplot_inds(plot_id,2), subplot_inds(plot_id,3));
    perifov_im = imagesc(retina_rods, [0 1]);
    xlabel('Perifoveal View');
    axis square;
    hold all;
end;

% Set up motor exec axes and image.
plot_id = 3;
if (subplot_inds(plot_id,3) > 0)
    motor_units = zeros(3,1);
    motor_exec_axes = subplot(subplot_inds(plot_id,1), ...
        subplot_inds(plot_id,2), subplot_inds(plot_id,3));
    motor_exec_im = imagesc(motor_units, [0 1]);
    xlabel('Motor Units');
    set(gca,'XTick',[]);
    set(gca,'YTick',1:3);
    set(gca,'YTickLabel',{'Track';'Nod';'Shake'});    
    axis square;
    hold all;
end;

% Set up color units axes and image.
plot_id = 4;
if (subplot_inds(plot_id,3) > 0)
    color_map = zeros(4,1);
    mem_color_map = zeros(4,1);
    color_input_axes = subplot(subplot_inds(plot_id,1), ...
        subplot_inds(plot_id,2), subplot_inds(plot_id,3));
    color_input_im = imagesc([color_map mem_color_map], [0 1]);
    xlabel('Color Units (Current / Memory)');
    set(gca,'XTick',[]);
    set(gca,'YTick',1:4);
    set(gca,'YTickLabel',{'R';'G';'B';'Y'});
    axis square;
    hold all;
end;

% Set up tone input units axes and image.
plot_id = 5;
if (subplot_inds(plot_id,3) > 0)
    tones_input_axes = subplot(subplot_inds(plot_id,1), ...
        subplot_inds(plot_id,2), subplot_inds(plot_id,3));
    tones_input_im = imagesc(zeros(12,2), [0 1]);
    xlabel('Tone Units (Current / Memory)','FontSize',10);
    set(gca,'XTick',[]);
    set(gca,'YTick',1:12,'FontSize',8);
    set(gca,'YTickLabel',{'C';'Db';'D';'Eb';'E';'F';'Gb';'G';'Ab';'A'; ...
        'Bb';'B'});
    axis square;
    hold all;
end;

% Set up reward/punisher unit axes and image.
plot_id = 6;
if (subplot_inds(plot_id,3) > 0)
    rew_pun_units = zeros(2,1);
    rew_pun_input_axes = subplot(subplot_inds(plot_id,1), ...
        subplot_inds(plot_id,2), subplot_inds(plot_id,3));
    rew_pun_input_im = imagesc(rew_pun_units, [0 1]);    
    xlabel('Reinforcement Units');
    set(gca,'XTick',[]);
    set(gca,'YTick',1:2);
    set(gca,'YTickLabel',{'Reward';'Punish'});    
    axis square;
    hold all;
end;

if (brain_type == brain_cog_model)
    % Set up novelty axes and image.
    plot_id = 7;
    if (subplot_inds(plot_id,3) > 0)
        novelty_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        novelty_im = imagesc(0, [0 1]);
        xlabel('Novelty');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;         
    end;
    
    % Set up visual stimulus presence unit axes and image.
    plot_id = 8;    
    if (subplot_inds(plot_id,3) > 0)
        vispres_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        vispres_im = imagesc(0, [0 1]);
        xlabel('Vis Stim On');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;         
    end;
    
    % Set up reward cue axes and image.
    plot_id = 9;
    if (subplot_inds(plot_id,3) > 0)
        reward_cue_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        reward_cue_im = imagesc(0, [0 1]);
        xlabel('Reward Cue');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;
    
    % Set up reward prediction axes and image.
    plot_id = 10;
    
    % Set up DA signal axes and image.
    plot_id = 11;
    if (subplot_inds(plot_id,3) > 0)
        DA_signal_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        DA_signal_im = imagesc(0, [0 1]);
        xlabel('DA Signal');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;         
    end;
    
    % Set up frustration unit axes and image.
    plot_id = 12;
    if (subplot_inds(plot_id,3) > 0)
        frust_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        frust_im = imagesc(0, [0 1]);
        xlabel('Frustration');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;         
    end;
    
    % Set up babble gating axes and image.
    plot_id = 13;
    if (subplot_inds(plot_id,3) > 0)
        babble_gate_units = zeros(2,3);
        babble_gate_level_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        babble_gate_level_im = imagesc(babble_gate_units, [0 1]);
        xlabel('Babble Gate Units');
        set(gca,'XTick',1:3);
        set(gca,'XTickLabel',{'R/N';'G';'I/E'});        
        set(gca,'YTick',1:2);
        set(gca,'YTickLabel',{'R/GE/I';'N/GI/E'});
        axis square;
        hold all;         
    end; 
 
    % Set up Babble Request unit axes and image.
    plot_id = 14;
    if (subplot_inds(plot_id,3) > 0)
        babble_req_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        babble_req_im = imagesc(0, [0 1]);
        xlabel('Babble Request');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;    
     
    % Set up Babble Go excitatory units axes and image.
    plot_id = 15;
    if (subplot_inds(plot_id,3) > 0)
        babble_go_e_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_go_e_units_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 1]);        
        area_ind = BabbleGoE_ind; 
        fetch_area_unit_inds;
        babble_go_e_units_uinds = unit_inds;     
        xlabel('Babble Go E Units'); 
        axis square;
        hold all;
    end;
    
    % Set up Babble Go inhibitory units axes and image.
    plot_id = 16;
    if (subplot_inds(plot_id,3) > 0)
        babble_go_i_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_go_i_units_im = imagesc(zeros(Area_xy(BabbleGoI_ind,2), ...
            Area_xy(BabbleGoI_ind,1)), [0 1]);        
        area_ind = BabbleGoI_ind; 
        fetch_area_unit_inds;
        babble_go_i_units_uinds = unit_inds;       
        xlabel('Babble Go I Units'); 
        axis square;
        hold all;
    end;
    
    % Set up Babble NoGo units axes and image.
    plot_id = 17;
    if (subplot_inds(plot_id,3) > 0)
        babble_nogo_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_nogo_units_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 1]);
        xlabel('Babble NoGo Units'); 
        axis square;
        hold all;
    end; 
    
    % Set up Babble Init unit axes and image.
    plot_id = 18;
    if (subplot_inds(plot_id,3) > 0)
        babble_init_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        babble_init_im = imagesc(0, [0 1]);
        xlabel('Babble Init');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;
    
    % Set up babble units axes and image.
    plot_id = 19;
    if (subplot_inds(plot_id,3) > 0)
        babble_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_units_im = imagesc(zeros(Area_xy(Babble_ind,2), ...
            Area_xy(Babble_ind,1)), [0 1]);        
        xlabel('Babble Units'); 
        axis square;
        hold all;
    end;    
    
    % Set up plan units axes and image.
    plot_id = 20;
    if (subplot_inds(plot_id,3) > 0)
        plan_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        plan_units_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 1]);
        xlabel('Plan Units'); 
        axis square;
        hold all;
    end;

    % Set up motor gating axes and image.   
    plot_id = 21;
    if (subplot_inds(plot_id,3) > 0)
        motor_gate_units = zeros(4,4);
        motor_gate_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        motor_gate_im = imagesc(motor_gate_units, [0 1]);
        xlabel('Motor Gate Units');
        set(gca,'XTick',1:4);
        set(gca,'XTickLabel',{'R/C';'G';'N';'I/E'});        
        set(gca,'YTick',1:4);
        set(gca,'YTickLabel',{'N RE/GE/x/I';'N C/GI/N/E'; ...
            'S RE/GE/x/I';'S x/GI/N/E'});
        hold all;
    end;     
 
    % Set up Nod Request excitatory units axes and image.
    plot_id = 22;
    if (subplot_inds(plot_id,3) > 0)
        nod_req_e_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        nod_req_e_im = imagesc(zeros(Area_xy(NodReqE_ind,2), ...
            Area_xy(NodReqE_ind,1)), [0 1]);
        xlabel('Nod Request E');
        axis square;
        hold all;    
    end;
      
    % Set up Nod Request inhibitory unit axes and image.
    plot_id = 23;
    if (subplot_inds(plot_id,3) > 0)
        nod_req_i_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        nod_req_i_im = imagesc(0, [0 1]);
        xlabel('Nod Request I');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;
    
    % Set up Nod Go excitatory units axes and image.
    plot_id = 24;
    if (subplot_inds(plot_id,3) > 0)
        nod_go_e_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        nod_go_e_units_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 1]);        
        area_ind = NodGoE_ind; 
        fetch_area_unit_inds;
        nod_go_e_units_uinds = unit_inds;     
        xlabel('Nod Go E Units'); 
        axis square;
        hold all;
    end;
    
    % Set up Nod Go inhibitory units axes and image.
    plot_id = 25;
    if (subplot_inds(plot_id,3) > 0)
        nod_go_i_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        nod_go_i_units_im = imagesc(zeros(Area_xy(NodGoI_ind,2), ...
            Area_xy(NodGoI_ind,1)), [0 1]);        
        area_ind = NodGoI_ind; 
        fetch_area_unit_inds;
        nod_go_i_units_uinds = unit_inds;       
        xlabel('Nod Go I Units'); 
        axis square;
        hold all;
    end;
    
    % Set up Nod NoGo units axes and image.
    plot_id = 26;
    if (subplot_inds(plot_id,3) > 0)
        nod_nogo_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        nod_nogo_units_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 1]);
        xlabel('Nod NoGo Units'); 
        axis square;
        hold all;
    end;
  
    % Set up Nod Init unit axes and image.
    plot_id = 27;
    if (subplot_inds(plot_id,3) > 0)
        nod_init_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        nod_init_im = imagesc(0, [0 1]);
        xlabel('Nod Init');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;
    
    % Set up Shake Request excitatory units axes and image.
    plot_id = 28;
    if (subplot_inds(plot_id,3) > 0)
        shake_req_e_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        shake_req_e_im = imagesc(zeros(Area_xy(ShakeReqE_ind,2), ...
            Area_xy(ShakeReqE_ind,1)), [0 1]);
        xlabel('Shake Request E');
        axis square;
        hold all;    
    end;
 
    % Set up Shake Request inhibitory unit axes and image.
    plot_id = 29;
    if (subplot_inds(plot_id,3) > 0)
        shake_req_i_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        shake_req_i_im = imagesc(0, [0 1]);
        xlabel('Shake Request I');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;
    
    % Set up Shake Go excitatory units axes and image.
    plot_id = 30;
    if (subplot_inds(plot_id,3) > 0)
        shake_go_e_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        shake_go_e_units_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 1]);
        xlabel('Shake Go E Units'); 
        axis square;
        hold all;
    end;
    
    % Set up Shake Go inhibitory units axes and image.
    plot_id = 31;
    if (subplot_inds(plot_id,3) > 0)
        shake_go_i_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        shake_go_i_units_im = imagesc(zeros(Area_xy(ShakeGoI_ind,2), ...
            Area_xy(ShakeGoI_ind,1)), [0 1]);
        xlabel('Shake Go I Units'); 
        axis square;
        hold all;
    end;
    
    % Set up Shake NoGo units axes and image.
    plot_id = 32;
    if (subplot_inds(plot_id,3) > 0)
        shake_nogo_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        shake_nogo_units_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 1]);
        xlabel('Shake NoGo Units'); 
        axis square;
        hold all;
    end;
    
    % Set up Shake Init unit axes and image.
    plot_id = 33;
    if (subplot_inds(plot_id,3) > 0)
        shake_init_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        shake_init_im = imagesc(0, [0 1]);
        xlabel('Shake Init');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;    
      
    % Set up neural noise units axes and image.
    plot_id = 34;
    if (subplot_inds(plot_id,3) > 0)
        neural_noise_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        neural_noise_units_im = imagesc(zeros(Area_xy(NeuralNoise_ind,2), ...
            Area_xy(NeuralNoise_ind,1)), [0 1]);
        xlabel('Neural Noise Units'); 
        axis square;
        hold all;
    end;    
      
    % Set up neural dice units axes and image.
    plot_id = 35;
    if (subplot_inds(plot_id,3) > 0)
        neural_dice_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        neural_dice_units_im = imagesc(zeros(Area_xy(NeuralDiceE_ind,2), ...
            Area_xy(NeuralDiceE_ind,1)), [0 1]);
        area_ind = NeuralDiceE_ind; 
        fetch_area_unit_inds;
        neural_dice_units_uinds = unit_inds;
        xlabel('Neural Dice Units'); 
        axis square;
        hold all;
    end;  
    
    % Set up neural geted dice units axes and image.
    plot_id = 36;
    if (subplot_inds(plot_id,3) > 0)
        neural_gated_dice_units_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        neural_gated_dice_units_im = imagesc(zeros(Area_xy(GatedDice_ind,2), ...
            Area_xy(GatedDice_ind,1)), [0 1]);
        xlabel('Neural Gated Dice Units'); 
        axis square;
        hold all;
    end;  
    
    % Set up Neural Dice Set unit axes and image.
    plot_id = 37;
    if (subplot_inds(plot_id,3) > 0)
        neural_dice_set_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        neural_dice_set_im = imagesc(0, [0 1]);
        xlabel('Neural Dice Set');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;   
    
    % Set up Neural Dice Gate unit axes and image.
    plot_id = 38;
    if (subplot_inds(plot_id,3) > 0)
        neural_dice_gate_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        neural_dice_gate_im = imagesc(0, [0 1]);
        xlabel('Neural Dice Gate');
        set(gca,'XTick',[]);
        set(gca,'YTick',[]);
        axis square;
        hold all;    
    end;   
    
    % Set up Nod Request -> Nod Go fanout weights axes and image.
    plot_id = 39; 
    if (subplot_inds(plot_id,3) > 0)
        nodreq_nodgo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        nodreq_nodgo_wts_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 1]);
        fasc_ind = NodReqtoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        nodreq_nodgo_wts_mod = MOD(Chan_type(fasc_ind));
        nodreq_nodgo_wts_winds = wt_inds;     
        xlabel('Nod Req->Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up RedWM -> Nod Go fanout weights axes and image.
    plot_id = 40;    
    if (subplot_inds(plot_id,3) > 0)
        redWM_nodgo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        redWM_nodgo_wts_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 0.1]);    
        fasc_ind = Color_WMtoNGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        redWM_nodgo_wts_mod = MOD(Chan_type(fasc_ind));
        redWM_nodgo_wts_winds = wt_inds;         
        xlabel('RedWM->Nod Go Fanout'); 
        axis square;
        hold all;
    end;   
    
    % Set up GreenWM -> Nod Go fanout weights axes and image.
    plot_id = 41;    
    if (subplot_inds(plot_id,3) > 0)
        greenWM_nodgo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        greenWM_nodgo_wts_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 0.1]);        
        fasc_ind = Color_WMtoNGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 2;
        fetch_cell_wt_inds;   
        greenWM_nodgo_wts_mod = MOD(Chan_type(fasc_ind));
        greenWM_nodgo_wts_winds = wt_inds;            
        xlabel('GreenWM->Nod Go Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up BlueWM -> Nod Go fanout weights axes and image.
    plot_id = 42;   
    if (subplot_inds(plot_id,3) > 0)
        blueWM_nodgo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        blueWM_nodgo_wts_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 0.1]);      
        fasc_ind = Color_WMtoNGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 3;
        fetch_cell_wt_inds;   
        blueWM_nodgo_wts_mod = MOD(Chan_type(fasc_ind));
        blueWM_nodgo_wts_winds = wt_inds;            
        xlabel('BlueWM->Nod Go Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up YellowWM -> Nod Go fanout weights axes and image.
    plot_id = 43;       
    if (subplot_inds(plot_id,3) > 0)
        yellowWM_nodgo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        yellowWM_nodgo_wts_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 0.1]);        
        fasc_ind = Color_WMtoNGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetch_cell_wt_inds;   
        yellowWM_nodgo_wts_mod = MOD(Chan_type(fasc_ind));
        yellowWM_nodgo_wts_winds = wt_inds;          
        xlabel('YellowWM->Nod Go Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up CToneWM -> Nod Go fanout weights axes and image.
    plot_id = 44; 
    if (subplot_inds(plot_id,3) > 0)
        c_toneWM_nodgo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        c_toneWM_nodgo_wts_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 0.1]);        
        fasc_ind = Tones_WMtoNGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        c_toneWM_nodgo_wts_mod = MOD(Chan_type(fasc_ind));
        c_toneWM_nodgo_wts_winds = wt_inds;         
        xlabel('CToneWM->Nod Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up EFlatToneWM -> Nod Go fanout weights axes and image.
    plot_id = 45;     
    if (subplot_inds(plot_id,3) > 0)
        eflat_toneWM_nodgo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        eflat_toneWM_nodgo_wts_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 0.1]);            
        fasc_ind = Tones_WMtoNGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetch_cell_wt_inds;   
        eflat_toneWM_nodgo_wts_mod = MOD(Chan_type(fasc_ind));
        eflat_toneWM_nodgo_wts_winds = wt_inds;       
        xlabel('EFlatToneWM->Nod Go Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up Nod Init -> Nod NoGo fanout weights axes and image.
    plot_id = 46;   
    if (subplot_inds(plot_id,3) > 0)
        nodinit_nodnogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        nodinit_nodnogo_wts_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 1.0]);       
        fasc_ind = NodInittoNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        nodinit_nodnogo_wts_mod = MOD(Chan_type(fasc_ind));
        nodinit_nodnogo_wts_winds = wt_inds;                        
        xlabel('Nod Init->NoGo Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up RedWM Init -> Nod NoGo fanout weights axes and image.
    plot_id = 47;      
    if (subplot_inds(plot_id,3) > 0)
        redWM_nodnogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        redWM_nodnogo_wts_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 0.1]);      
        xlabel('RedWM->Nod NoGo Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up GreenWM -> Nod NoGo fanout weights axes and image.
    plot_id = 48;    
    if (subplot_inds(plot_id,3) > 0)
        greenWM_nodnogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        greenWM_nodnogo_wts_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 0.1]);      
        xlabel('GreenWM->Nod NoGo Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up BlueWM -> Nod NoGo fanout weights axes and image.
    plot_id = 49;   
    if (subplot_inds(plot_id,3) > 0)
        blueWM_nodnogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        blueWM_nodnogo_wts_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 0.1]);      
        xlabel('BlueWM->Nod NoGo Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up YellowWM -> Nod NoGo fanout weights axes and image.
    plot_id = 50;       
    if (subplot_inds(plot_id,3) > 0)
        yellowWM_nodnogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        yellowWM_nodnogo_wts_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 0.1]);      
        xlabel('YellowWM->Nod NoGo Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up CToneWM -> Nod NoGo fanout weights axes and image.
    plot_id = 51; 
    if (subplot_inds(plot_id,3) > 0)
        c_toneWM_nodnogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        c_toneWM_nodnogo_wts_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 0.1]);      
        xlabel('CToneWM->Nod NoGo Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up EFlatToneWM -> Nod NoGo fanout weights axes and image.
    plot_id = 52;     
    if (subplot_inds(plot_id,3) > 0)
        eflat_toneWM_nodnogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        eflat_toneWM_nodnogo_wts_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 0.1]);      
        xlabel('EFlatToneWM->Nod NoGo Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up Shake Request -> Shake Go fanout weights axes and image.
    plot_id = 53; 
    if (subplot_inds(plot_id,3) > 0)
        shakereq_shakego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        shakereq_shakego_wts_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 1]);      
        xlabel('Shake Req->Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up RedWM -> Shake Go fanout weights axes and image.
    plot_id = 54;    
    if (subplot_inds(plot_id,3) > 0)
        redWM_shakego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        redWM_shakego_wts_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 0.1]);      
        xlabel('RedWM->Shake Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up GreenWM -> Shake Go fanout weights axes and image.
    plot_id = 55;    
    if (subplot_inds(plot_id,3) > 0)
        greenWM_shakego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        greenWM_shakego_wts_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 0.1]);      
        xlabel('GreenWM->Shake Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up BlueWM -> Shake Go fanout weights axes and image.
    plot_id = 56;   
    if (subplot_inds(plot_id,3) > 0)
        blueWM_shakego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        blueWM_shakego_wts_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 0.1]);      
        xlabel('BlueWM->Shake Go Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up YellowWM -> Shake Go fanout weights axes and image.
    plot_id = 57;       
    if (subplot_inds(plot_id,3) > 0)
        yellowWM_shakego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        yellowWM_shakego_wts_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 0.1]);      
        xlabel('YellowWM->Shake Go Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up CToneWM -> Shake Go fanout weights axes and image.
    plot_id = 58; 
    if (subplot_inds(plot_id,3) > 0)
        c_toneWM_shakego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        c_toneWM_shakego_wts_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 0.1]);      
        xlabel('CToneWM->Shake Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up EFlatToneWM -> Shake Go fanout weights axes and image.
    plot_id = 59;     
    if (subplot_inds(plot_id,3) > 0)
        eflat_toneWM_shakego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        eflat_toneWM_shakego_wts_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 0.1]);      
        xlabel('EFlatToneWM->Shake Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up Shake Init -> Shake NoGo fanout weights axes and image.
    plot_id = 60;   
    if (subplot_inds(plot_id,3) > 0)
        shakeinit_shakenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        shakeinit_shakenogo_wts_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 1.0]);      
        xlabel('Shake Init->NoGo Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up RedWM Init -> Shake NoGo fanout weights axes and image.
    plot_id = 61;      
    if (subplot_inds(plot_id,3) > 0)
        redWM_shakenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        redWM_shakenogo_wts_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 0.1]);      
        xlabel('RedWM->Shake NoGo Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up GreenWM -> Shake NoGo fanout weights axes and image.
    plot_id = 62;    
    if (subplot_inds(plot_id,3) > 0)
        greenWM_shakenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        greenWM_shakenogo_wts_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 0.1]);      
        xlabel('GreenWM->Shake NoGo Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up BlueWM -> Shake NoGo fanout weights axes and image.
    plot_id = 63;   
    if (subplot_inds(plot_id,3) > 0)
        blueWM_shakenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        blueWM_shakenogo_wts_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 0.1]);      
        xlabel('BlueWM->Shake NoGo Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up YellowWM -> Shake NoGo fanout weights axes and image.
    plot_id = 64;       
    if (subplot_inds(plot_id,3) > 0)
        yellowWM_shakenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        yellowWM_shakenogo_wts_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 0.1]);      
        xlabel('YellowWM->Shake NoGo Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up CToneWM -> Shake NoGo fanout weights axes and image.
    plot_id = 65; 
    if (subplot_inds(plot_id,3) > 0)
        c_toneWM_shakenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        c_toneWM_shakenogo_wts_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 0.1]);      
        xlabel('CToneWM->Shake NoGo Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up EFlatToneWM -> Shake NoGo fanout weights axes and image.
    plot_id = 66;      
    if (subplot_inds(plot_id,3) > 0)
        eflat_toneWM_shakenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        eflat_toneWM_shakenogo_wts_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 0.1]);      
        xlabel('EFlatToneWM->Shake NoGo Fanout'); 
        axis square;
        hold all;
    end;      
    
    % Set up Babble Request -> Babble Go fanout weights axes and image.
    plot_id = 67; 
    if (subplot_inds(plot_id,3) > 0)
        babblereq_babblego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babblereq_babblego_wts_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 1]);      
        xlabel('Babble Req->Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up RedWM -> Babble Go fanout weights axes and image.
    plot_id = 68;    
    if (subplot_inds(plot_id,3) > 0)
        redWM_babblego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        redWM_babblego_wts_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 0.1]);      
        xlabel('RedWM->Babble Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up GreenWM -> Babble Go fanout weights axes and image.
    plot_id = 69;    
    if (subplot_inds(plot_id,3) > 0)
        greenWM_babblego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        greenWM_babblego_wts_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 0.1]);      
        xlabel('GreenWM->Babble Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up BlueWM -> Babble Go fanout weights axes and image.
    plot_id = 70;   
    if (subplot_inds(plot_id,3) > 0)
        blueWM_babblego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        blueWM_babblego_wts_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 0.1]);      
        xlabel('BlueWM->Babble Go Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up YellowWM -> Babble Go fanout weights axes and image.
    plot_id = 71;       
    if (subplot_inds(plot_id,3) > 0)
        yellowWM_babblego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        yellowWM_babblego_wts_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 0.1]);      
        xlabel('YellowWM->Babble Go Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up CToneWM -> Babble Go fanout weights axes and image.
    plot_id = 72; 
    if (subplot_inds(plot_id,3) > 0)
        c_toneWM_babblego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        c_toneWM_babblego_wts_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 0.1]);      
        xlabel('CToneWM->Babble Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up EFlatToneWM -> Babble Go fanout weights axes and image.
    plot_id = 73;     
    if (subplot_inds(plot_id,3) > 0)
        eflat_toneWM_babblego_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        eflat_toneWM_babblego_wts_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 0.1]);      
        xlabel('EFlatToneWM->Babble Go Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up Shake Init -> Babble NoGo fanout weights axes and image.
    plot_id = 74;   
    if (subplot_inds(plot_id,3) > 0)
        babbleinit_babblenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babbleinit_babblenogo_wts_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 1.0]);      
        xlabel('Babble Init->NoGo Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up RedWM Init -> Babble NoGo fanout weights axes and image.
    plot_id = 75;      
    if (subplot_inds(plot_id,3) > 0)
        redWM_babblenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        redWM_babblenogo_wts_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 0.1]);      
        xlabel('RedWM->Babble NoGo Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up GreenWM -> Babble NoGo fanout weights axes and image.
    plot_id = 76;    
    if (subplot_inds(plot_id,3) > 0)
        greenWM_babblenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        greenWM_babblenogo_wts_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 0.1]);      
        xlabel('GreenWM->Babble NoGo Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up BlueWM -> Babble NoGo fanout weights axes and image.
    plot_id = 77;   
    if (subplot_inds(plot_id,3) > 0)
        blueWM_babblenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        blueWM_babblenogo_wts_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 0.1]);      
        xlabel('BlueWM->Babble NoGo Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up YellowWM -> Babble NoGo fanout weights axes and image.
    plot_id = 78;       
    if (subplot_inds(plot_id,3) > 0)
        yellowWM_babblenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        yellowWM_babblenogo_wts_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 0.1]);      
        xlabel('YellowWM->Babble NoGo Fanout'); 
        axis square;
        hold all;
    end;
    
    % Set up CToneWM -> Babble NoGo fanout weights axes and image.
    plot_id = 79; 
    if (subplot_inds(plot_id,3) > 0)
        c_toneWM_babblenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        c_toneWM_babblenogo_wts_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 0.1]);      
        xlabel('CToneWM->Babble NoGo Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up EFlatToneWM -> Babble NoGo fanout weights axes and image.
    plot_id = 80;      
    if (subplot_inds(plot_id,3) > 0)
        eflat_toneWM_babblenogo_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        eflat_toneWM_babblenogo_wts_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 0.1]);      
        xlabel('EFlatToneWM->Babble NoGo Fanout'); 
        axis square;
        hold all;
    end;    
    
    % Set up VisStim -> Plan fanout weights axes and image.
    plot_id = 81;    
    if (subplot_inds(plot_id,3) > 0)
        vispres_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        vispres_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]); 
        fasc_ind = VisStimtoPlan_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        vispres_plan_wts_mod = MOD(Chan_type(fasc_ind));
        vispres_plan_wts_winds = wt_inds;       
        xlabel('VisPres->Plan Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up RedWM -> Plan fanout weights axes and image.
    plot_id = 82;
    if (subplot_inds(plot_id,3) > 0)
        redWM_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        redWM_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]);   
        fasc_ind = Color_WMtoPlan_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        redWM_plan_wts_mod = MOD(Chan_type(fasc_ind));
        redWM_plan_wts_winds = wt_inds;        
        xlabel('RedWM->Plan Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up GreenWM -> Plan fanout weights axes and image.
    plot_id = 83;
    if (subplot_inds(plot_id,3) > 0)
        greenWM_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        greenWM_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]);   
        fasc_ind = Color_WMtoPlan_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 2;
        fetch_cell_wt_inds;   
        greenWM_plan_wts_mod = MOD(Chan_type(fasc_ind));
        greenWM_plan_wts_winds = wt_inds;          
        xlabel('GreenWM->Plan Fanout'); 
        axis square;
        hold all;
    end;     
    
    % Set up BlueWM -> Plan fanout weights axes and image.
    plot_id = 84;
    if (subplot_inds(plot_id,3) > 0)
        blueWM_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        blueWM_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]); 
        fasc_ind = Color_WMtoPlan_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 3;
        fetch_cell_wt_inds;   
        blueWM_plan_wts_mod = MOD(Chan_type(fasc_ind));
        blueWM_plan_wts_winds = wt_inds;      
        xlabel('BlueWM->Plan Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up YellowWM -> Plan fanout weights axes and image.
    plot_id = 85;
    if (subplot_inds(plot_id,3) > 0)
        yellowWM_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        yellowWM_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]); 
        fasc_ind = Color_WMtoPlan_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetch_cell_wt_inds;   
        yellowWM_plan_wts_mod = MOD(Chan_type(fasc_ind));
        yellowWM_plan_wts_winds = wt_inds;  
        xlabel('YellowWM->Plan Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up CToneWM -> Plan fanout weights axes and image.
    plot_id = 86;
    if (subplot_inds(plot_id,3) > 0)
        c_toneWM_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        c_toneWM_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]);       
        fasc_ind = Tones_WMtoPlan_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        c_toneWM_plan_wts_mod = MOD(Chan_type(fasc_ind));
        c_toneWM_plan_wts_winds = wt_inds;         
        xlabel('CToneWM->Plan Fanout'); 
        axis square;
        hold all;
    end;    
    
    % Set up EFlatToneWM -> Plan fanout weights axes and image.
    plot_id = 87;
    if (subplot_inds(plot_id,3) > 0)
        eflat_toneWM_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        eflat_toneWM_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]); 
        fasc_ind = Tones_WMtoPlan_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetch_cell_wt_inds;   
        eflat_toneWM_plan_wts_mod = MOD(Chan_type(fasc_ind));
        eflat_toneWM_plan_wts_winds = wt_inds;          
        xlabel('EFlatToneWM->Plan Fanout'); 
        axis square;
        hold all;
    end;  
     
    % Set up Bias -> Plan fanout weights axes and image.
    plot_id = 88;
    if (subplot_inds(plot_id,3) > 0)
        bias_plan_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        bias_plan_wts_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 0.5]);        
        fasc_ind = PlanBias_ind;    
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        bias_plan_wts_mod = MOD(Chan_type(fasc_ind));
        bias_plan_wts_winds = wt_inds;          
        xlabel('Bias->Plan Fanout'); 
        axis square;
        hold all;
    end;  
    
    % Set up Bias -> Nod Request fanout weights axes and image.
    plot_id = 89;
    if (subplot_inds(plot_id,3) > 0)
        bias_nodreq_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        bias_nodreq_wts_im = imagesc(zeros(Area_xy(NodReqE_ind,2), ...
            Area_xy(NodReqE_ind,1)), [0 0.5]);        
        fasc_ind = NodReqBias_ind;    
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        bias_nodreq_wts_mod = MOD(Chan_type(fasc_ind));
        bias_nodreq_wts_winds = wt_inds;          
        xlabel('Bias->NodReq Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up Bias -> Shake Request fanout weights axes and image.
    plot_id = 90;
    if (subplot_inds(plot_id,3) > 0)
        bias_shakereq_wts_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        bias_shakereq_wts_im = imagesc(zeros(Area_xy(ShakeReqE_ind,2), ...
            Area_xy(ShakeReqE_ind,1)), [0 0.5]);        
        fasc_ind = ShakeReqBias_ind;    
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetch_cell_wt_inds;   
        bias_shakereq_wts_mod = MOD(Chan_type(fasc_ind));
        bias_shakereq_wts_winds = wt_inds;          
        xlabel('Bias->ShakeReq Fanout'); 
        axis square;
        hold all;
    end; 
    
    % Set up Inputs -> Plan fanin weights axes and image.
    plot_id = 91;   
    if (subplot_inds(plot_id,3) > 0)
        plan_fanin_wts = zeros(4,5);
        plan_fanin_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3));
        plan_fanin_im = imagesc(plan_fanin_wts, [0 0.1]);
        xlabel('Plan Unit Fanin');
        set(gca,'XTick',1:5);
        set(gca,'XTickLabel',{'S';'C';'T1';'T2';'T3'}); 
        set(gca,'YTick',1:4);
        set(gca,'YTickLabel',{'St/Rd/C/E/Ab'; 'xx/Gr/Db/F/A '; ...
            'xx/Bl/D/Gb/Bb'; 'xx/Yl/Eb/G/B '});        
        axis square;
        hold all;
    end;

    % Set up Nod Init -> Nod NoGo fascicle summed net input 
    % axes and image.
    plot_id = 92;
    if (subplot_inds(plot_id,3) > 0)
        nod_init_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        nod_init_nogo_fascins_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 1]);      
        xlabel('Nod Init->NoGo Netin'); 
        axis square;
        hold all;
    end;   
    
    % Set up Neural DiceE -> Nod NoGo fascicle summed net input 
    % axes and image.
    plot_id = 93;
    if (subplot_inds(plot_id,3) > 0)
        dice_nod_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        dice_nod_nogo_fascins_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 1]);      
        xlabel('Dice->Nod NoGo Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Color and Tone WM -> Nod NoGo fascicle summed net input 
    % axes and image.
    plot_id = 94;
    if (subplot_inds(plot_id,3) > 0)
        wm_nod_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        wm_nod_nogo_fascins_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 1]);      
        xlabel('WM->Nod NoGo Netin'); 
        axis square;
        hold all;
    end; 
    
    % Set up Total Nod NoGo fascicle summed net input axes and image.
    plot_id = 95;
    if (subplot_inds(plot_id,3) > 0)
        tot_nod_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        tot_nod_nogo_fascins_im = imagesc(zeros(Area_xy(NodNoGo_ind,2), ...
            Area_xy(NodNoGo_ind,1)), [0 1]);      
        xlabel('Total Nod NoGo Netin'); 
        axis square;
        hold all;
    end;
        
    % Set up Shake Init -> Shake NoGo fascicle summed net input 
    % axes and image.
    plot_id = 96;
    if (subplot_inds(plot_id,3) > 0)
        shake_init_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        shake_init_nogo_fascins_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 1]);      
        xlabel('Shake Init->NoGo Netin'); 
        axis square;
        hold all;
    end;   
    
    % Set up Neural DiceE -> Shake NoGo fascicle summed net input 
    % axes and image.
    plot_id = 97;
    if (subplot_inds(plot_id,3) > 0)
        dice_shake_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        dice_shake_nogo_fascins_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 1]);      
        xlabel('Dice->Shake NoGo Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Color and Tone WM -> Shake NoGo fascicle summed net input 
    % axes and image.
    plot_id = 98;
    if (subplot_inds(plot_id,3) > 0)
        wm_shake_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        wm_shake_nogo_fascins_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 1]);      
        xlabel('WM->Shake NoGo Netin'); 
        axis square;
        hold all;
    end; 
    
    % Set up Total Shake NoGo fascicle summed net input axes and image.
    plot_id = 99;
    if (subplot_inds(plot_id,3) > 0)
        tot_shake_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        tot_shake_nogo_fascins_im = imagesc(zeros(Area_xy(ShakeNoGo_ind,2), ...
            Area_xy(ShakeNoGo_ind,1)), [0 1]);      
        xlabel('Total Shake NoGo Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Nod Request -> Nod Go fascicle summed net input 
    % axes and image.
    plot_id = 100;
    if (subplot_inds(plot_id,3) > 0)
        nod_req_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        nod_req_go_fascins_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 1]);      
        xlabel('Nod Request->Go Netin'); 
        axis square;
        hold all;
    end;   
    
    % Set up Neural DiceE -> Nod Go fascicle summed net input 
    % axes and image.
    plot_id = 101;
    if (subplot_inds(plot_id,3) > 0)
        dice_nod_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        dice_nod_go_fascins_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 1]);       
        xlabel('Dice->Nod Go Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Color and Tone WM -> Nod Go fascicle summed net input 
    % axes and image.
    plot_id = 102;
    if (subplot_inds(plot_id,3) > 0)
        wm_nod_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        wm_nod_go_fascins_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 1]);      
        xlabel('WM->Nod Go Netin'); 
        axis square;
        hold all;
    end; 
    
    % Set up Total Nod Go fascicle summed net input axes and image.
    plot_id = 103;
    if (subplot_inds(plot_id,3) > 0)
        tot_nod_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        tot_nod_go_fascins_im = imagesc(zeros(Area_xy(NodGoE_ind,2), ...
            Area_xy(NodGoE_ind,1)), [0 1]); 
        xlabel('Total Nod Go Netin'); 
        axis square;
        hold all;
    end;
        
    % Set up Shake Request -> Shake Go fascicle summed net input 
    % axes and image.
    plot_id = 104;
    if (subplot_inds(plot_id,3) > 0)
        shake_req_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        shake_req_go_fascins_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 1]);      
        xlabel('Shake Request->Go Netin'); 
        axis square;
        hold all;
    end;   
    
    % Set up Neural DiceE -> Shake Go fascicle summed net input 
    % axes and image.
    plot_id = 105;
    if (subplot_inds(plot_id,3) > 0)
        dice_shake_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        dice_shake_go_fascins_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 1]);      
        xlabel('Dice->Shake Go Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Color and Tone WM -> Shake Go fascicle summed net input 
    % axes and image.
    plot_id = 106;
    if (subplot_inds(plot_id,3) > 0)
        wm_shake_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        wm_shake_go_fascins_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 1]);      
        xlabel('WM->Shake Go Netin'); 
        axis square;
        hold all;
    end; 
    
    % Set up Total Shake Go fascicle summed net input axes and image.
    plot_id = 107;
    if (subplot_inds(plot_id,3) > 0)
        tot_shake_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        tot_shake_go_fascins_im = imagesc(zeros(Area_xy(ShakeGoE_ind,2), ...
            Area_xy(ShakeGoE_ind,1)), [0 1]);      
        xlabel('Total Shake Go Netin'); 
        axis square;
        hold all;
    end;   
    
    % Set up Babble Request -> Babble Go fascicle summed net input 
    % axes and image.
    plot_id = 108;
    if (subplot_inds(plot_id,3) > 0)
        babble_req_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_req_go_fascins_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 1]);      
        xlabel('Babble Request->Go Netin'); 
        axis square;
        hold all;
    end;   
    
    % Set up Neural DiceE -> Babble Go fascicle summed net input 
    % axes and image.
    plot_id = 109;
    if (subplot_inds(plot_id,3) > 0)
        dice_babble_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        dice_babble_go_fascins_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 1]);      
        xlabel('Dice->Babble Go Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Color and Tone WM -> Babble Go fascicle summed net input 
    % axes and image.
    plot_id = 110;
    if (subplot_inds(plot_id,3) > 0)
        wm_babble_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        wm_babble_go_fascins_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 1]);      
        xlabel('WM->Babble Go Netin'); 
        axis square;
        hold all;
    end; 
    
    % Set up Total Babble Go fascicle summed net input axes and image.
    plot_id = 111;
    if (subplot_inds(plot_id,3) > 0)
        tot_babble_go_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        tot_babble_go_fascins_im = imagesc(zeros(Area_xy(BabbleGoE_ind,2), ...
            Area_xy(BabbleGoE_ind,1)), [0 1]);      
        xlabel('Total Babble Go Netin'); 
        axis square;
        hold all;
    end;       
  
    % Set up Babble Init -> Babble NoGo fascicle summed net input 
    % axes and image.
    plot_id = 112;
    if (subplot_inds(plot_id,3) > 0)
        babble_init_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_init_nogo_fascins_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 1]);      
        xlabel('Babble Init->NoGo Netin'); 
        axis square;
        hold all;
    end;   
    
    % Set up Neural DiceE -> Babble NoGo fascicle summed net input 
    % axes and image.
    plot_id = 113;
    if (subplot_inds(plot_id,3) > 0)
        dice_babble_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        dice_babble_nogo_fascins_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 1]);      
        xlabel('Dice->Babble NoGo Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Color and Tone WM -> Babble NoGo fascicle summed net input 
    % axes and image.
    plot_id = 114;
    if (subplot_inds(plot_id,3) > 0)
        wm_babble_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        wm_babble_nogo_fascins_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 1]);      
        xlabel('WM->Babble NoGo Netin'); 
        axis square;
        hold all;
    end; 
    
    % Set up Total Babble NoGo fascicle summed net input axes and image.
    plot_id = 115;
    if (subplot_inds(plot_id,3) > 0)
        tot_babble_nogo_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        tot_babble_nogo_fascins_im = imagesc(zeros(Area_xy(BabbleNoGo_ind,2), ...
            Area_xy(BabbleNoGo_ind,1)), [0 1]);      
        xlabel('Total Babble NoGo Netin'); 
        axis square;
        hold all;
    end;
     
    % Set up Inputs -> Plan fascicle summed net input axes and image.
    plot_id = 116;
    if (subplot_inds(plot_id,3) > 0)
        inputs_plan_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        inputs_plan_fascins_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 1]);      
        xlabel('Inputs->Plan Netin'); 
        axis square;
        hold all;
    end;

    % Set up Babble -> Plan fascicle summed net input axes and image.
    plot_id = 117;
    if (subplot_inds(plot_id,3) > 0)
        babble_plan_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_plan_fascins_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 1]);      
        xlabel('Babble->Plan Netin'); 
        axis square;
        hold all;
    end;   
  
    % Set up Bias -> Plan fascicle summed net input axes and image.
    plot_id = 118;
    if (subplot_inds(plot_id,3) > 0)
        bias_plan_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        bias_plan_fascins_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 1]);      
        xlabel('Bias->Plan Netin'); 
        axis square;
        hold all;
    end;     
    
    % Set up Total Plan fascicle summed net input axes and image.
    plot_id = 119;
    if (subplot_inds(plot_id,3) > 0)
        total_plan_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        total_plan_fascins_im = imagesc(zeros(Area_xy(Plan_ind,2), ...
            Area_xy(Plan_ind,1)), [0 1]);      
        xlabel('Total Plan Netin'); 
        axis square;
        hold all;
    end;        
    
    % Set up Plan -> Nod Request fascicle summed net input axes and image.
    plot_id = 120;
    if (subplot_inds(plot_id,3) > 0)
        plan_nod_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        plan_nod_req_fascins_im = imagesc(zeros(Area_xy(NodReqE_ind,2), ...
            Area_xy(NodReqE_ind,1)), [0 1]);      
        xlabel('Plan->Nod Req Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Babble -> Nod Request fascicle summed net input axes and image.
    plot_id = 121;
    if (subplot_inds(plot_id,3) > 0)
        babble_nod_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_nod_req_fascins_im = imagesc(zeros(Area_xy(NodReqE_ind,2), ...
            Area_xy(NodReqE_ind,1)), [0 1]);      
        xlabel('Babble->Nod Req Netin'); 
        axis square;
        hold all;
    end;    
    
    % Set up Bias -> Nod Request fascicle summed net input axes and image.
    plot_id = 122;
    if (subplot_inds(plot_id,3) > 0)
        bias_nod_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        bias_nod_req_fascins_im = imagesc(zeros(Area_xy(NodReqE_ind,2), ...
            Area_xy(NodReqE_ind,1)), [0 1]);      
        xlabel('Bias->Nod Req Netin'); 
        axis square;
        hold all;
    end;  
 
    % Set up Total Nod Request fascicle summed net input axes and image.
    plot_id = 123;
    if (subplot_inds(plot_id,3) > 0)
        total_nod_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        total_nod_req_fascins_im = imagesc(zeros(Area_xy(NodReqE_ind,2), ...
            Area_xy(NodReqE_ind,1)), [0 1]);      
        xlabel('Total Nod Req Netin'); 
        axis square;
        hold all;
    end;  
    
    % Set up Plan -> Shake Request fascicle summed net input axes and image.
    plot_id = 124;
    if (subplot_inds(plot_id,3) > 0)
        plan_shake_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        plan_shake_req_fascins_im = imagesc(zeros(Area_xy(ShakeReqE_ind,2), ...
            Area_xy(ShakeReqE_ind,1)), [0 1]);      
        xlabel('Plan->Shake Req Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Babble -> Shake Request fascicle summed net input axes and image.
    plot_id = 125;
    if (subplot_inds(plot_id,3) > 0)
        babble_shake_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        babble_shake_req_fascins_im = imagesc(zeros(Area_xy(ShakeReqE_ind,2), ...
            Area_xy(ShakeReqE_ind,1)), [0 1]);      
        xlabel('Babble->Shake Req Netin'); 
        axis square;
        hold all;
    end;    

    % Set up Bias -> Shake Request fascicle summed net input axes and image.
    plot_id = 126;
    if (subplot_inds(plot_id,3) > 0)
        bias_shake_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        bias_shake_req_fascins_im = imagesc(zeros(Area_xy(ShakeReqE_ind,2), ...
            Area_xy(ShakeReqE_ind,1)), [0 1]);      
        xlabel('Bias->Shake Req Netin'); 
        axis square;
        hold all;
    end;  
 
    % Set up Total Shake Request fascicle summed net input axes and image.
    plot_id = 127;
    if (subplot_inds(plot_id,3) > 0)
        total_shake_req_fascins_axes = subplot(subplot_inds(plot_id,1), ...
            subplot_inds(plot_id,2), subplot_inds(plot_id,3)); 
        total_shake_req_fascins_im = imagesc(zeros(Area_xy(ShakeReqE_ind,2), ...
            Area_xy(ShakeReqE_ind,1)), [0 1]);      
        xlabel('Total Shake Req Netin'); 
        axis square;
        hold all;
    end;     
    
end;