%
% modl_initA.m
% 
% Read the model structure parameters for the net from a file and 
% build the network.
%
% Last modification: 6/11/07

% Clear all variables and close all figures.
clear all;
close all;

% Do we want to use negative weights?
use_neg_wts = 0;

% 
% Read the model definitons from file.
%

% Load the simulation run parameters.
load sim_run_params;

% Open the parameter file.   
fid = fopen(model_parm_fname, 'rt');

curr_CLT = 0;
curr_CXT = 0;
Fparam_names = '';
Fparams = [];
  
% Parse the model file.
while 1
    % Read the next line.
    line = fgets(fid);
    
    % Only read stuff in if the line isn't a %-comment and isn't blank.
    if ((line(1) ~= '%') & (size(line,2) > 2) & (~isempty(line)))        
        % Read all the tokens
        items = tokenize(line,' ');
                
        % If we have a $ parameter, read it into the list.
        if (line(1) == '$')
            Fparam_names = str2mat(Fparam_names,items(1,2:size(items,2)));
            Fparams = [ Fparams str2double(items(2,:)) ];
            if (size(Fparam_names,1) > size(Fparams,2))
                Fparam_names = Fparam_names(2:size(Fparam_names,1),:); 
            end;
            
        % If we haven't read in the first line yet, do so.
        elseif ((curr_CLT == 0) & (curr_CXT == 0))
            Model_name = sscanf(items(1,:),'%s');
            Num_areas = readparam(items(2,:),Fparam_names,Fparams);
            Num_conns = readparam(items(3,:),Fparam_names,Fparams);
            curr_CLT = 1;
            curr_CXT = 1;
            Area_name = '';
            Conn_name = ''; 
            Conn_kind = ''; 
            Conn_mask = '';
        elseif (curr_CLT <= Num_areas)
            Area_name = str2mat(Area_name,sscanf(items(1,:),'%s'));
            Area_num(curr_CLT) = readparam(items(2,:),Fparam_names,Fparams);
            Cell_type(curr_CLT) = readparam(items(3,:),Fparam_names,Fparams);
            Area_xy(curr_CLT,1) = readparam(items(4,:),Fparam_names,Fparams);
            Area_xy(curr_CLT,2) = readparam(items(5,:),Fparam_names,Fparams);
            Area_xy(curr_CLT,3) = Area_xy(curr_CLT,1)*Area_xy(curr_CLT,2);       
            curr_CLT = curr_CLT + 1;
        elseif (curr_CXT <= Num_conns)
            Conn_name = str2mat(Conn_name,sscanf(items(1,:),'%s'));
            Conn_fromto(curr_CXT,1) = readparam(items(2,:),Fparam_names,Fparams);
            Conn_fromto(curr_CXT,2) = readparam(items(3,:),Fparam_names,Fparams);
            Chan_type(curr_CXT) = readparam(items(4,:),Fparam_names,Fparams);
            Conn_kind = str2mat(Conn_kind,sscanf(items(5,:),'%s'));
            Conn_mask = str2mat(Conn_mask,sscanf(items(6,:),'%s'));
            Conn_xy(curr_CXT,1) = readparam(items(7,:),Fparam_names,Fparams);
            Conn_xy(curr_CXT,2) = readparam(items(8,:),Fparam_names,Fparams);
            Conn_prob(curr_CXT) = readparam(items(9,:),Fparam_names,Fparams);
            Weig_mean(curr_CXT) = readparam(items(10,:),Fparam_names,Fparams);
            Weig_sigm(curr_CXT) = readparam(items(11,:),Fparam_names,Fparams);
            Conn_scle(curr_CXT) = readparam(items(12,:),Fparam_names,Fparams);        
            curr_CXT = curr_CXT + 1;
        end;
    end; % if we have a valid line
    
    % Break out of the loop if we're at the end of the file.
    if feof(fid)
        break;
    end;
        
end; % while loop

% Close the parameter file.
fclose(fid);

Area_name = Area_name(2:Num_areas+1,:);  % discard null first area name
Conn_name = Conn_name(2:Num_conns+1,:);  % discard null first connection name
Conn_kind = Conn_kind(2:Num_conns+1,:);  % discard null first kind
Conn_mask = Conn_mask(2:Num_conns+1,:);  % discard null first mask

% 
% Generate and save the connection addresses and weights of the model.
%

% Initialize connection addresses (CA), connection arbor (CR), 
% connection weights (CW), channel types (presynaptic) (CH), 
% postsynaptic cell types (CT) and number of connections (NC) and units (NU)
CA = []; CR = []; CW = []; CH = []; CT = []; NC = [];
NU = (Area_xy(:,1) .* Area_xy(:,2))';
for ct = 1:Num_areas
   % store (postsynaptic) cell type
   CT = [CT uint8(Cell_type(ct) .* ones(1,NU(ct)))];
end; 

% Loop over connection types...
for nc = 1:Num_conns
    % Depdending on what the connection type is...
    switch lower(Conn_kind(nc,:)) 
        % Uniform connectivity.
        case 'unif'
            disp(['conntype ', num2str(nc),' is uniform']);
            % Lay out the matrix Conn_addr.  Each row corresponds to a cell in 
            % the ouput area of the fascicle (ordered column-wise from the
            % area). 
            % assemble the sparse Conn_addr matrix; note that we do this target 
            % cell by target cell so conn_prob applies to each cell arbor.  
            % Ideally, conn_prob should be a fraction 1/sourceareasize.
            % NOTE: the result of sprandn seems weird, here.
            Conn_addr = [];
            for i = 1:Area_xy((Conn_fromto(nc,2)),1) * ...
              Area_xy((Conn_fromto(nc,2)),2)
                if (Conn_prob(nc) >= 1.0)
                    Conn_addr = [Conn_addr; ...
                        ones(1,Area_xy((Conn_fromto(nc,1)),1)* ... 
                        Area_xy((Conn_fromto(nc,1)),2))];
                else
                    Conn_addr = [Conn_addr; ... 
                        sprandn(1,Area_xy((Conn_fromto(nc,1)),1)* ... 
                        Area_xy((Conn_fromto(nc,1)),2),Conn_prob(nc))];
                end;
            end;

            % The connection subtype is 'nslf' (no-self), then we want to
            % zero out connections where the (x,y) of the source
            % corresponds with (x,y) of the target.  This is used, for
            % example, when we want to make a lateral inhibition connection
            % and we don't want the connection to include a weight for
            % self-inhibition.  Conn_addr needs to be square for this to
            % work correctly.
            if (strcmp(sscanf(Conn_mask(nc,:),'%s'),'nslf'))
                for i = 1:Area_xy((Conn_fromto(nc,2)),1) * ...
                        Area_xy((Conn_fromto(nc,2)),2)
                    Conn_addr(i,i) = 0.0;
                end;
            end;
                
            % Read all the arbors into CA: first row of CA has target cell ID, 
            % second has source ID
            [a,b,c] = find(Conn_addr);

            % In the case of one output unit, the following need to be done.
            if (size(a,1) == 1)
                a = a';
            end;
            if (size(b,1) == 1)
                b = b';
            end;

            CA = uint16([CA [a,b]']);  % note: area size must not exceed 256x256!!

            % Remember the size of the arbors for each output unit.
            % (i.e. the number of connections of this type for each individual 
            % target cell).
            if (size(Conn_addr,2) > 1)
                CR = uint16([CR full(sum((Conn_addr~=0)'))]);  % note: arbor size must 
                                                               % not exceed 256x256
            else
                CR = uint16([CR (Conn_addr>0)']);
            end;

            % Remember how many connection exist for this fascicle.
            NC = [NC nnz(Conn_addr)];  

            % Assign weights to these connections.
            Conn_weig = (Conn_addr ~= 0) .* ...
                (Weig_mean(nc) + randn(size(Conn_addr)) .* Weig_sigm(nc));

            % Add the weights to CW.
            [a,b,c] = find(Conn_weig);

            % In the case of one output unit, the following need to be done.
            if (size(a,1) == 1)
                a = a';
            end;
            if (size(b,1) == 1)
                b = b';
            end;
            if (size(c,1) == 1)
                c = c';
            end;

            CW = [CW Conn_scle(nc) * c'];

            % Store (presynaptic) channel type.
            CH = [CH uint8(Chan_type(nc) .* ones(1,NC(nc)))];

            % Clear up some storage space.
            clear Conn_addr Conn_addr_rand Conn_weig a b c

        % Topological connectivity.
        case 'topo'
            disp(['conntype ', num2str(nc),' is topographic'])

            % Lay out the matrix Conn_addr.  Each row corresponds to a cell in 
            % the ouput area of the fascicle (ordered column-wise from the area).  
            % Each column corresponds to an available arbor slot (with slots 
            % ordered column-wise from the arbor map).  Conn_addr(number of 
            % cells in target area,number of cells in connarbor)
            Conn_addr = zeros(Area_xy((Conn_fromto(nc,2)),1) * ...
                Area_xy((Conn_fromto(nc,2)),2), Conn_xy(nc,1) * Conn_xy(nc,2));

            % Load the arbor connection mask.  
            % If 'norm', this will be all 1's.
            mask = ones(Conn_xy(nc,2),Conn_xy(nc,1));
            if (strcmp(sscanf(Conn_mask(nc,:),'%s'),'norm'))
                mask = ones(Conn_xy(nc,2),Conn_xy(nc,1));  % here as placeholder 
                                                           % for no-op
            % Else if 'tpinh', make the top half -1's and bottom half 1's
            elseif (strcmp(sscanf(Conn_mask(nc,:),'%s'),'tpinh'))
                mask(1:floor(Conn_xy(nc,2) / 2),:) = -1;
            % Else if 'btinh', make the bottom half -1's and top half 1's
            elseif (strcmp(sscanf(Conn_mask(nc,:),'%s'),'btinh'))
                mask(ceil(Conn_xy(nc,2) / 2)+1:Conn_xy(nc,2),:) = -1;
            % Else if 'lfinh', make the left half -1's and right half 1's
            elseif (strcmp(sscanf(Conn_mask(nc,:),'%s'),'lfinh'))
                mask(:,1:floor(Conn_xy(nc,1) / 2)) = -1;
            % Else if 'rtinh', make the right half -1's and left half 1's
            elseif (strcmp(sscanf(Conn_mask(nc,:),'%s'),'rtinh'))
                mask(:,ceil(Conn_xy(nc,1) / 2)+1:Conn_xy(nc,1)) = -1;
            % Otherwise, load from a .mat file.
            else
                load(sscanf(Conn_mask(nc,:),'%s'));
            end;

            % Create the scaling mask for the whole fascicle from the arbor 
            % connection mask.
            scale_mask = []; 
            for y = 1:Area_xy((Conn_fromto(nc,2)),1) * Area_xy((Conn_fromto(nc,2)),2)
                scale_mask = [scale_mask; reshape(mask,1,Conn_xy(nc,1) * ... 
                    Conn_xy(nc,2))]; 
            end;

            % Now determine the centers of the arbors in the x-direction.
            increm = Area_xy((Conn_fromto(nc,1)),1) / ...
                Area_xy((Conn_fromto(nc,2)),1);
            center_coord_x = [];
            for x = 1:Area_xy((Conn_fromto(nc,2)),1)
                center_coord_x = [center_coord_x floor(1 + 0.5 * increm + ...
                    (x-1) * increm)];
            end;

            % Do the same for the y-direction.
            increm = Area_xy((Conn_fromto(nc,1)),2) / ...
                Area_xy((Conn_fromto(nc,2)),2);
            center_coord_y = [];
            for y = 1:Area_xy((Conn_fromto(nc,2)),2)
                center_coord_y = [center_coord_y floor(1 + 0.5 * increm + ...
                    (y-1) * increm)];
            end;

            % Loop column-wise across all the appropriate centers for arbors...
            cell = 1;
            for xi = 1:length(center_coord_x)
                for yi = 1:length(center_coord_y)
                    % Create a binary mask (X) for the arbor.
                    X = zeros(Area_xy((Conn_fromto(nc,1)),2), ...
                        Area_xy((Conn_fromto(nc,1)),1));
                    X(center_coord_y(yi),center_coord_x(xi)) = 1;
                    SE = ones(Conn_xy(nc,2),Conn_xy(nc,1));
%                     X = imdilate(X,SE);   % This command requires the image 
%                                           % processing toolbox.
                    % Use this on machines missing the image toolbox.
                    loX = center_coord_x(xi) - floor(Conn_xy(nc,1) / 2);
                    loX = max(loX,1);
                    hiX = loX + Conn_xy(nc,1) - 1;
                    hiX = min(hiX,size(X,2));
                    loY = center_coord_y(yi) - floor(Conn_xy(nc,2) / 2);
                    loY = max(loY,1);
                    hiY = loY + Conn_xy(nc,2) - 1;
                    hiY = min(hiY,size(X,1));
                    X(loY:hiY,loX:hiX) = 1;
%         imagesc(X);
%         pause;
                    % Save the arbor to the appropriate row of Conn_addr.

                    % Get the rows and columns that have 1's in them.
                    [a,b] = find(X);

                    % Figure out how many first columns to skip.
                    pre_skip_cols = 0;
                    if (max(b) - size(SE,2) < 0)
                        pre_skip_cols = size(SE,2) - max(b);
                    end;

                    % Figure out how many first rows to skip.
                    pre_skip_rows = 0;  
                    if (max(a) - size(SE,1) < 0)
                        pre_skip_rows = size(SE,1) - max(a);
                    end;

                    % Figure out how many last columns to skip.
                    post_skip_cols = 0;
                    if (min(b) + size(SE,2) > size(X,2) + 1)
                        post_skip_cols = size(SE,2) - size(X,2) + min(b) - 1;
                    end;

                    % Figure out how many last rows to skip.
                    post_skip_rows = 0;  
                    if (min(a) + size(SE,1) > size(X,1) + 1)
                        post_skip_rows = size(SE,1) - size(X,1) + min(a) - 1;
                    end;

                    % Get all the input addresses and fill in the arbor for 
                    % the current cell.
                    c = find(X);
                    conn = 1;
                    for xxi = pre_skip_cols + 1:size(SE,2) - post_skip_cols
                        for yyi = pre_skip_rows + 1:size(SE,1) - post_skip_rows
                            Conn_addr(cell,(xxi - 1) * size(SE,1) + yyi) = c(conn);
                            conn = conn + 1;
                        end;
                    end;

                    % Prepare to get the arbor for next cell.
                    cell = cell + 1;
                end;
            end;

            % Prune away the connections that are actually not made.
            Conn_addr_rand = rand(size(Conn_addr));
            Conn_addr_rand = Conn_addr_rand<=Conn_prob(nc);
            Conn_addr = Conn_addr.*Conn_addr_rand;

            % Read all the arbors into CA: first row of CA has target cell ID, 
            % second has source ID
            [a,b,c] = find(Conn_addr);
            
            % In the case of one output unit, the following need to be done.
            if (size(a,1) == 1)
                a = a';
            end;
            if (size(c,1) == 1)
                c = c';
            end;
            
            CA = uint16([CA [a,c]']);  % note: area size must not exceed 256x256!!

            % Remember the size of the arbors for each output unit.
            % (i.e. the number of connections of this type for each individual 
            % target cell).
            if (size(Conn_addr,2) > 1)
                CR = uint16([CR sum((Conn_addr>0)')]);  % note: arbor size must not 
                                                        % exceed 256x256
            else
                CR = uint16([CR (Conn_addr>0)']);
            end;

            % Remember how many connection exist for this fascicle.
            NC = [NC nnz(Conn_addr)];

            % Assign weights to these connections.
            Conn_weig = logical(Conn_addr>0).*(((randn(size(Conn_addr_rand)).* ... 
                Weig_sigm(nc))+Weig_mean(nc)));

            % Apply the scaling mask to the weights.
            Conn_weig = Conn_weig .* scale_mask;

            % Add the weights to CW.
            [a,b,c] = find(Conn_weig);
            
            % In the case of one output unit, the following need to be
            % done.
            if (size(c,1) == 1)
                c = c';
            end;           
            CW = [CW Conn_scle(nc)*c'];

            % Store (presynaptic) channel type.
            CH = [CH uint8(Chan_type(nc).*ones(1,NC(nc)))];

            % Clear up some storage space
            clear Conn_addr Conn_addr_rand Conn_weig a b c

    end;   % switch(Conn_kind)

end;   % nc (over all fascicles)

% At this point, CA contains unit ID's ranging from 1 to n for each area separately.
% Now convert that into a version of CA that contains as single unit ID ranging from
% 1 to sum(NU) for the whole model.  Then save the respective unit_offsets for 
% later usage.

% Calculate offsets.
unit_offset(1) = 0;
for nu = 2:length(NU)
   unit_offset(nu) = sum(NU(1:nu-1));
end;

% Apply the offsets to the addresses in CA.
off = 1; CA = double(CA);
for nc = 1:length(NC)
   CA(1,off:off+NC(nc)-1) = CA(1,off:off+NC(nc)-1)+unit_offset(Conn_fromto(nc,2));
   CA(2,off:off+NC(nc)-1) = CA(2,off:off+NC(nc)-1)+unit_offset(Conn_fromto(nc,1));
   off = off + NC(nc);
end;
CA = uint16(CA);

% Zero out any negative weights we have if we don't want to use negative
% weights.
if (use_neg_wts == 0)
    CW(CW < 0) = 0;
end;

% Save output.
save(start_model_fname,'Model_name','Num_areas','Num_conns','Area_name', ...
    'Area_num','Cell_type','Area_xy','Conn_name','Conn_fromto', ...
    'Chan_type','Conn_kind','Conn_xy','Conn_prob','Weig_mean', ... 
    'Weig_sigm','Conn_scle','CA','CW','CR','CH','CT','NC','NU', ...
    'unit_offset');