%
% plot_sim.m
%
% This script shows plots of variables over the simulation.
%
% Last modification: 4/26/08


% Make sure we have all of the model indices.
get_cog_model_indices;

% Set the boundary for the init units, so we can display them.
premotor_exec_thresh = 0.65;
babble_exec_thresh = 0.5;

% Select Request units
NodReqUnitX = 2;
NodReqUnitY = 1;
ShakeReqUnitX = 4;
ShakeReqUnitY = 4;
% ShakeReqUnitX = 1;
% ShakeReqUnitY = 2;

%
% Set up user-selected initial variables.
%

% Choose the set of things to be plotted.
% plot_set = 1;   % basic simulation (no cognitive model)
                  % stimuli, responses, and reinforcements
% plot_set = 2;   % C tone adaptive critic simulation
% plot_set = 3;   % general cognitive model simulation
plot_set = 4;   % Nod gating plots
% plot_set = 5;   % Shake gating plots
% plot_set = 6;   % Babble gating plots
% plot_set = 7;   % Nod Request focus analysis plots
% plot_set = 8;   % Shake Request focus analysis plots
% plot_set = 9;   % Nod-Shake Conflict plots
% plot_set = 10;  % Babble Request focus analysis plots (not done yet)
% plot_set = 11;  % Nod Init focus analysis plots
% plot_set = 12;  % Shake Init focus analysis plots
% plot_set = 13;  % Babble Init focus analysis plots
% plot_set = 14;  % Adaptive Go/NoGo unit threshold plots
% plot_set = 15;  % DA Effect plots (showing Nod/Shake thresholds)
% plot_set = 16;  % DA Effect plots (showing Babble thresholds)
% plot_set = 17;  % DA Effect plots (showing no thresholds)
% plot_set = 18;  % DA Signal Unit influence plots

% Set up range of iterations to plot.
min_iter = 1;
max_iter = num_iters;
% min_iter = 850;
% max_iter = 1000;

% Grab script arguments if they exist.
if (~isempty(who('ps_sargs')))
    nargs = size(ps_sargs,2);
    if (nargs > 0)
        plot_set = ps_sargs(1);
    end;
    if (nargs >= 3)
        min_iter = ps_sargs(2);
        max_iter = ps_sargs(3);
    end;
end;

% Initialize title of plot.
plot_title = 'Simulation';

% Lay out the display.
% ID#  What it plots
% -------------------
%   1  Colored square stimulus on (Red, Green, Blue, Yellow)
%   2  Tone stimulus on (Blue/C, Red/Eb)
%   3  Track execution
%   4  Nod execution
%   5  Shake execution
%   6  Behavior execution (nothing/Track, Green/Nod, Red/Shake, Both/Black)
%   7  Errors (Green/Correct, Black/Miss, Red/Wrong Response, 
%        Yellow/Double Response, Blue/Extra Correct Response, 
%        Orangle/Delay Respponse, Violet/Blind Response
%   8  Reward activation
%   9  Punisher activation
%  10  Reinforcement activation (Green/Reward, Red/Punisher)
%  11  Color working memory activation
%  12  Tone working memory activation
%  13  Reinforcement working memory activation (Green/Reward, 
%        Red/Punisher, Yellow/Reward and Punisher)
%  14  Novelty unit activation
%  15  Reward cue excitatory activation
%  16  Reward cue inhibitory activation
%  17  Reward prediction summed activation
%  18  DA cell activation
%  19  Frustration unit activation
%  20  Babble Req activation
%  21  Babble Go excitatory summed activation
%  22  Babble Go inhibitory summed activation
%  23  Babble NoGo summed activation
%  24  Babble Init activation
%  25  Babble Exec activation
%  26  Babble unit summed thresholded activation
%  27  Plan unit summed thresholded activation
%  28  Nod Request summed excitatory activation
%  29  Nod Request unit activation
%  30  Nod Go excitatory summed activation
%  31  Nod Go inhibitory summed activation
%  32  Nod NoGo summed activation
%  33  Nod Init activation
%  34  Shake Request summed excitatory activation
%  35  Shake Request unit activation
%  36  Shake Go excitatory summed activation
%  37  Shake Go inhibitory summed activation
%  38  Shake NoGo summed activation
%  39  Shake Init activation
%  40  Nod / Shake Conflict unit activation
%  41  Plan -> Nod Request netin activity
%  42  Babble -> Nod Request netin activity
%  43  Plan + Babble -> Nod Request netin activity
%  44  Plan -> Shake Request netin activity
%  45  Babble -> Shake Request netin activity
%  46  Plan + Babble -> Shake Request netin activity
%  47  Nod Request -> Init netin activity
%  48  Nod GoE -> Init netin activity
%  49  Nod GoI -> Init netin activity
%  50  Nod NoGo -> Init netin activity
%  51  Nod Init Summed netin activity
%  52  Shake Request -> Init netin activity
%  53  Shake GoE -> Init netin activity
%  54  Shake GoI -> Init netin activity
%  55  Shake NoGo -> Init netin activity
%  56  Shake Init Summed netin activity
%  57  Babble Request -> Init netin activity
%  58  Babble GoE -> Init netin activity
%  59  Babble GoI -> Init netin activity
%  60  Babble NoGo -> Init netin activity
%  61  Babble Init Summed netin activity
%  62  Nod Go units base threshold
%  63  Nod Go units kWTA-adjusted threshold
%  64  Nod NoGo units base threshold
%  65  Nod NoGo units kWTA-adjusted threshold
%  66  Shake Go units base threshold
%  67  Shake Go units kWTA-adjusted threshold
%  68  Shake NoGo units base threshold
%  69  Shake NoGo units kWTA-adjusted threshold
%  70  Babble Go units base threshold
%  71  Babble Go units kWTA-adjusted threshold
%  72  Babble NoGo units base threshold
%  73  Babble NoGo units kWTA-adjusted threshold
%  74  DA plan unit effects
%  75  DA request unit effects
%  76  DA Nod/Shake Go unit effects
%  77  DA Nod/Shake NoGo unit effects
%  78  DA Babble Go unit effects
%  79  DA Babbble NoGo unit effects

% This is the ordering in which the plots are to be shown...
%     case 4
%         disp_plot_map = [ 2 12 1 11 27 28 30 31 32 33 6 7 76 25 ]; 
%     case 5
%         disp_plot_map = [ 2 12 1 11 27 34 36 37 38 39 6 7 76 25 ]; 
%     case 6
%         disp_plot_map = [ 2 12 1 11 6 10 14 19 20 21 22 23 24 78 25 26 ]; 
switch(plot_set)
    case 1
        disp_plot_map = [ 2 1 6 7 10 ];
    case 2
        disp_plot_map = [ 11 12 6 7 10 14 15 16 17 19 18 ];
    case 3
        disp_plot_map = [ 2 12 1 11 6 7 10 13 25 18 ];         
    case 4
        disp_plot_map = [ 2 12 1 11 27 28 30 31 32 33 6 7 18 25 ]; 
    case 5
        disp_plot_map = [ 2 12 1 11 27 34 36 37 38 39 6 7 18 25 ];         
    case 6
        disp_plot_map = [ 2 12 1 11 6 10 14 19 20 21 22 23 24 18 25 26 ];        
    case 7
        disp_plot_map = [ 2 12 1 11 26 27 41 42 43 29 6 7 ];       
    case 8
        disp_plot_map = [ 2 12 1 11 26 27 44 45 46 35 6 7 ];      
    case 9
        disp_plot_map = [ 2 12 1 11 26 27 28 34 40 6 7 ];
    case 10
        disp_plot_map = [ 2 12 1 11 26 27 41 42 43 28 29 6 7 ];      
    case 11
        disp_plot_map = [ 12 11 26 27 28 47 48 49 50 51 33 6 7 ]; 
    case 12
        disp_plot_map = [ 12 11 26 27 34 52 53 54 55 56 39 6 7 ]; 
    case 13
        disp_plot_map = [ 12 11 14 19 20 57 58 59 60 61 24 25 7 ];         
    case 14
        disp_plot_map = [ 2 12 1 11 33 6 7 25 19 62 64 ];  
    case 15
        disp_plot_map = [ 19 18 74 75 76 77 78 79 62 64 ];
    case 16
        disp_plot_map = [ 19 18 74 75 76 77 78 79 70 72 ];
    case 17
        disp_plot_map = [ 19 18 74 75 76 77 78 79 ];        
    case 18
        disp_plot_map = [ 14 8 9 19 18 ]; 
    case 19
        disp_plot_map = [ 18 62 64 ];        
end;

% Initialize labels for plots (in order of plot IDs).
plot_labels = ...
    str2mat( ...
    'default', ...  % Colored square stimulus on
    'default', ...  % Tone stimulus on
    'default', ...  % Track execution
    'default', ...  % Nod execution
    'default', ...  % Shake execution 
    'default', ...  % Behavior execution  
    'default', ...  % Errors 
    'default', ...  % Reward activation 
    'default', ...  % Punisher activation  
    'default', ...  % Reinforcement activation    
    'default', ...  % Color working memory activation  
    'default', ...  % Tone working memory activation 
    'default', ...  % Reinforcement working memory activation    
    'default', ...  % Novelty unit activation   
    'default', ...  % Reward cue excitatory activation      
    'default', ...  % Reward cue inhibitory activation   
    'default', ...  % Reward prediction summed activation 
    'default', ...  % DA cell activation 
    'default', ...  % Frustration unit activation   
    'default', ...  % Babble Req activation      
    'default', ...  % Babble Go excitatory summed activation   
    'default', ...  % Babble Go inhibitory summed activation         
    'default', ...  % Babble NoGo summed activation     
    'default', ...  % Babble Init activation      
    'default', ...  % Babble Exec activation   
    'default', ...  % Babble unit summed thresholded activation
    'default', ...  % Plan unit summed thresholded activation  
    'default', ...  % Nod Req excitatory activation 
    'default', ...  % Nod Request unit activation        
    'default', ...  % Nod Go excitatory summed activation  
    'default', ...  % Nod Go inhibitory summed activation     
    'default', ...  % Nod NoGo summed activation  
    'default', ...  % Nod Init activation      
    'default', ...  % Shake Req excitatory activation 
    'default', ...  % Shake Request unit activation        
    'default', ...  % Shake Go summed excitatory activation   
    'default', ...  % Shake Go summed inhibitory activation       
    'default', ...  % Shake NoGo summed activation  
    'default', ...  % Shake Init activation 
    'default', ...  % Nod / Shake Conflict unit activation 
    'Plan->NodReq', ...     % Plan -> Nod Request netin activity
    'Babble->NodReq',  ...  % Babble -> Nod Request netin activity     
    'P+B->NodReq', ...      % Plan + Babble -> Nod Request netin activity 
    'Plan->ShakeReq', ...     % Plan -> Shake Request netin activity. 
    'Babble->ShakeReq',  ...  % Babble -> Shake Request netin activity     
    'P+B->ShakeReq', ...      % Plan + Babble -> Shake Request netin activity
    'R->NodInit', ...     % Nod Request -> Init netin activity
    'GE->NodInit', ...    % Nod GoE -> Init netin activity
    'GI->NodInit', ...    % Nod GoI -> Init netin activity
    'NG->NodInit', ...    % Nod NoGo -> Init netin activity
    'NodInitSum', ...     % Nod Init Summed netin activity  
    'R->ShakeInit', ...   % Shake Request -> Init netin activity
    'GE->ShakeInit', ...  % Shake GoE -> Init netin activity
    'GI->ShakeInit', ...  % Shake GoI -> Init netin activity
    'NG->ShakeInit', ...  % Shake NoGo -> Init netin activity
    'ShakeInitSum', ...   % Shake Init Summed netin activity     
    'R->BabbleInit', ...  % Babble Request -> Init netin activity
    'GE->BabbleInit', ... % Babble GoE -> Init netin activity
    'GI->BabbleInit', ... % Babble GoI -> Init netin activity
    'NG->BabbleInit', ... % Babble NoGo -> Init netin activity
    'BabbleInitSum', ...  % Babble Init Summed netin activity     
    'NdGoBaseThr', ...     % Nod Go units base threshold
    'NdGoAdjThr',  ...     % Nod Go units kWTA-adjusted threshold  
    'NdNoGoBaseThr', ...   % Nod NoGo units base threshold
    'NdNoGoAdjThr',  ...   % Nod NoGo units kWTA-adjusted threshold      
    'ShGoBaseThr', ...     % Shake Go units base threshold
    'ShGoAdjThr',  ...     % Shake Go units kWTA-adjusted threshold  
    'ShNoGoBaseThr', ...   % Shake NoGo units base threshold
    'ShNoGoAdjThr',  ...   % Shake NoGo units kWTA-adjusted threshold    
    'BaGoBaseThr', ...     % Babble Go units base threshold
    'BaGoAdjThr',  ...     % Babble Go units kWTA-adjusted threshold  
    'BaNoGoBaseThr', ...   % Babble NoGo units base threshold
    'BaNoGoAdjThr',  ...   % Babble NoGo units kWTA-adjusted threshold     
    'DAPlanEff', ...       % DA plan unit effects
    'DAReqEff', ...        % DA request unit effects
    'DANSGoEff', ...       % DA Nod/Shake Go unit effects
    'DANSNoGoEff', ...     % DA Nod/Shake NoGo unit effects
    'DABGoEff', ...        % DA Babble Go unit effects
    'DABNoGoEff' ...       % DA Babble NoGo unit effects    
    );

% Set up (in order of plot IDs) y axis settings.  Each row is a plot = 
% [ custom? min_y max_y min_y_tick max_y_tick ]
y_axis_layout = [ ...
      0  -1  11   0  10; ...  % Colored square stimulus on
      0  -1  11   0  10; ...  % Tone stimulus on
      0  -1  11   0  10; ...  % Track execution
      0  -1  11   0  10; ...  % Nod execution  
      0  -1  11   0  10; ...  % Shake execution   
      0  -1  11   0  10; ...  % Behavior execution 
      0  -1  11   0  10; ...  % Errors    
      0  -1  11   0  10; ...  % Reward activation 
      0  -1  11   0  10; ...  % Punisher activation 
      0  -1  11   0  10; ...  % Reinforcement activation
      0  -1  11   0  10; ...  % Color working memory activation
      0  -1  11   0  10; ...  % Tone working memory activation  
      0  -1  11   0  10; ...  % Reinforcement working memory activation
      0  -1  11   0  10; ...  % Novelty unit activation   
      0  -1  11   0  10; ...  % Reward cue excitatory activation        
      0  -1  11   0  10; ...  % Reward cue inhibitory activation   
      0  -1  11   0  10; ...  % Reward prediction summed activation        
      0  -1  11   0  10; ...  % DA cell activation 
      0  -1  11   0  10; ...  % Frustration unit activation   
      0  -1  11   0  10; ...  % Babble Req activation        
      0  -1  11   0  10; ...  % Babble Go excitatory summed activation   
      0  -1  11   0  10; ...  % Babble Go inhibitory summed activation        
      0  -1  11   0  10; ...  % Babble NoGo activation      
      0  -1  11   0  10; ...  % Babble Init activation   
      0  -1  11   0  10; ...  % Babble Exec activation        
      0  -1  11   0  10; ...  % Babble unit summed thresholded activation 
      0  -1  11   0  10; ...  % Plan unit summed thresholded activation 
      0  -1  11   0  10; ...  % Nod Req excitatory activation   
      0  -1  11   0  10; ...  % Nod Request unit activation        
      0  -1  11   0  10; ...  % Nod Go excitatory summed activation   
      0  -1  11   0  10; ...  % Nod Go inhibitory summed activation        
      0  -1  11   0  10; ...  % Nod NoGo summed activation 
      0  -1  11   0  10; ...  % Nod Init activation 
      0  -1  11   0  10; ...  % Shake Req excitatory activation   
      0  -1  11   0  10; ...  % Shake Request unit activation        
      0  -1  11   0  10; ...  % Shake Go excitatory summed activation   
      0  -1  11   0  10; ...  % Shake Go inhibitory summed activation         
      0  -1  11   0  10; ...  % Shake NoGo summed activation 
      0  -1  11   0  10; ...  % Shake Init activation  
      0  -1  11   0  10; ...  % Nod / Shake Conflict unit activation 
      0  -1  11   0  10; ...  % Plan -> Nod Request netin activity 
      0  -1  11   0  10; ...  % Babble -> Nod Request netin activity 
      0  -1  11   0  10; ...  % Plan + Babble -> Nod Request netin activity 
      0  -1  11   0  10; ...  % Plan -> Shake Request netin activity 
      0  -1  11   0  10; ...  % Babble -> Shake Request netin activity 
      0  -1  11   0  10; ...  % Plan + Babble -> Shake Request netin activity 
      1   0  1.0  0  1.0; ...  % Nod Request -> Init netin activity
      1   0  1.0  0  1.0; ...  % Nod GoE -> Init netin activity
      1   0  1.0  0  1.0; ...  % Nod GoI -> Init netin activity
      1   0  1.0  0  1.0; ...  % Nod NoGo -> Init netin activity     
      1   0  1.0  0  1.0; ...  % Nod Init Summed netin activity  
      1   0  1.0  0  1.0; ...  % Shake Request -> Init netin activity
      1   0  1.0  0  1.0; ...  % Shake GoE -> Init netin activity
      1   0  1.0  0  1.0; ...  % Shake GoI -> Init netin activity
      1   0  1.0  0  1.0; ...  % Shake NoGo -> Init netin activity     
      1   0  1.0  0  1.0; ...  % Shake Init Summed netin activity  
      1   0  1.0  0  1.0; ...  % Babble Request -> Init netin activity
      1   0  1.0  0  1.0; ...  % Babble GoE -> Init netin activity
      1   0  1.0  0  1.0; ...  % Babble GoI -> Init netin activity
      1   0  1.0  0  1.0; ...  % Babble NoGo -> Init netin activity     
      1   0  1.0  0  1.0; ...  % Babble Init Summed netin activity  
      0  -1  11   0  10; ...   % Nod Go units base threshold    
      0  -1  11   0  10; ...   % Nod Go units kWTA-adjusted threshold
      0  -1  11   0  10; ...   % Nod NoGo units base threshold    
      0  -1  11   0  10; ...   % Nod NoGo units kWTA-adjusted threshold
      0  -1  11   0  10; ...   % Shake Go units base threshold    
      0  -1  11   0  10; ...   % Shake Go units kWTA-adjusted threshold
      0  -1  11   0  10; ...   % Shake NoGo units base threshold    
      0  -1  11   0  10; ...   % Shake NoGo units kWTA-adjusted threshold      
      0  -1  11   0  10; ...   % Babble Go units base threshold    
      0  -1  11   0  10; ...   % Babble Go units kWTA-adjusted threshold
      0  -1  11   0  10; ...   % Babble NoGo units base threshold    
      0  -1  11   0  10; ...   % Babble NoGo units kWTA-adjusted threshold 
      0  -1  11   0  10; ...   % DA plan unit effects
      0  -1  11   0  10; ...   % DA request unit effects
      0  -1  11   0  10; ...   % DA Nod/Shake Go unit effects
      0  -1  11   0  10; ...   % DA Nod/Shake NoGo unit effects
      0  -1  11   0  10; ...   % DA Babble Go unit effects
      0  -1  11   0  10 ...    % DA Babble NoGo unit effects       
      ];

num_avail_plots = size(y_axis_layout,1);

%
% Color definitions.
%
col_red =    [1    0   0];
col_orange = [1    0.5 0];
col_yellow = [1    1   0];
col_green =  [0    1   0];
col_blue =   [0    0   1];
col_indigo = [0.5  0   1];
col_violet = [1    0   1];
col_black =  [0    0   0];
col_white =  [1    1   1];

% 
% Set up figure for plotting.
%

% Set up the figure window.
small_window = 0;
if (small_window == 1)
    l_fig_pos = 0.01;
    b_fig_pos = 0.05;
    fig_w = 0.7;
    fig_h = 0.6;
else
    l_fig_pos = 0.01;
    b_fig_pos = 0.05;
    fig_w = 0.9;
    fig_h = 0.85;
end;
% fh = figure(1);
fh = figure;
set(fh,'Units','normalized');
set(fh,'Position',[l_fig_pos b_fig_pos fig_w fig_h]);
colormap(gray);

% Lay out the subplots.
num_plots = size(disp_plot_map,2);
subplot_inds = zeros(num_avail_plots,3);
for ii = 1:num_avail_plots
    x = find(disp_plot_map == ii);
    subplot_inds(ii,1) = num_plots;
    subplot_inds(ii,2) = 1;
    if (isempty(x))
        subplot_inds(ii,3) = 0;
    else
        subplot_inds(ii,3) = x;
    end;
end;

%
% Plot presence of a square stimulus.
%
plot_id = 1;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot red stimuli.
    the_plot = stim_red_sv .* stim_on_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_red);
    hold on;
    
    % Plot green stimuli.
    the_plot = stim_green_sv .* stim_on_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_green);    
    
    % Plot blue stimuli.
    the_plot = stim_blue_sv .* stim_on_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_blue); 
    
    % Plot yellow stimuli.
    the_plot = stim_red_sv .* stim_green_sv .* stim_on_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_yellow);     
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Square On';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot presence of a tone stimulus.
%
plot_id = 2;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot C tone stimuli.
    the_plot = tones_on_sv(1,:);
    ah = area(the_plot);
    set(ah,'FaceColor',col_blue);  
    hold on;

    % Plot Eb tone stimuli.
    the_plot = tones_on_sv(4,:);
    ah = area(the_plot);
    set(ah,'FaceColor',col_red); 
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Tone On';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot Track behavior execution.
%
plot_id = 3;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = track_execute_sv;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Track Behavior';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot Nod behavior execution.
%
plot_id = 4;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = nod_execute_sv;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Nod Behavior';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot Shake behavior execution.
%
plot_id = 5;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = shake_execute_sv;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Shake Behavior';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot behavior execution (Track/Nod/Shake/Both).
%
plot_id = 6;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the Nod data.
    the_plot = nod_execute_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_green); 
    hold on;
    
    % Plot the Shake data.
    the_plot = shake_execute_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_red);  
    
    % Plot the Nod/Shake data.
    the_plot = nod_execute_sv .* shake_execute_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_yellow); 
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Behavior';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot error occurences.
%
plot_id = 7;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));

    % Plot correct responses.
    the_plot = zeros(1,num_iters);
    event_iters = [ target_nod distractor_shake ];
    mark_idx = event_iters;
    mark_idx = [ mark_idx (event_iters + 1) ];
    mark_idx = [ mark_idx (event_iters + 2) ];
    mark_idx = [ mark_idx (event_iters + 3) ];
    mark_idx = [ mark_idx (event_iters + 4) ];
    mark_idx(find(mark_idx > num_iters)) = [];
    the_plot(mark_idx) = 1;
    ah = area(the_plot);
    set(ah,'FaceColor',col_green);   
    hold on; 
    
    % Plot misses.
    the_plot = zeros(1,num_iters);
    event_iters = [ target_miss distractor_miss ];
    mark_idx = event_iters;
    mark_idx = [ mark_idx (event_iters + 1) ];
    mark_idx = [ mark_idx (event_iters + 2) ];
    mark_idx = [ mark_idx (event_iters + 3) ];
    mark_idx = [ mark_idx (event_iters + 4) ];
    mark_idx(find(mark_idx > num_iters)) = [];
    the_plot(mark_idx) = 1;
    ah = area(the_plot);
    set(ah,'FaceColor',col_black);  
    
    % Plot opposite responses.
    the_plot = zeros(1,num_iters);
    event_iters = [ target_shake distractor_nod ];
    mark_idx = event_iters;
    mark_idx = [ mark_idx (event_iters + 1) ];
    mark_idx = [ mark_idx (event_iters + 2) ];
    mark_idx = [ mark_idx (event_iters + 3) ];
    mark_idx = [ mark_idx (event_iters + 4) ];
    mark_idx(find(mark_idx > num_iters)) = [];
    the_plot(mark_idx) = 1;
    ah = area(the_plot);
    set(ah,'FaceColor',col_red);
    
    % Plot target/distractor nod/shakes.
    the_plot = zeros(1,num_iters);
    event_iters = [ target_nod_shake distractor_nod_shake ];
    mark_idx = event_iters;
    mark_idx = [ mark_idx (event_iters + 1) ];
    mark_idx = [ mark_idx (event_iters + 2) ];
    mark_idx = [ mark_idx (event_iters + 3) ];
    mark_idx = [ mark_idx (event_iters + 4) ];
    mark_idx(find(mark_idx > num_iters)) = [];
    the_plot(mark_idx) = 1;
    ah = area(the_plot);
    set(ah,'FaceColor',col_yellow); 
    
    % Plot correct, but extra responses.
    the_plot = zeros(1,num_iters);
    event_iters = [ target_x_nod distractor_x_shake ];
    mark_idx = event_iters;
    mark_idx = [ mark_idx (event_iters + 1) ];
    mark_idx = [ mark_idx (event_iters + 2) ];
    mark_idx = [ mark_idx (event_iters + 3) ];
    mark_idx = [ mark_idx (event_iters + 4) ];
    mark_idx(find(mark_idx > num_iters)) = [];
    the_plot(mark_idx) = 1;
    ah = area(the_plot);
    set(ah,'FaceColor',col_blue); 

    % Plot delay period responses.
    the_plot = zeros(1,num_iters);
    event_iters = [ delay_nod delay_shake delay_nod_shake ];
    mark_idx = event_iters;
    mark_idx = [ mark_idx (event_iters + 1) ];
    mark_idx = [ mark_idx (event_iters + 2) ];
    mark_idx = [ mark_idx (event_iters + 3) ];
    mark_idx = [ mark_idx (event_iters + 4) ];
    mark_idx(find(mark_idx > num_iters)) = [];
    the_plot(mark_idx) = 1;
    ah = area(the_plot);
    set(ah,'FaceColor',col_orange);    

    % Plot blind responses.
    the_plot = zeros(1,num_iters);
    event_iters = [ blind_nod blind_shake ];
    mark_idx = event_iters;
    mark_idx = [ mark_idx (event_iters + 1) ];
    mark_idx = [ mark_idx (event_iters + 2) ];
    mark_idx = [ mark_idx (event_iters + 3) ];
    mark_idx = [ mark_idx (event_iters + 4) ];
    mark_idx(find(mark_idx > num_iters)) = [];
    the_plot(mark_idx) = 1;
    ah = area(the_plot);
    set(ah,'FaceColor',col_violet);
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Errors';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot reward execution.
%
plot_id = 8;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = reward_on_sv;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Reward On';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot punisher activation.
%
plot_id = 9;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = punish_on_sv;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Punisher On';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot reinforcement activation (reward or punishment).
%
plot_id = 10;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the reward data.
    the_plot = reward_on_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_green); 
    hold on; 
    
    % Plot the punisher data.
    the_plot = punish_on_sv;
    ah = area(the_plot);
    set(ah,'FaceColor',col_red);    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Reinf On';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;


%
% Plot the color working memory activity.
%
plot_id = 11;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot red square working memory data.
    area_ind = ColorMem_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_red);     
    hold on;
    
     % Fetch and plot green square working memory data.
    area_ind = ColorMem_ind;
    x_ind = 1;
    y_ind = 2;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_green); 
    
     % Fetch and plot blue square working memory data.
    area_ind = ColorMem_ind;
    x_ind = 1;
    y_ind = 3;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_blue); 
    
     % Fetch and plot yellow square working memory data.
    area_ind = ColorMem_ind;
    x_ind = 1;
    y_ind = 4;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_yellow); 
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Color WM';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the tone working memory activity.
%
plot_id = 12;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the C tone working memory data.
    area_ind = TonesMem_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_blue);     
    hold on;
    
    % Fetch and plot the Eb tone working memory data.
    area_ind = TonesMem_ind;
    x_ind = 1;
    y_ind = 4;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_red); 
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Tone WM';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the reinforcement working memory activity.
%
plot_id = 13;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the reward working memory data.
    area_ind = ReinfMem_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_green);
    rew_trace = activ_trace;
    hold on;
    
    % Fetch and plot the punisher working memory data.
    area_ind = ReinfMem_ind;
    x_ind = 1;
    y_ind = 2;
    fetchps_unit_activ_alliters;
    ah = area(activ_trace);  
    set(ah,'FaceColor',col_red); 
    pun_trace = activ_trace;
    
    % Fetch and plot simultaneous reward/punisher working memory data.
    ah = area(rew_trace .* pun_trace);  
    set(ah,'FaceColor',col_yellow); 
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Reinf WM';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the novelty unit activity.
%
plot_id = 14;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = Novelty_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the reward cue excitatory unit activity.
%
plot_id = 15;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = RewardCue_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the reward cue inhibitory unit activity.
%
plot_id = 16;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = RewardCue_ind + 1;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the reward prediction summed activity.
%
plot_id = 17;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = RewPredict_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the dopamine cell activity.
%
plot_id = 18;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DASignal_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the frustration unit activity.
%
plot_id = 19;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = Frustration_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Req activity.
%
plot_id = 20;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleReq_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Go excitatory summed activity.
%
plot_id = 21;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleGoE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Go inhibitory summed activity.
%
plot_id = 22;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleGoI_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble NoGo summed activity.
%
plot_id = 23;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleNoGo_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Init activity.
%
plot_id = 24;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleInit_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Plot the threshold for the corresponding Exec unit.
    hold on;
    the_plot = babble_exec_thresh * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;   
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Exec activity.
%
plot_id = 25;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleExec_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the babble unit summed thresholded activity.
%
plot_id = 26;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = Babble_ind;   
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        sum_thresh = 0.8;
        the_plot(ii) = sum(sum((activs > sum_thresh)));        
    end;
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = 0;
        max_y_axis = 10; 
        min_y_tick = 0;
        max_y_tick = 10;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
        ystr = strcat(Area_name(area_ind,:), ' tsum');        
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Plan unit summed thresholded activity.
%
plot_id = 27;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = Plan_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        sum_thresh = 0.8;
        the_plot(ii) = sum(sum((activs > sum_thresh)));
    end;
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = 0;
        max_y_axis = 10; 
        min_y_tick = 0;
        max_y_tick = 10;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' tsum');        
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Request excitatory summed activity.
%
plot_id = 28;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodReqE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Request unit activation.
%
plot_id = 29;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodReqE_ind;
    x_ind = NodReqUnitX;
    y_ind = NodReqUnitY;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
 
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Go excitatory summed activity.
%
plot_id = 30;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodGoE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Go inhibitory summed activity.
%
plot_id = 31;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodGoI_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod NoGo summed activity.
%
plot_id = 32;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodNoGo_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Init activity.
%
plot_id = 33;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    unit_ind = 0;
    area_ind = NodInit_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 

    % Plot the threshold for the corresponding Exec unit.
    hold on;
    the_plot = premotor_exec_thresh * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Request excitatory summed activity.
%
plot_id = 34;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeReqE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Request unit activation.
%
plot_id = 35;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    unit_ind = 0;
    area_ind = ShakeReqE_ind;
    x_ind = ShakeReqUnitX;
    y_ind = ShakeReqUnitY;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Go excitatory summed activity.
%
plot_id = 36;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeGoE_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Go inhibitory summed activity.
%
plot_id = 37;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeGoI_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake NoGo summed activity.
%
plot_id = 38;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeNoGo_ind;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;  
        the_plot(ii) = sum(sum(activs));
    end;
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:), ' sum');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Init activity.
%
plot_id = 39;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeInit_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Plot the threshold for the corresponding Exec unit.
    hold on;
    the_plot = premotor_exec_thresh * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod / Shake Conflict unit activation activity.
%
plot_id = 40;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodShakeConf_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
 
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Plan -> Nod Request fascicle summed net input activity.
%
plot_id = 41;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodReqE_ind;
    x_ind = NodReqUnitX;
    y_ind = NodReqUnitY;
    fascin_trace = zeros(1,num_iters);
    for ii = 1:num_iters
        fascin_trace(ii) = plan_nod_req_fascins_data(y_ind,x_ind,ii);
    end;
    area(fascin_trace); 
    ftrace = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble -> Nod Request fascicle summed net input activity.
%
plot_id = 42;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodReqE_ind;
    x_ind = NodReqUnitX;
    y_ind = NodReqUnitY;
    fascin_trace = zeros(1,num_iters);
    for ii = 1:num_iters
        fascin_trace(ii) = babble_nod_req_fascins_data(y_ind,x_ind,ii);
    end;
    area(fascin_trace); 
    ftrace2 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Plan + Babble -> Nod Request fascicle summed net input activity.
%
plot_id = 43;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area(ftrace + ftrace2); 
    
    % Plot the threshold for the corresponding Exec unit.
    hold on;
    the_plot = thresh(Cell_type(area_ind)) * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Plan -> Shake Request fascicle summed net input activity.
%
plot_id = 44;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeReqE_ind;
    x_ind = ShakeReqUnitX;
    y_ind = ShakeReqUnitY;
    fascin_trace = zeros(1,num_iters);
    for ii = 1:num_iters
        fascin_trace(ii) = plan_shake_req_fascins_data(y_ind,x_ind,ii);
    end;
    area(fascin_trace); 
    ftrace = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble -> Shake Request fascicle summed net input activity.
%
plot_id = 45;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeReqE_ind;
    x_ind = ShakeReqUnitX;
    y_ind = ShakeReqUnitY;
    fascin_trace = zeros(1,num_iters);
    for ii = 1:num_iters
        fascin_trace(ii) = babble_shake_req_fascins_data(y_ind,x_ind,ii);
    end;
    area(fascin_trace); 
    ftrace2 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Plan + Babble -> Shake Request fascicle summed net input activity.
%
plot_id = 46;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area(ftrace + ftrace2); 
    
    % Plot the threshold for the corresponding Exec unit.
    hold on;
    the_plot = thresh(Cell_type(area_ind)) * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Request -> Init fascicle summed net input activity.
%
plot_id = 47;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = NodReqtoInit_ind;
    fetchps_unit_fascin_alliters;
    area(fascin_trace); 
    ftrace = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod GoE -> Init fascicle summed net input activity.
%
plot_id = 48;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = NodGoEtoInit_ind;
    fetchps_unit_fascin_alliters;
    area(fascin_trace); 
    ftrace2 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod GoI -> Init fascicle summed net input activity.
%
plot_id = 49;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = NodGoItoInit_ind;
    fetchps_unit_fascin_alliters;
    ah = area(fascin_trace); 
    set(ah,'FaceColor',col_red);    
    ftrace3 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod NoGo -> Init fascicle summed net input activity.
%
plot_id = 50;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = NodNoGotoInit_ind;
    fetchps_unit_fascin_alliters;
    ah = area(fascin_trace); 
    set(ah,'FaceColor',col_red);  
    ftrace4 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Init Summed fascicle summed net input activity.
%
plot_id = 51;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area(ftrace + ftrace2 - ftrace3 - ftrace4); 

    % Plot the threshold for the Nod Init sigmoid.
    hold on;
    the_plot = thresh(Cell_type(NodInit_ind)) * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Request -> Init fascicle summed net input activity.
%
plot_id = 52;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = ShakeReqtoInit_ind;
    fetchps_unit_fascin_alliters;
    area(fascin_trace); 
    ftrace = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake GoE -> Init fascicle summed net input activity.
%
plot_id = 53;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = ShakeGoEtoInit_ind;
    fetchps_unit_fascin_alliters;
    area(fascin_trace); 
    ftrace2 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake GoI -> Init fascicle summed net input activity.
%
plot_id = 54;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = ShakeGoItoInit_ind;
    fetchps_unit_fascin_alliters;
    ah = area(fascin_trace); 
    set(ah,'FaceColor',col_red);    
    ftrace3 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake NoGo -> Init fascicle summed net input activity.
%
plot_id = 55;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = ShakeNoGotoInit_ind;
    fetchps_unit_fascin_alliters;
    ah = area(fascin_trace); 
    set(ah,'FaceColor',col_red);  
    ftrace4 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Init Summed fascicle summed net input activity.
%
plot_id = 56;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area(ftrace + ftrace2 - ftrace3 - ftrace4); 

    % Plot the threshold for the Shake Init sigmoid.
    hold on;
    the_plot = thresh(Cell_type(ShakeInit_ind)) * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Request -> Init fascicle summed net input activity.
%
plot_id = 57;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = BabbleReqtoInit_ind;
    fetchps_unit_fascin_alliters;
    area(fascin_trace); 
    ftrace = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble GoE -> Init fascicle summed net input activity.
%
plot_id = 58;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = BabbleGoEtoInit_ind;
    fetchps_unit_fascin_alliters;
    area(fascin_trace); 
    ftrace2 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble GoI -> Init fascicle summed net input activity.
%
plot_id = 59;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = BabbleGoItoInit_ind;
    fetchps_unit_fascin_alliters;
    ah = area(fascin_trace); 
    set(ah,'FaceColor',col_red);    
    ftrace3 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble NoGo -> Init fascicle summed net input activity.
%
plot_id = 60;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleInit_ind;
    x_ind = 1;
    y_ind = 1;
    fasc_ind = BabbleNoGotoInit_ind;
    fetchps_unit_fascin_alliters;
    ah = area(fascin_trace); 
    set(ah,'FaceColor',col_red);  
    ftrace4 = fascin_trace;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Init Summed fascicle summed net input activity.
%
plot_id = 61;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area(ftrace + ftrace2 - ftrace3 - ftrace4); 

    % Plot the threshold for the Babble Init sigmoid.
    hold on;
    the_plot = thresh(Cell_type(BabbleInit_ind)) * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Go units base threshold.
%
plot_id = 62;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodGoE_ind;
    fetch_area_unit_inds;
    area(base_threshs(unit_inds(1,1),:)); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod Go units kWTA-adjusted threshold.
%
plot_id = 63;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodGoE_ind;
    fetch_area_unit_inds;
    the_plot = base_threshs(unit_inds(1,1),:) + ...
        thresh_adjs(unit_inds(1,1),:);
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod NoGo units base threshold.
%
plot_id = 64;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodNoGo_ind;
    fetch_area_unit_inds;
    area(base_threshs(unit_inds(1,1),:)); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod NoGo units kWTA-adjusted threshold.
%
plot_id = 65;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = NodNoGo_ind;
    fetch_area_unit_inds;
    the_plot = base_threshs(unit_inds(1,1),:) + ...
        thresh_adjs(unit_inds(1,1),:);
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Go units base threshold.
%
plot_id = 66;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeGoE_ind;
    fetch_area_unit_inds;
    area(base_threshs(unit_inds(1,1),:)); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake Go units kWTA-adjusted threshold.
%
plot_id = 67;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeGoE_ind;
    fetch_area_unit_inds;
    the_plot = base_threshs(unit_inds(1,1),:) + ...
        thresh_adjs(unit_inds(1,1),:);
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake NoGo units base threshold.
%
plot_id = 68;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeNoGo_ind;
    fetch_area_unit_inds;
    area(base_threshs(unit_inds(1,1),:)); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Shake NoGo units kWTA-adjusted threshold.
%
plot_id = 69;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = ShakeNoGo_ind;
    fetch_area_unit_inds;
    the_plot = base_threshs(unit_inds(1,1),:) + ...
        thresh_adjs(unit_inds(1,1),:);
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Go units base threshold.
%
plot_id = 70;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleGoE_ind;
    fetch_area_unit_inds;
    area(base_threshs(unit_inds(1,1),:)); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble Go units kWTA-adjusted threshold.
%
plot_id = 71;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleGoE_ind;
    fetch_area_unit_inds;
    the_plot = base_threshs(unit_inds(1,1),:) + ...
        thresh_adjs(unit_inds(1,1),:);
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble NoGo units base threshold.
%
plot_id = 72;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleNoGo_ind;
    fetch_area_unit_inds;
    area(base_threshs(unit_inds(1,1),:)); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Babble NoGo units kWTA-adjusted threshold.
%
plot_id = 73;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = BabbleNoGo_ind;
    fetch_area_unit_inds;
    the_plot = base_threshs(unit_inds(1,1),:) + ...
        thresh_adjs(unit_inds(1,1),:);
    area(the_plot); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA plan unit effects.
%
plot_id = 74;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA request unit effects.
%
plot_id = 75;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 2;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Nod/Shake Go unit effects.
%
plot_id = 76;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 3;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Nod/Shake NoGo unit effects.
%
plot_id = 77;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 4;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Babble Go unit effects.
%
plot_id = 78;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 5;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Babble NoGo unit effects.
%
plot_id = 79;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 6;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

% Show the title in the first subplot.
subplot(num_plots,1,1);
title(plot_title);

% Null out the X tick labels for all but the last subplot.
for ii = 1:(num_plots - 1);
    subplot(num_plots,1,ii);
    set(gca,'XTickLabel',[]);
end;

% Show the iterations in the last subplot.
subplot(num_plots,1,num_plots);
xlabel('Iterations (Increments of 100 ms)');