%
% readparam.m
%
% Function for reading a parameter from a parameter file.  If it is a 
% $ parameter, return the $ parameter's value.  Otherwise, return the 
% number.
%
% Inputs:
%   token: the string to be parsed
%   Fparam_names: the names of parameters we might read from
%   Fparams: the corresponding values (double) of the parameters
%
% Last modification: 10/28/04

function  [param] = readparam(token,Fparam_names,Fparams)

    if (token(1) ~= '$')
        param = str2double(token);
    else
        % Find the matching token.
        matchp = -1;
        for fps = 1:size(Fparams,2)
            if (strcmp(deblank(token(2:size(token,2))), ...
                deblank(Fparam_names(fps,:))) == 1)
                matchp = fps;
            end;
        end; 
        
        % If we have no match, return -1
        if (matchp == -1)
            param = matchp;
        else
            param = Fparams(matchp);
        end;
    end;