%
% runtrialsimC.m
%
% This script runs a working memory simulation trial for the second-year
% project.
%
% Last modification: 3/21/05

% V1 unit parameters.
V1_offset = 0.35;  % offset to V1 squashing
V1_gain = 50;      % gain to V1 squashing
V1_nfr = 0.01;     % noise fraction for V1 units

% Initialize state parameters.
DA_agonism = 1;        % Set to 1 to turn on reuptake inhibition.
DA_antagonism = 0;     % Set to 1 to block the effects of DA.
init_unit_noise = 0.001;
DA_state = 0;
min_DA = 5;
max_DA = 20;
ant_coeff = 0;
reuptake_rate = 0.4;   % good reuptake rate: lower this to make DA super-normal
if (DA_agonism == 1)
%     reuptake_rate = 0.1;     % DA agonist reuptake rate
%     reuptake_rate = 0.175;
%     reuptake_rate = 0.250;
     reuptake_rate = 0.325;
end;
if (DA_antagonism == 1)
     ant_coeff = 1;
%     ant_coeff = 0.75;
%     ant_coeff = 0.5;
%     ant_coeff = 0.25;
end;
discharge_rate = 0.4;

task_area = PFCIdleEind;
lo_bound = 1;
for xx = 1:task_area - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
idle_task_Eunit = lo_bound;
task_area = PFCDMSEind;
lo_bound = 1;
for xx = 1:task_area - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
DMS_task_Eunit = lo_bound;
task_area = PFCDNMSEind;
lo_bound = 1;
for xx = 1:task_area - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
DNMS_task_Eunit = lo_bound;

% Output parameters.
monitor_interval = 100;  
    % how often to tell us how far we are along (0 turns off)
snapshot_interval = 0; 
    % how often to save snapshots of activations and weight values 
    % (0 turns off)
plot_net_activ = 0;
brain_scan = 1;

%
% Load the simulation data.
%

% Load model parameters (connectivity and cell/channel-types).
load modl_parm_1;

% Load physiological parameters (cells and channels).
load phys_parm_1;

% Initialize vectors for unit activity.
% NOTE: Spast and S are ordered so that activity is drawn column-wise from the 
% areas.
Spast = init_unit_noise.*rand(1,sum(NU));      
    % random uniform distribution 0 to 1 * noise factor

% Initialize output data arrays.
output = zeros(sum(NU),T);
output_bs = [];
if (brain_scan == 1)
   output_bs = zeros(sum(NU),T);
end;
output_DA_level = zeros(T,1);

%
% Simulation
%

ctime = cputime;

% For each iteration...
for t=1:T
      
% Monitor progress.
if (mod(t,monitor_interval) == 0) disp(['Iteration ',num2str(t)]); end;

% Save snapshot if at appropriate interval.
if (mod(t,snapshot_interval) == 0)
    save(strcat('sshot',num2str(t)), 'CW', 'output', 'T');
end;

% If it's time to switch phases...
if (ismember(t,tr_ph_start_iter(:,trial_ind)))
    % Increment the phase.
    phase_ind = phase_ind + 1; 
    
    % Select the appropriate stimulus.
    stimI = ph_stim(:,:,tr_phase_id(phase_ind,trial_ind));
    
    % Remember which task unit (if any) to send biasing input to.
    task_bias = ph_task_bias(tr_phase_id(phase_ind,trial_ind));

%     % If dopamine (in PFC deep units) is currently off and needs to come on...
%     if ((dop_on == 0) & (ph_dop_st(tr_phase_id(phase_ind,trial_ind)) == 2))
%         % Change all type 4 units to type 5 units.
%         CT(find(CT == 4)) = 5;  
%         
%         % Modify all the weights for the distal dopamine-modulated 
%         % connections.
%         CW(find(CH == 3)) = CW(find(CH == 3)) * 0.8;
%         
%         % Remember that the dopamine is on.
%         dop_on = 1;
%     end;
%     
%     % If dopamine (in PFC deep units) is currently on and needs to turn off...
%     if ((dop_on == 1) & (ph_dop_st(tr_phase_id(phase_ind,trial_ind)) == 0))
%         % Change all type 5 units to type 4 units.       
%         CT(find(CT == 5)) = 4;  
%         
%         % Modify all the weights for the distal dopamine-modulated 
%         % connections.
%         CW(find(CH == 3)) = CW(find(CH == 3)) * 1/0.8;        
%        
%         % Remember that the dopamine is off.
%         dop_on = 0;
%     end;    
end;
    
% Do convolutions to get inputs to vertical and horizontal V1 units.
V1_input_h = conv2(stimI,filt_h,'same');
V1_input_v = conv2(stimI,filt_v,'same');  

% Apply noise and squashing to V1 inputs.
V1_H = sigm(V1_offset,V1_gain,V1_input_h + V1_nfr.*randn(size(V1_input_h)));
V1_V = sigm(V1_offset,V1_gain,V1_input_v + V1_nfr.*randn(size(V1_input_v)));

% Now do the "Gestalt-like" self-connections
V1_H = conv2(V1_H,2.*gest_h,'same');
V1_V = conv2(V1_V,2.*gest_v,'same');

% Apply noise and squashing to V1 inputs.
V1_H = sigm(V1_offset,V1_gain,V1_H + V1_nfr.*randn(size(V1_H)));
V1_V = sigm(V1_offset,V1_gain,V1_V + V1_nfr.*randn(size(V1_V)));

% Feed the horizontal V1 inputs into the first set of units of the network.
numV1_H = size(V1_H,1) * size(V1_H,2);
Spast(1:numV1_H) = V1_H;

% Feed the vertical V1 outputs into the second set of units of the network.
numV1_V = size(V1_V,1) * size(V1_V,2);
Spast((numV1_H + 1):(numV1_H + numV1_V)) = V1_V;

% Calculate inputs to V4 cross units.
V4Ci = conv2(V1_H,hbar,'same') + conv2(V1_V,vbar,'same');
% V4Ci = blkproc(V4Ci,[4 4],'blkavg');  % 'blkproc' needs a toolbox
% Use this when toolbox is missing...
bavg = zeros(16,16);
for ii = 1:16
    for jj = 1:16
        loX = (ii - 1) * 4 + 1;
        hiX = loX + 3;
        loY = (jj - 1) * 4 + 1;
        hiY = loY + 3;
        bavg(jj,ii) = mean(mean(V4Ci(loY:hiY,loX:hiX)));
    end;
end;
V4Ci = bavg;

% Calculate inputs to V4 T units.
V4Ti = conv2(V1_H,hbar,'same') + conv2(V1_V,vbartpend,'same');
% V4Ti = blkproc(V4Ti,[4 4],'blkavg');  % 'blkproc' needs a toolbox
% Use this when toolbox is missing...
for ii = 1:16
    for jj = 1:16
        loX = (ii - 1) * 4 + 1;
        hiX = loX + 3;
        loY = (jj - 1) * 4 + 1;
        hiY = loY + 3;
        bavg(jj,ii) = mean(mean(V4Ti(loY:hiY,loX:hiX)));
    end;
end;
V4Ti = bavg;

% Calculate inputs to V4 L units.
V4Li = conv2(V1_H,hbarlfend,'same') + conv2(V1_V,vbarbtend,'same');
% V4Li = blkproc(V4Li,[4 4],'blkavg');  % 'blkproc' needs a toolbox
% Use this when toolbox is missing...
for ii = 1:16
    for jj = 1:16
        loX = (ii - 1) * 4 + 1;
        hiX = loX + 3;
        loY = (jj - 1) * 4 + 1;
        hiY = loY + 3;
        bavg(jj,ii) = mean(mean(V4Li(loY:hiY,loX:hiX)));
    end;
end;
V4Li = bavg;

% Feed the vertical V4 inputs into the third set of units of the network.
numV4Ci = size(V4Ci,1) * size(V4Ci,2);
Spast((numV1_H + numV1_V + 1):(numV1_H + numV1_V + numV4Ci)) = V4Ci;
numV4Ti = size(V4Ti,1) * size(V4Ti,2);
Spast((numV1_H + numV1_V + numV4Ci + 1):(numV1_H + numV1_V + numV4Ci + ... 
    numV4Ti)) = V4Ti;
numV4Li = size(V4Li,1) * size(V4Li,2);
Spast((numV1_H + numV1_V + numV4Ci + numV4Ti + 1):(numV1_H + numV1_V + ... 
    numV4Ci + numV4Ti + numV4Li)) = V4Li;

% Feed the PFC task unit inputs into the appropriate units in the model.
% Zero the Idle unit input.
task_area = PFCIdleEind - 1;  % -1 means the input unit, not the E unit.
lo_bound = 1;
for xx = 1:task_area - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(task_area,3) - 1;
Spast(lo_bound:hi_bound) = 0;

% Zero the DMS unit input.
task_area = PFCDMSEind - 1;
lo_bound = 1;
for xx = 1:task_area - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(task_area,3) - 1;
Spast(lo_bound:hi_bound) = 0;

% Zero the DNMS unit input.
task_area = PFCDNMSEind - 1;
lo_bound = 1;
for xx = 1:task_area - 1
    lo_bound = lo_bound + Area_xy(xx,3);
end;
hi_bound = lo_bound + Area_xy(task_area,3) - 1;
Spast(lo_bound:hi_bound) = 0;

% Select which task unit to send a bias signal to.
if (task_bias == 1)
    task_area = PFCIdleEind - 1;
elseif (task_bias == 2)
    task_area = PFCDMSEind - 1;
elseif (task_bias == 3) 
    task_area = PFCDNMSEind - 1;
else
    task_area = 0;
end;

% If any task unit was selected, send bias input to it.
if (task_area ~= 0)
	lo_bound = 1;
	for xx = 1:task_area - 1
        lo_bound = lo_bound + Area_xy(xx,3);
	end;
	hi_bound = lo_bound + Area_xy(task_area,3) - 1;
	Spast(lo_bound:hi_bound) = 1;
end;

% First sum all the voltage-independent inputs; VI(CH) is the filter for 
% vi-inputs.
Avi = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC),VI(CH).*CW.* ...
    Spast(CA(2,:))),2)';

% If brain scan is desired, save absolute values of voltage-independent synaptic 
% inputs to all units
if (brain_scan == 1)
   Avi_bs = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC),VI(CH).* ...
       abs(CW).*Spast(CA(2,:))),2)';
end;
 
% Then sum all the voltage-dependent inputs.
vd_thresh = 0.3;
vd_gain = 50;
% vd_thresh = 50.0;
Avd = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC),~VI(CH) ...
    .*sigm(vd_thresh,vd_gain,Avi(CA(1,:))) ...
    .*CW.*Spast(CA(2,:))),2)';

% If brain scan is desired, save absolute values of voltage-dependent synaptic 
% inputs to all units, i.e. they are treated as if they are voltage-independent
if (brain_scan == 1)
   Avd_bs = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC),~VI(CH).* ...
       abs(CW).*Spast(CA(2,:))),2)';
end;

% Update unit activity.
S = Spast + wcunitupdate(Spast,Avi+Avd,thresh(CT),gain(CT),namp(CT), ...
    growth(CT),decay(CT));
%S = Spast + wcunitupdate(Spast,Avi,thresh(CT),gain(CT),namp(CT), ...
%     growth(CT),decay(CT));

% Calculate total synaptic activity
if (brain_scan == 1)
   syn_bs = Avi_bs + Avd_bs;
end;

% % Determine whether we have a response or not.
% resp_area = 23;
% % resp_thresh = 13;  % threshold for trials1c
% resp_thresh = 18;  % threshold for trials1g
% lo_bound = 1;
% for xx = 1:resp_area - 1
%     lo_bound = lo_bound + Area_xy(xx,3);
% end;
% hi_bound = lo_bound + Area_xy(resp_area,3) - 1;
% resp_sum = sum(S(lo_bound:hi_bound));
% 
% % If our response is over threshold and the dopamine is on
% % and in a resetable state, turn off the dopamine.
% if ((dop_on == 1) & ...
%     (ph_dop_st(tr_phase_id(phase_ind,trial_ind)) == 1) & ...
%     (resp_sum > resp_thresh))
%     % Change all type 5 units to type 4 units.       
%     CT(find(CT == 5)) = 4;  
%     
%     % Modify all the weights for the distal dopamine-modulated 
%     % connections.
%     CW(find(CH == 3)) = CW(find(CH == 3)) * 1/0.8;        
%    
%     % Remember that the dopamine is off.
%     dop_on = 0;
% end;

% Update the dopamine (DA) state (should fall between 0 and 1).
DA_state = DA_state - DA_state * reuptake_rate + ...
    discharge_rate * (S(DMS_task_Eunit) + S(DNMS_task_Eunit));

% Set the absolute DA level from the 0 to 1-varying state.
DA_level = DA_state * (1 - ant_coeff) * (max_DA - min_DA) + min_DA;

% Adjust the gains of the dopamine modulated units.
gain(4) = DA_level;   % set this to min_DA for hypo-DA condition

% Overwrite the new results for the V1 populations since these aren't supposed 
% to be changing except for noise.
S(1:numV1_H) = V1_H;
S((numV1_H + 1):(numV1_H + numV1_V)) = V1_V;

% Do the same for the V4 feature unit inputs.
S((numV1_H + numV1_V + 1):(numV1_H + numV1_V + numV4Ci)) = V4Ci;
S((numV1_H + numV1_V + numV4Ci + 1):(numV1_H + numV1_V + numV4Ci + ...
    numV4Ti)) = V4Ti;
S((numV1_H + numV1_V + numV4Ci + numV4Ti + 1):(numV1_H + numV1_V + ...
    numV4Ci + numV4Ti + numV4Li)) = V4Li;

% Save unit activities for later display.
output(:,t) = S';
if (brain_scan == 1)
   output_bs(:,t) = syn_bs';
end;
output_DA_level(t,1) = DA_level;

% Remember the previous activations.
Spast = S;

% If we want, plot all of the layers after each time step.
if (plot_net_activ == 1)
	fh = figure(1);
    set(fh,'Name',strcat('Trial ',num2str(trial_ind),' Iter ', ...
        num2str(t)));
	colormap(gray);
	subplot(4,6,1)
	area_ind = V1Hind; 
	disp_area_act;
	subplot(4,6,2)
	area_ind = V1Vind; 
	disp_area_act;
	subplot(4,6,3)
	imagesc(stimI,[0 1]);
	axis square;
 	subplot(4,6,4)
 	area_ind = PFCIdleEind; 
 	disp_area_act;     
 	subplot(4,6,5)
 	area_ind = DMSMatEind; 
 	disp_area_act;        
	subplot(4,6,7)
	area_ind = V4CrEind; 
	disp_area_act;
	subplot(4,6,8)
	area_ind = V4TEind; 
	disp_area_act;   
	subplot(4,6,9)
	area_ind = V4LEind; 
	disp_area_act;
  	subplot(4,6,10)
 	area_ind = PFCDMSEind; 
 	disp_area_act;
 	subplot(4,6,11)
 	area_ind = DMSMismEind; 
 	disp_area_act;     
  	subplot(4,6,12)
 	area_ind = NodEind; 
 	disp_area_act;        
 	subplot(4,6,13)
 	area_ind = ITCrEind; 
 	disp_area_act;
 	subplot(4,6,14)
 	area_ind = ITTEind; 
 	disp_area_act;
 	subplot(4,6,15)
 	area_ind = ITLEind; 
 	disp_area_act;
    subplot(4,6,16)
 	area_ind = PFCDNMSEind; 
 	disp_area_act;     
  	subplot(4,6,17)
 	area_ind = DNMSMatEind; 
 	disp_area_act;     
   	subplot(4,6,18)
 	area_ind = ShakeEind; 
 	disp_area_act;        
 	subplot(4,6,19)
 	area_ind = PFCSEind; 
 	disp_area_act;    
  	subplot(4,6,20)
 	area_ind = PFCDEind; 
 	disp_area_act;
 	subplot(4,6,21)
 	area_ind = PFCMEind; 
 	disp_area_act;    
    subplot(4,6,22)
    imagesc(DA_level,[5 20]);
    axis square;    
  	subplot(4,6,23)
 	area_ind = DNMSMismEind; 
 	disp_area_act;  
  	subplot(4,6,24)    
 	area_ind = ACCEind; 
 	disp_area_act;        
    pause(1.0);  % needed on my desktop because of performance issues
end;

end;   % end of main loop

cputime-ctime

save out1 output output_bs output_DA_level T
