%
% set_simulation_params.m
%
% Set the parameters for simulation runs.  Needs to be run before
% fresh_model_run or the other simulation scripts.  Edit the lines in this
% script and run...
%
% Last modification: 7/17/07

% phys_parm_fname: the physiological parameters .dat parameter text file
% model_parm_fname: the model .dat text file
% sim_out_fname: the .mat file containing simulation results not including
%     the neurocognitive model
% cogmodel_out_fname: the .mat file containing simulation results related
%     to the neurocognitive model
% start_model_fname: the .mat file containing model parameters for the model
%     that the simulator will begin with in the simulation
% train_model_fname: the .mat file containing model parameters for the model
%     that the simulator will save as the trained model after the run
% prev_train_model_fname: the .mat file used to save the current version of
%     the train_model_fname file before it is overwritten with new 
%     parameters
% backup_model_fname: .mat file used by save_modl_parm.m to back up the
%     current version of the train_model_fname parameters
% phys_fname: the .mat file containing physiological parameters for the
%     model the simulator will use
% lock_model: if set to 1, this protects the user from running
%     fresh_model_run and overwriting an existing model that (for example a
%     saved demo)  It will also prevent the file designated by 
%     train_model_fname from being overwritten

clear all;
close all;

simulation_model = 'MainModel';
% simulation_model = 'LatestDemo';
% simulation_model = 'DACriticModel';
% simulation_model = 'TestModel';
% simulation_model = 'DemoModel1';
% simulation_model = 'LayerModel';
if (strcmp(simulation_model,'MainModel'))
    lock_model = 0;
    phys_parm_fname = 'phys_parm_1.dat';
    model_parm_fname = 'model_1.dat';
    sim_out_fname = 'sim_out1';   % don't need to tack on '.mat'
    cogmodel_out_fname = 'cog_out1';   % don't need to tack on '.mat'
    start_model_fname = 'modl_parm_1';   % don't need to tack on '.mat'
    train_model_fname = 'modl_parm_tr';   % don't need to tack on '.mat'
    prev_train_model_fname = 'prev_modl_parm_tr'; 
                                  % don't need to tack on '.mat'
    backup_model_fname = 'backup_modl_parm_tr';   
                                  % don't need to tack on '.mat'                    
    phys_fname = 'phys_parm_1';   % don't need to tack on '.mat' 
elseif (strcmp(simulation_model,'LatestDemo')) 
    lock_model = 1;
    phys_parm_fname = 'phys_parm_7.17.07.dat';
    model_parm_fname = 'model_7.17.07.dat';
    sim_out_fname = 'latest_demo_sim_out';   % don't need to tack on '.mat'
    cogmodel_out_fname = 'latest_demo_cog_out';   % don't need to tack on '.mat'
    start_model_fname = 'latest_demo_modl_parm';   % don't need to tack on '.mat'
    train_model_fname = 'latest_demo_modl_parm_tr';   
                                  % don't need to tack on '.mat'
    prev_train_model_fname = 'latest_demo_prev_modl_parm_tr'; 
                                  % don't need to tack on '.mat'
    backup_model_fname = 'latest_demo_backup_modl_parm_tr';   
                                  % don't need to tack on '.mat'        
    phys_fname = 'latest_demo_phys_parm';   % don't need to tack on '.mat'  
    simulation_model = 'MainModel';    
elseif (strcmp(simulation_model,'DACriticModel')) 
    lock_model = 0;
    phys_parm_fname = 'DAcrit_parm.dat';  
    model_parm_fname = 'DAcrit_model.dat';
    sim_out_fname = 'sim_out1';   % don't need to tack on '.mat'
    cogmodel_out_fname = 'cog_out1';   % don't need to tack on '.mat'   
    start_model_fname = 'modl_parm_1';   % don't need to tack on '.mat'
    train_model_fname = 'modl_parm_tr';   % don't need to tack on '.mat'
    phys_fname = 'phys_parm_1';   % don't need to tack on '.mat'       
elseif (strcmp(simulation_model,'TestModel')) 
    lock_model = 0;
    phys_parm_fname = 'test_parm.dat';  
    model_parm_fname = 'test_model.dat';
    sim_out_fname = 'sim_out1';   % don't need to tack on '.mat'
    cogmodel_out_fname = 'cog_out1';   % don't need to tack on '.mat'   
    start_model_fname = 'modl_parm_1';   % don't need to tack on '.mat'
    train_model_fname = 'modl_parm_tr';   % don't need to tack on '.mat'
    phys_fname = 'phys_parm_1';   % don't need to tack on '.mat'    
elseif (strcmp(simulation_model,'DemoModel1')) 
    lock_model = 1;
    phys_parm_fname = 'phys_parm_11.18.06.dat';
    model_parm_fname = 'model_11.18.06.dat';
    sim_out_fname = 'sim_out1';   % don't need to tack on '.mat'
    cogmodel_out_fname = 'cog_out1';   % don't need to tack on '.mat'
    start_model_fname = 'demo_model1';   % don't need to tack on '.mat'
    train_model_fname = 'modl_parm_tr';   % don't need to tack on '.mat'
    phys_fname = 'phys_parm_1';   % don't need to tack on '.mat'  
    simulation_model = 'MainModel';
elseif (strcmp(simulation_model,'LayerModel')) 
    lock_model = 0;
    phys_parm_fname = 'layer_parm.dat';  
    model_parm_fname = 'layer_model.dat';
    sim_out_fname = 'sim_out1';   % don't need to tack on '.mat'
    cogmodel_out_fname = 'cog_out1';   % don't need to tack on '.mat'   
    start_model_fname = 'modl_parm_1';   % don't need to tack on '.mat'
    train_model_fname = 'modl_parm_tr';   % don't need to tack on '.mat'
    phys_fname = 'phys_parm_1';   % don't need to tack on '.mat'
end;
save sim_run_params simulation_model lock_model phys_parm_fname ...
    model_parm_fname sim_out_fname cogmodel_out_fname start_model_fname ...
    train_model_fname prev_train_model_fname backup_model_fname phys_fname;

% Show what simulation model is to be run.
simulation_model