%
% wcunitupdate.m
%
% Function of a Wilson/Cowan (sub-)unit.  The unit stands for a population
% of excitatory or inhibitory (cortical) neurons.  An actual Wilson-Cowan
% unit consists of one of these units for the E pool and another for the I
% pool.  This function implements the leaky-integrator equation for such a
% sub-unit.
%
% Inputs:
%   activ_curr: the current activation level of the WC sub-unit
%   activ_fanin: the raw activation from the summed input activity
%   thresh: the threshold of the sigmoidal output function for the sub-unit
%   gain: the gain of the sigmoidal output function for the sub-unit
%   noise_frac: the amount of noise to be added to activ_fanin
%   growth: the growth factor for the unit's activation
%   decay: the decay factor for the unit's activation
%
% Last modification: 10/15/04

function  [activ_diff] = wcunitupdate(activ_curr,activ_fanin,thresh,gain, ...
    noise_frac,growth,decay)

    % Get the sigmoidal results for the inputs.
    sigm_res = sigm(thresh,gain,activ_fanin + noise_frac.*randn(size(activ_fanin)));
    
    % Return the change to apply to the unit activation.
    activ_diff = growth .* sigm_res - decay .* activ_curr;